import React, { useMemo, forwardRef, useState, useCallback, Fragment, useLayoutEffect, useEffect } from 'react';
import { ArrowRight, Cancel, CheckBox, ClearAll, Close, DensityMedium, DensitySmall, KeyboardDoubleArrowDown, DragHandle, DynamicFeed, Edit, ExpandLess, ExpandMore, FilterAlt, FilterAltOff, FilterList, FilterListOff, FullscreenExit, Fullscreen, MoreHoriz, MoreVert, PushPin, RestartAlt, Save, Search, SearchOff, Sort, ViewColumn, VisibilityOff } from '@mui/icons-material';
import { createTable, getCoreRowModel, getExpandedRowModel, getFacetedRowModel, getFilteredRowModel, getGroupedRowModel, getPaginationRowModel, getSortedRowModel, useTableInstance } from '@tanstack/react-table';
import { Tooltip, IconButton, Menu, MenuItem, Box, FormControlLabel, Switch, Button, Divider, ListItemIcon, Checkbox, debounce, Collapse, TextField, InputAdornment, TablePagination, Chip, Alert, LinearProgress, useMediaQuery, Toolbar, lighten, alpha, TableSortLabel, TableCell, TableRow, TableHead, darken, Skeleton, TableBody, TableFooter, Table, TableContainer, Paper, Dialog, Grow } from '@mui/material';
import { rankItem, rankings } from '@tanstack/match-sorter-utils';
import { useDrop, useDrag, DndProvider } from 'react-dnd';
import { HTML5Backend } from 'react-dnd-html5-backend';
import { useVirtual } from 'react-virtual';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _objectDestructuringEmpty(obj) {
  if (obj == null) throw new TypeError("Cannot destructure undefined");
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MRT_DefaultLocalization_EN = {
  actions: 'Actions',
  and: 'and',
  cancel: 'Cancel',
  changeFilterMode: 'Change filter mode',
  changeSearchMode: 'Change search mode',
  clearFilter: 'Clear filter',
  clearSearch: 'Clear search',
  clearSort: 'Clear sort',
  clickToCopy: 'Click to copy',
  columnActions: 'Column Actions',
  copiedToClipboard: 'Copied to clipboard',
  edit: 'Edit',
  expand: 'Expand',
  expandAll: 'Expand all',
  filterBetween: 'Between',
  filterByColumn: 'Filter by {column}',
  filterContains: 'Contains',
  filterEmpty: 'Empty',
  filterEndsWith: 'Ends With',
  filterEquals: 'Equals',
  filterFuzzy: 'Fuzzy',
  filterGreaterThan: 'Greater Than',
  filterLessThan: 'Less Than',
  filterMode: 'Filter Mode: {filterType}',
  filterNotEmpty: 'Not Empty',
  filterNotEquals: 'Not Equals',
  filterStartsWith: 'Starts With',
  filteringByColumn: 'Filtering by {column} - {filterType} {filterValue}',
  grab: 'Grab',
  groupByColumn: 'Group by {column}',
  groupedBy: 'Grouped by ',
  hideAll: 'Hide all',
  hideColumn: 'Hide {column} column',
  max: 'Max',
  min: 'Min',
  pinToLeft: 'Pin to left',
  pinToRight: 'Pin to right',
  resetColumnSize: 'Reset column size',
  resetOrder: 'Reset order',
  rowActions: 'Row Actions',
  rowNumber: '#',
  rowNumbers: 'Row Numbers',
  save: 'Save',
  search: 'Search',
  selectedCountOfRowCountRowsSelected: '{selectedCount} of {rowCount} row(s) selected',
  select: 'Select',
  showAll: 'Show all',
  showAllColumns: 'Show all columns',
  showHideColumns: 'Show/Hide columns',
  showHideFilters: 'Show/Hide filters',
  showHideSearch: 'Show/Hide search',
  sortByColumnAsc: 'Sort by {column} ascending',
  sortByColumnDesc: 'Sort by {column} descending',
  sortedByColumnAsc: 'Sorted by {column} ascending',
  sortedByColumnDesc: 'Sorted by {column} descending',
  thenBy: ', then by ',
  to: 'to',
  toggleDensePadding: 'Toggle dense padding',
  toggleFullScreen: 'Toggle full screen',
  toggleSelectAll: 'Toggle select all',
  toggleSelectRow: 'Toggle select row',
  ungroupByColumn: 'Ungroup by {column}',
  unpin: 'Unpin',
  unpinAll: 'Unpin all',
  unsorted: 'Unsorted'
};

var MRT_Default_Icons = {
  ArrowRightIcon: ArrowRight,
  CancelIcon: Cancel,
  CheckBoxIcon: CheckBox,
  ClearAllIcon: ClearAll,
  CloseIcon: Close,
  DensityMediumIcon: DensityMedium,
  DensitySmallIcon: DensitySmall,
  KeyboardDoubleArrowDownIcon: KeyboardDoubleArrowDown,
  DragHandleIcon: DragHandle,
  DynamicFeedIcon: DynamicFeed,
  EditIcon: Edit,
  ExpandLessIcon: ExpandLess,
  ExpandMoreIcon: ExpandMore,
  FilterAltIcon: FilterAlt,
  FilterAltOffIcon: FilterAltOff,
  FilterListIcon: FilterList,
  FilterListOffIcon: FilterListOff,
  FullscreenExitIcon: FullscreenExit,
  FullscreenIcon: Fullscreen,
  MoreHorizIcon: MoreHoriz,
  MoreVertIcon: MoreVert,
  PushPinIcon: PushPin,
  RestartAltIcon: RestartAlt,
  SaveIcon: Save,
  SearchIcon: Search,
  SearchOffIcon: SearchOff,
  SortIcon: Sort,
  ViewColumnIcon: ViewColumn,
  VisibilityOffIcon: VisibilityOff
};

var MRT_ExpandAllButton = function MRT_ExpandAllButton(_ref) {
  var tableInstance = _ref.tableInstance;
  var getIsAllRowsExpanded = tableInstance.getIsAllRowsExpanded,
      getIsSomeRowsExpanded = tableInstance.getIsSomeRowsExpanded,
      getCanSomeRowsExpand = tableInstance.getCanSomeRowsExpand,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      KeyboardDoubleArrowDownIcon = _tableInstance$option.icons.KeyboardDoubleArrowDownIcon,
      localization = _tableInstance$option.localization,
      renderDetailPanel = _tableInstance$option.renderDetailPanel,
      toggleAllRowsExpanded = tableInstance.toggleAllRowsExpanded;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expandAll
  }, React.createElement(IconButton, {
    "aria-label": localization.expandAll,
    disabled: !getCanSomeRowsExpand() && !renderDetailPanel,
    onClick: function onClick() {
      return toggleAllRowsExpanded(!getIsAllRowsExpanded());
    },
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React.createElement(KeyboardDoubleArrowDownIcon, {
    style: {
      transform: "rotate(" + (getIsAllRowsExpanded() ? -180 : getIsSomeRowsExpanded() ? -90 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_ExpandButton = function MRT_ExpandButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      ExpandMoreIcon = _tableInstance$option.icons.ExpandMoreIcon,
      localization = _tableInstance$option.localization,
      onMrtRowExpandChange = _tableInstance$option.onMrtRowExpandChange,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleToggleExpand = function handleToggleExpand(event) {
    row.toggleExpanded();
    onMrtRowExpandChange == null ? void 0 : onMrtRowExpandChange({
      event: event,
      row: row,
      tableInstance: tableInstance
    });
  };

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expand
  }, React.createElement(IconButton, {
    "aria-label": localization.expand,
    disabled: !row.getCanExpand() && !renderDetailPanel,
    onClick: handleToggleExpand,
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React.createElement(ExpandMoreIcon, {
    style: {
      transform: "rotate(" + (!row.getCanExpand() && !renderDetailPanel ? -90 : row.getIsExpanded() ? -180 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_FILTER_OPTION;

(function (MRT_FILTER_OPTION) {
  MRT_FILTER_OPTION["BETWEEN"] = "between";
  MRT_FILTER_OPTION["CONTAINS"] = "contains";
  MRT_FILTER_OPTION["EMPTY"] = "empty";
  MRT_FILTER_OPTION["ENDS_WITH"] = "endsWith";
  MRT_FILTER_OPTION["EQUALS"] = "equals";
  MRT_FILTER_OPTION["FUZZY"] = "fuzzy";
  MRT_FILTER_OPTION["GREATER_THAN"] = "greaterThan";
  MRT_FILTER_OPTION["LESS_THAN"] = "lessThan";
  MRT_FILTER_OPTION["NOT_EMPTY"] = "notEmpty";
  MRT_FILTER_OPTION["NOT_EQUALS"] = "notEquals";
  MRT_FILTER_OPTION["STARTS_WITH"] = "startsWith";
})(MRT_FILTER_OPTION || (MRT_FILTER_OPTION = {}));

var fuzzy = function fuzzy(row, columnId, value, addMeta) {
  var itemRank = rankItem(row.getValue(columnId), value, {
    threshold: rankings.MATCHES
  });
  addMeta(itemRank);
  return itemRank.passed;
};

fuzzy.autoRemove = function (val) {
  return !val;
};

var contains = function contains(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().includes(filterValue.toString().toLowerCase().trim());
};

contains.autoRemove = function (val) {
  return !val;
};

var startsWith = function startsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().startsWith(filterValue.toString().toLowerCase().trim());
};

startsWith.autoRemove = function (val) {
  return !val;
};

var endsWith = function endsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().endsWith(filterValue.toString().toLowerCase().trim());
};

endsWith.autoRemove = function (val) {
  return !val;
};

var equals = function equals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() === filterValue.toString().toLowerCase().trim();
};

equals.autoRemove = function (val) {
  return !val;
};

var notEquals = function notEquals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() !== filterValue.toString().toLowerCase().trim();
};

notEquals.autoRemove = function (val) {
  return !val;
};

var greaterThan = function greaterThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) >= +filterValue : row.getValue(id).toString().toLowerCase().trim() > filterValue.toString().toLowerCase().trim();
};

greaterThan.autoRemove = function (val) {
  return !val;
};

var lessThan = function lessThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) <= +filterValue : row.getValue(id).toString().toLowerCase().trim() < filterValue.toString().toLowerCase().trim();
};

lessThan.autoRemove = function (val) {
  return !val;
};

var between = function between(row, id, filterValues) {
  return (['', undefined].includes(filterValues[0]) || greaterThan(row, id, filterValues[0])) && (!isNaN(+filterValues[0]) && !isNaN(+filterValues[1]) && +filterValues[0] > +filterValues[1] || ['', undefined].includes(filterValues[1]) || lessThan(row, id, filterValues[1]));
};

between.autoRemove = function (val) {
  return !val;
};

var empty = function empty(row, id, _filterValue) {
  return !row.getValue(id).toString().trim();
};

empty.autoRemove = function (val) {
  return !val;
};

var notEmpty = function notEmpty(row, id, _filterValue) {
  return !!row.getValue(id).toString().trim();
};

notEmpty.autoRemove = function (val) {
  return !val;
};

var defaultFilterFNs = {
  between: between,
  contains: contains,
  empty: empty,
  endsWith: endsWith,
  equals: equals,
  fuzzy: fuzzy,
  greaterThan: greaterThan,
  lessThan: lessThan,
  notEmpty: notEmpty,
  notEquals: notEquals,
  startsWith: startsWith
};

var commonMenuItemStyles = {
  py: '6px',
  my: 0,
  alignItems: 'center'
};
var MRT_FilterOptionMenu = function MRT_FilterOptionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      onSelect = _ref.onSelect,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enabledGlobalFilterOptions = _tableInstance$option.enabledGlobalFilterOptions,
      localization = _tableInstance$option.localization,
      setCurrentFilterFns = tableInstance.setCurrentFilterFns,
      setCurrentGlobalFilterFn = tableInstance.setCurrentGlobalFilterFn;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      currentFilterFns = _getState.currentFilterFns,
      currentGlobalFilterFn = _getState.currentGlobalFilterFn;

  var _ref2 = header != null ? header : {},
      column = _ref2.column;

  var _ref3 = column != null ? column : {},
      columnDef = _ref3.columnDef;

  var filterOptions = useMemo(function () {
    return [{
      option: MRT_FILTER_OPTION.FUZZY,
      label: localization.filterFuzzy,
      divider: false,
      fn: fuzzy
    }, {
      option: MRT_FILTER_OPTION.CONTAINS,
      label: localization.filterContains,
      divider: false,
      fn: contains
    }, {
      option: MRT_FILTER_OPTION.STARTS_WITH,
      label: localization.filterStartsWith,
      divider: false,
      fn: startsWith
    }, {
      option: MRT_FILTER_OPTION.ENDS_WITH,
      label: localization.filterEndsWith,
      divider: true,
      fn: endsWith
    }, {
      option: MRT_FILTER_OPTION.EQUALS,
      label: localization.filterEquals,
      divider: false,
      fn: equals
    }, {
      option: MRT_FILTER_OPTION.NOT_EQUALS,
      label: localization.filterNotEquals,
      divider: true,
      fn: notEquals
    }, {
      option: MRT_FILTER_OPTION.BETWEEN,
      label: localization.filterBetween,
      divider: false,
      fn: between
    }, {
      option: MRT_FILTER_OPTION.GREATER_THAN,
      label: localization.filterGreaterThan,
      divider: false,
      fn: greaterThan
    }, {
      option: MRT_FILTER_OPTION.LESS_THAN,
      label: localization.filterLessThan,
      divider: true,
      fn: lessThan
    }, {
      option: MRT_FILTER_OPTION.EMPTY,
      label: localization.filterEmpty,
      divider: false,
      fn: empty
    }, {
      option: MRT_FILTER_OPTION.NOT_EMPTY,
      label: localization.filterNotEmpty,
      divider: false,
      fn: notEmpty
    }].filter(function (filterType) {
      return columnDef ? !columnDef.enabledColumnFilterOptions || columnDef.enabledColumnFilterOptions.includes(filterType.option) : (!enabledGlobalFilterOptions || enabledGlobalFilterOptions.includes(filterType.option)) && [MRT_FILTER_OPTION.FUZZY, MRT_FILTER_OPTION.CONTAINS].includes(filterType.option);
    });
  }, []);

  var handleSelectFilterType = function handleSelectFilterType(value) {
    if (header && column) {
      setCurrentFilterFns(function (prev) {
        var _extends2;

        return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = value, _extends2));
      });

      if ([MRT_FILTER_OPTION.EMPTY, MRT_FILTER_OPTION.NOT_EMPTY].includes(value)) {
        column.setFilterValue(' ');
      } else if (value === MRT_FILTER_OPTION.BETWEEN) {
        column.setFilterValue(['', '']);
      } else {
        column.setFilterValue('');
      }
    } else {
      setCurrentGlobalFilterFn(value);
    }

    setAnchorEl(null);
    onSelect == null ? void 0 : onSelect();
  };

  var filterOption = !!header ? currentFilterFns[header.id] : currentGlobalFilterFn;
  return React.createElement(Menu, {
    anchorEl: anchorEl,
    anchorOrigin: {
      vertical: 'center',
      horizontal: 'right'
    },
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    open: !!anchorEl,
    MenuListProps: {
      dense: isDensePadding
    }
  }, filterOptions.map(function (_ref4, index) {
    var option = _ref4.option,
        label = _ref4.label,
        divider = _ref4.divider,
        fn = _ref4.fn;
    return React.createElement(MenuItem, {
      divider: divider,
      key: index,
      onClick: function onClick() {
        return handleSelectFilterType(option);
      },
      selected: option === filterOption || fn === filterOption,
      sx: commonMenuItemStyles,
      value: option
    }, label);
  }));
};

var MRT_ColumnPinningButtons = function MRT_ColumnPinningButtons(_ref) {
  var column = _ref.column,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      PushPinIcon = _tableInstance$option.icons.PushPinIcon,
      localization = _tableInstance$option.localization;

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
  };

  return React.createElement(Box, {
    sx: {
      minWidth: '70px',
      textAlign: 'center'
    }
  }, column.getIsPinned() ? React.createElement(Tooltip, {
    arrow: true,
    title: localization.unpin
  }, React.createElement(IconButton, {
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    size: "small"
  }, React.createElement(PushPinIcon, null))) : React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    title: localization.pinToLeft
  }, React.createElement(IconButton, {
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    size: "small"
  }, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  }))), React.createElement(Tooltip, {
    arrow: true,
    title: localization.pinToRight
  }, React.createElement(IconButton, {
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    size: "small"
  }, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })))));
};

var MRT_GrabHandleButton = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      DragHandleIcon = _tableInstance$option.icons.DragHandleIcon,
      localization = _tableInstance$option.localization;
  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.grab
  }, React.createElement(IconButton, {
    disableRipple: true,
    ref: ref,
    size: "small",
    sx: {
      cursor: 'grab',
      m: 0,
      opacity: 0.5,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 1
      },
      '&:active': {
        cursor: 'grabbing'
      }
    }
  }, React.createElement(DragHandleIcon, null)));
});

var getAllLeafColumnDefs = function getAllLeafColumnDefs(columns) {
  var lowestLevelColumns = columns;
  var currentCols = columns;

  while (!!((_currentCols = currentCols) != null && _currentCols.length) && currentCols.some(function (col) {
    return col.columns;
  })) {
    var _currentCols;

    var nextCols = currentCols.filter(function (col) {
      return !!col.columns;
    }).map(function (col) {
      return col.columns;
    }).flat();

    if (nextCols.every(function (col) {
      return !(col != null && col.columns);
    })) {
      lowestLevelColumns = [].concat(lowestLevelColumns, nextCols);
    }

    currentCols = nextCols;
  }

  return lowestLevelColumns.filter(function (col) {
    return !col.columns;
  });
};
var createGroup = function createGroup(table, column, currentFilterFns) {
  var _column$columns;

  return table.createGroup(_extends({}, column, {
    columns: column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.map == null ? void 0 : _column$columns.map(function (col) {
      return col.columns ? createGroup(table, col, currentFilterFns) : createDataColumn(table, col, currentFilterFns);
    })
  }));
};
var createDataColumn = function createDataColumn(table, column, currentFilterFns) {
  return (// @ts-ignore
    table.createDataColumn(column.id, _extends({
      filterFn: currentFilterFns[column.id] instanceof Function ? currentFilterFns[column.id] : defaultFilterFNs[currentFilterFns[column.id]]
    }, column))
  );
};
var createDisplayColumn = function createDisplayColumn(table, column) {
  return table.createDisplayColumn(column);
};
var reorderColumn = function reorderColumn(movingColumn, receivingColumn, columnOrder, setColumnOrder) {
  if (movingColumn.getCanPin()) {
    movingColumn.pin(receivingColumn.getIsPinned());
  }

  columnOrder.splice(columnOrder.indexOf(receivingColumn.id), 0, columnOrder.splice(columnOrder.indexOf(movingColumn.id), 1)[0]);
  setColumnOrder([].concat(columnOrder));
};

var MRT_ShowHideColumnsMenuItems = function MRT_ShowHideColumnsMenuItems(_ref) {
  var _column$columns2;

  var allColumns = _ref.allColumns,
      column = _ref.column,
      isSubMenu = _ref.isSubMenu,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      onMrtToggleColumnVisibility = _tableInstance$option.onMrtToggleColumnVisibility,
      setColumnOrder = tableInstance.setColumnOrder;

  var _getState = getState(),
      columnOrder = _getState.columnOrder,
      columnVisibility = _getState.columnVisibility;

  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var _useDrag = useDrag({
    collect: function collect(monitor) {
      return {
        isDragging: monitor.isDragging()
      };
    },
    item: function item() {
      return column;
    },
    type: 'column'
  }),
      dragRef = _useDrag[1],
      previewRef = _useDrag[2];

  var switchChecked = columnDefType !== 'group' && column.getIsVisible() || columnDefType === 'group' && column.getLeafColumns().some(function (col) {
    return col.getIsVisible();
  });

  var handleToggleColumnHidden = function handleToggleColumnHidden(column) {
    if (columnDefType === 'group') {
      var _column$columns;

      column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.forEach == null ? void 0 : _column$columns.forEach(function (childColumn) {
        childColumn.toggleVisibility(!switchChecked);
      });
    } else {
      column.toggleVisibility();
    }

    onMrtToggleColumnVisibility == null ? void 0 : onMrtToggleColumnVisibility({
      column: column,
      columnVisibility: columnVisibility,
      tableInstance: tableInstance
    });
  };

  return React.createElement(React.Fragment, null, React.createElement(MenuItem, {
    ref: columnDefType === 'data' ? dropRef : undefined,
    sx: {
      alignItems: 'center',
      justifyContent: 'flex-start',
      my: 0,
      pl: (column.depth + 0.5) * 2 + "rem",
      py: '6px'
    }
  }, React.createElement(Box, {
    ref: previewRef,
    sx: {
      display: 'flex',
      flexWrap: 'nowrap',
      gap: '8px'
    }
  }, columnDefType !== 'group' && enableColumnOrdering && columnDef.enableColumnOrdering !== false && !allColumns.some(function (col) {
    return col.columnDefType === 'group';
  }) && React.createElement(MRT_GrabHandleButton, {
    ref: dragRef,
    tableInstance: tableInstance
  }), !isSubMenu && column.getCanPin() && React.createElement(MRT_ColumnPinningButtons, {
    column: column,
    tableInstance: tableInstance
  }), React.createElement(FormControlLabel, {
    componentsProps: {
      typography: {
        sx: {
          mb: 0,
          opacity: columnDefType !== 'display' ? 1 : 0.5
        }
      }
    },
    checked: switchChecked,
    control: React.createElement(Switch, null),
    disabled: isSubMenu && switchChecked || !column.getCanHide() || column.getIsGrouped(),
    label: columnDef.header,
    onChange: function onChange() {
      return handleToggleColumnHidden(column);
    }
  }))), (_column$columns2 = column.columns) == null ? void 0 : _column$columns2.map(function (c, i) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      key: i + "-" + c.id,
      column: c,
      isSubMenu: isSubMenu,
      tableInstance: tableInstance
    });
  }));
};

var MRT_ShowHideColumnsMenu = function MRT_ShowHideColumnsMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      isSubMenu = _ref.isSubMenu,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getAllColumns = tableInstance.getAllColumns,
      getAllLeafColumns = tableInstance.getAllLeafColumns,
      getCenterLeafColumns = tableInstance.getCenterLeafColumns,
      getIsAllColumnsVisible = tableInstance.getIsAllColumnsVisible,
      getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      getIsSomeColumnsVisible = tableInstance.getIsSomeColumnsVisible,
      getLeftLeafColumns = tableInstance.getLeftLeafColumns,
      getRightLeafColumns = tableInstance.getRightLeafColumns,
      getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      enablePinning = _tableInstance$option.enablePinning,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      columnOrder = _getState.columnOrder,
      columnPinning = _getState.columnPinning;

  var hideAllColumns = function hideAllColumns() {
    getAllLeafColumns().filter(function (col) {
      return col.columnDef.enableHiding !== false;
    }).forEach(function (col) {
      return col.toggleVisibility(false);
    });
  };

  var allColumns = useMemo(function () {
    var columns = getAllColumns();

    if (columnOrder.length > 0 && !columns.some(function (col) {
      return col.columnDefType === 'group';
    })) {
      return [].concat(getLeftLeafColumns(), Array.from(new Set(columnOrder)).map(function (colId) {
        return getCenterLeafColumns().find(function (col) {
          return (col == null ? void 0 : col.id) === colId;
        });
      }), getRightLeafColumns()).filter(Boolean);
    }

    return columns;
  }, [columnOrder, columnPinning, getAllColumns(), getCenterLeafColumns(), getLeftLeafColumns(), getRightLeafColumns()]);
  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: isSubMenu ? 'center' : 'space-between',
      p: '0.5rem',
      pt: 0
    }
  }, !isSubMenu && React.createElement(Button, {
    disabled: !getIsSomeColumnsVisible(),
    onClick: hideAllColumns
  }, localization.hideAll), !isSubMenu && enableColumnOrdering && React.createElement(Button, {
    onClick: function onClick() {
      return tableInstance.resetColumnOrder();
    }
  }, localization.resetOrder), !isSubMenu && enablePinning && React.createElement(Button, {
    disabled: !getIsSomeColumnsPinned(),
    onClick: function onClick() {
      return tableInstance.resetColumnPinning(true);
    }
  }, localization.unpinAll), React.createElement(Button, {
    disabled: getIsAllColumnsVisible(),
    onClick: function onClick() {
      return toggleAllColumnsVisible(true);
    }
  }, localization.showAll)), React.createElement(Divider, null), allColumns.map(function (column, index) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      column: column,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id,
      tableInstance: tableInstance
    });
  }));
};

var commonMenuItemStyles$1 = {
  py: '6px',
  my: 0,
  justifyContent: 'space-between',
  alignItems: 'center'
};
var commonListItemStyles = {
  display: 'flex',
  alignItems: 'center'
};
var MRT_ColumnActionMenu = function MRT_ColumnActionMenu(_ref) {
  var _localization$sortByC, _localization$sortByC2, _localization$filterB, _localization, _localization$hideCol, _localization$showAll;

  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      setColumnOrder = tableInstance.setColumnOrder,
      _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableGrouping = _tableInstance$option.enableGrouping,
      enableHiding = _tableInstance$option.enableHiding,
      enablePinning = _tableInstance$option.enablePinning,
      enableSorting = _tableInstance$option.enableSorting,
      _tableInstance$option2 = _tableInstance$option.icons,
      ArrowRightIcon = _tableInstance$option2.ArrowRightIcon,
      ClearAllIcon = _tableInstance$option2.ClearAllIcon,
      ViewColumnIcon = _tableInstance$option2.ViewColumnIcon,
      DynamicFeedIcon = _tableInstance$option2.DynamicFeedIcon,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      PushPinIcon = _tableInstance$option2.PushPinIcon,
      SortIcon = _tableInstance$option2.SortIcon,
      RestartAltIcon = _tableInstance$option2.RestartAltIcon,
      VisibilityOffIcon = _tableInstance$option2.VisibilityOffIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      setShowFilters = tableInstance.setShowFilters;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      columnSizing = _getState.columnSizing,
      columnVisibility = _getState.columnVisibility,
      isDensePadding = _getState.isDensePadding;

  var _useState = useState(null),
      filterMenuAnchorEl = _useState[0],
      setFilterMenuAnchorEl = _useState[1];

  var _useState2 = useState(null),
      showHideColumnsMenuAnchorEl = _useState2[0],
      setShowHideColumnsMenuAnchorEl = _useState2[1];

  var handleClearSort = function handleClearSort() {
    column.clearSorting();
    setAnchorEl(null);
  };

  var handleSortAsc = function handleSortAsc() {
    column.toggleSorting(false);
    setAnchorEl(null);
  };

  var handleSortDesc = function handleSortDesc() {
    column.toggleSorting(true);
    setAnchorEl(null);
  };

  var handleResetColumnSize = function handleResetColumnSize() {
    column.resetSize();
    setAnchorEl(null);
  };

  var handleHideColumn = function handleHideColumn() {
    column.toggleVisibility(false);
    setAnchorEl(null);
  };

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
    setAnchorEl(null);
  };

  var handleGroupByColumn = function handleGroupByColumn() {
    column.toggleGrouping();
    setColumnOrder(function (old) {
      return ['mrt-expand'].concat(old);
    });
    setAnchorEl(null);
  };

  var handleClearFilter = function handleClearFilter() {
    column.setFilterValue('');
    setAnchorEl(null);
  };

  var handleFilterByColumn = function handleFilterByColumn() {
    setShowFilters(true);
    setTimeout(function () {
      var _document$getElementB, _header$muiTableHeadC, _header$muiTableHeadC2;

      return (_document$getElementB = document.getElementById( // @ts-ignore
      (_header$muiTableHeadC = (_header$muiTableHeadC2 = header.muiTableHeadCellFilterTextFieldProps) == null ? void 0 : _header$muiTableHeadC2.id) != null ? _header$muiTableHeadC : "mrt-" + tableId + "-" + header.id + "-filter-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
    setAnchorEl(null);
  };

  var handleShowAllColumns = function handleShowAllColumns() {
    toggleAllColumnsVisible(true);
    setAnchorEl(null);
  };

  var handleOpenFilterModeMenu = function handleOpenFilterModeMenu(event) {
    event.stopPropagation();
    setFilterMenuAnchorEl(event.currentTarget);
  };

  var handleOpenShowHideColumnsMenu = function handleOpenShowHideColumnsMenu(event) {
    event.stopPropagation();
    setShowHideColumnsMenuAnchorEl(event.currentTarget);
  };

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableSorting && column.getCanSort() && [React.createElement(MenuItem, {
    disabled: !column.getIsSorted(),
    key: 0,
    onClick: handleClearSort,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ClearAllIcon, null)), localization.clearSort)), React.createElement(MenuItem, {
    disabled: column.getIsSorted() === 'asc',
    key: 1,
    onClick: handleSortAsc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, null)), (_localization$sortByC = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC.replace('{column}', String(columnDef.header)))), React.createElement(MenuItem, {
    divider: enableColumnFilters || enableGrouping || enableHiding,
    key: 2,
    disabled: column.getIsSorted() === 'desc',
    onClick: handleSortDesc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, {
    style: {
      transform: 'rotate(180deg) scaleX(-1)'
    }
  })), (_localization$sortByC2 = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC2.replace('{column}', String(columnDef.header))))], enableColumnFilters && column.getCanFilter() && [React.createElement(MenuItem, {
    disabled: !column.getFilterValue(),
    key: 0,
    onClick: handleClearFilter,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListOffIcon, null)), localization.clearFilter)), React.createElement(MenuItem, {
    divider: enableGrouping || enableHiding,
    key: 1,
    onClick: handleFilterByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListIcon, null)), (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header))), !columnDef.filterSelectOptions && React.createElement(IconButton, {
    onClick: handleOpenFilterModeMenu,
    onMouseEnter: handleOpenFilterModeMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_FilterOptionMenu, {
    anchorEl: filterMenuAnchorEl,
    header: header,
    key: 2,
    onSelect: handleFilterByColumn,
    setAnchorEl: setFilterMenuAnchorEl,
    tableInstance: tableInstance
  })], enableGrouping && column.getCanGroup() && [React.createElement(MenuItem, {
    divider: enablePinning,
    key: 0,
    onClick: handleGroupByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(DynamicFeedIcon, null)), (_localization = localization[column.getIsGrouped() ? 'ungroupByColumn' : 'groupByColumn']) == null ? void 0 : _localization.replace('{column}', String(columnDef.header))))], enablePinning && column.getCanPin() && [React.createElement(MenuItem, {
    disabled: column.getIsPinned() === 'left' || !column.getCanPin(),
    key: 0,
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  })), localization.pinToLeft)), React.createElement(MenuItem, {
    disabled: column.getIsPinned() === 'right' || !column.getCanPin(),
    key: 1,
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })), localization.pinToRight)), React.createElement(MenuItem, {
    disabled: !column.getIsPinned(),
    divider: enableHiding,
    key: 2,
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, null)), localization.unpin))], enableColumnResizing && [React.createElement(MenuItem, {
    disabled: !column.getCanResize() || !columnSizing[column.id],
    key: 0,
    onClick: handleResetColumnSize,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(RestartAltIcon, null)), localization.resetColumnSize))], enableHiding && [React.createElement(MenuItem, {
    disabled: columnDef.enableHiding === false,
    key: 0,
    onClick: handleHideColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(VisibilityOffIcon, null)), (_localization$hideCol = localization.hideColumn) == null ? void 0 : _localization$hideCol.replace('{column}', String(columnDef.header)))), React.createElement(MenuItem, {
    disabled: !Object.values(columnVisibility).filter(function (visible) {
      return !visible;
    }).length,
    key: 1,
    onClick: handleShowAllColumns,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ViewColumnIcon, null)), (_localization$showAll = localization.showAllColumns) == null ? void 0 : _localization$showAll.replace('{column}', String(columnDef.header))), React.createElement(IconButton, {
    onClick: handleOpenShowHideColumnsMenu,
    onMouseEnter: handleOpenShowHideColumnsMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: showHideColumnsMenuAnchorEl,
    isSubMenu: true,
    key: 2,
    setAnchorEl: setShowHideColumnsMenuAnchorEl,
    tableInstance: tableInstance
  })]);
};

var MRT_RowActionMenu = function MRT_RowActionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      handleEdit = _ref.handleEdit,
      row = _ref.row,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      EditIcon = _tableInstance$option.icons.EditIcon,
      enableEditing = _tableInstance$option.enableEditing,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableEditing && React.createElement(MenuItem, {
    onClick: handleEdit,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(EditIcon, null)), localization.edit)), renderRowActionMenuItems == null ? void 0 : renderRowActionMenuItems({
    row: row,
    tableInstance: tableInstance,
    closeMenu: function closeMenu() {
      return setAnchorEl(null);
    }
  }));
};

var MRT_EditActionButtons = function MRT_EditActionButtons(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      CancelIcon = _tableInstance$option2.CancelIcon,
      SaveIcon = _tableInstance$option2.SaveIcon,
      localization = _tableInstance$option.localization,
      onMrtEditRowSubmit = _tableInstance$option.onMrtEditRowSubmit,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var handleCancel = function handleCancel() {
    var _row$original;

    row._valuesCache = (_row$original = row.original) != null ? _row$original : {};
    setCurrentEditingRow(null);
  };

  var handleSave = function handleSave() {
    onMrtEditRowSubmit == null ? void 0 : onMrtEditRowSubmit({
      row: currentEditingRow != null ? currentEditingRow : row,
      tableInstance: tableInstance
    });
    setCurrentEditingRow(null);
  };

  return React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.75rem'
    }
  }, React.createElement(Tooltip, {
    arrow: true,
    title: localization.cancel
  }, React.createElement(IconButton, {
    "aria-label": localization.cancel,
    onClick: handleCancel
  }, React.createElement(CancelIcon, null))), React.createElement(Tooltip, {
    arrow: true,
    title: localization.save
  }, React.createElement(IconButton, {
    "aria-label": localization.save,
    color: "info",
    onClick: handleSave
  }, React.createElement(SaveIcon, null))));
};

var commonIconButtonStyles = {
  height: '2rem',
  ml: '10px',
  opacity: 0.5,
  transition: 'opacity 0.2s',
  width: '2rem',
  '&:hover': {
    opacity: 1
  }
};
var MRT_ToggleRowActionMenuButton = function MRT_ToggleRowActionMenuButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableEditing = _tableInstance$option.enableEditing,
      _tableInstance$option2 = _tableInstance$option.icons,
      EditIcon = _tableInstance$option2.EditIcon,
      MoreHorizIcon = _tableInstance$option2.MoreHorizIcon,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems,
      renderRowActions = _tableInstance$option.renderRowActions,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleOpenRowActionMenu = function handleOpenRowActionMenu(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var handleStartEditMode = function handleStartEditMode() {
    setCurrentEditingRow(_extends({}, row));
    setAnchorEl(null);
  };

  return React.createElement(React.Fragment, null, renderRowActions ? React.createElement(React.Fragment, null, renderRowActions({
    row: row,
    tableInstance: tableInstance
  })) : row.id === (currentEditingRow == null ? void 0 : currentEditingRow.id) ? React.createElement(MRT_EditActionButtons, {
    row: row,
    tableInstance: tableInstance
  }) : !renderRowActionMenuItems && enableEditing ? React.createElement(Tooltip, {
    placement: "right",
    arrow: true,
    title: localization.edit
  }, React.createElement(IconButton, {
    sx: commonIconButtonStyles,
    onClick: handleStartEditMode
  }, React.createElement(EditIcon, null))) : renderRowActionMenuItems ? React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.rowActions
  }, React.createElement(IconButton, {
    "aria-label": localization.rowActions,
    onClick: handleOpenRowActionMenu,
    size: "small",
    sx: commonIconButtonStyles
  }, React.createElement(MoreHorizIcon, null))), React.createElement(MRT_RowActionMenu, {
    anchorEl: anchorEl,
    handleEdit: handleStartEditMode,
    row: row,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  })) : null);
};

var MRT_SelectCheckbox = function MRT_SelectCheckbox(_ref) {
  var row = _ref.row,
      selectAll = _ref.selectAll,
      tableInstance = _ref.tableInstance;
  var getRowModel = tableInstance.getRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiSelectCheckboxProps = _tableInstance$option.muiSelectCheckboxProps,
      onMrtSelectRowChange = _tableInstance$option.onMrtSelectRowChange,
      onMrtSelectAllChange = _tableInstance$option.onMrtSelectAllChange,
      selectAllMode = _tableInstance$option.selectAllMode;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleSelectChange = function handleSelectChange(event) {
    if (selectAll) {
      if (selectAllMode === 'all') {
        tableInstance.getToggleAllRowsSelectedHandler()(event);
      } else if (selectAllMode === 'page') {
        tableInstance.getToggleAllPageRowsSelectedHandler()(event);
      }

      onMrtSelectAllChange == null ? void 0 : onMrtSelectAllChange({
        event: event,
        selectedRows: event.target.checked ? getRowModel().flatRows : [],
        tableInstance: tableInstance
      });
    } else if (row) {
      row == null ? void 0 : row.getToggleSelectedHandler()(event);
      onMrtSelectRowChange == null ? void 0 : onMrtSelectRowChange({
        event: event,
        row: row,
        selectedRows: event.target.checked ? [].concat(getSelectedRowModel().flatRows, [row]) : getSelectedRowModel().flatRows.filter(function (selectedRow) {
          return selectedRow.id !== row.id;
        }),
        tableInstance: tableInstance
      });
    }
  };

  var checkboxProps = muiSelectCheckboxProps instanceof Function ? muiSelectCheckboxProps({
    isSelectAll: !!selectAll,
    row: row,
    tableInstance: tableInstance
  }) : muiSelectCheckboxProps;
  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
  }, React.createElement(Checkbox, Object.assign({
    checked: selectAll ? tableInstance.getIsAllRowsSelected() : row == null ? void 0 : row.getIsSelected(),
    indeterminate: selectAll ? tableInstance.getIsSomeRowsSelected() : row == null ? void 0 : row.getIsSomeSelected(),
    inputProps: {
      'aria-label': selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
    },
    onChange: handleSelectChange,
    size: isDensePadding ? 'small' : 'medium'
  }, checkboxProps, {
    sx: _extends({
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }, checkboxProps == null ? void 0 : checkboxProps.sx)
  })));
};

var _excluded = ["tableInstance"];
var MRT_FullScreenToggleButton = function MRT_FullScreenToggleButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FullscreenExitIcon = _tableInstance$option2.FullscreenExitIcon,
      FullscreenIcon = _tableInstance$option2.FullscreenIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleFullScreen = _tableInstance$option.onMrtToggleFullScreen,
      setIsFullScreen = tableInstance.setIsFullScreen;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var handleToggleFullScreen = function handleToggleFullScreen(event) {
    onMrtToggleFullScreen == null ? void 0 : onMrtToggleFullScreen({
      event: event,
      isFullScreen: !isFullScreen,
      tableInstance: tableInstance
    });
    setIsFullScreen(!isFullScreen);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleFullScreen
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleFullScreen
  }, rest), isFullScreen ? React.createElement(FullscreenExitIcon, null) : React.createElement(FullscreenIcon, null)));
};

var _excluded$1 = ["tableInstance"];
var MRT_ShowHideColumnsButton = function MRT_ShowHideColumnsButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _tableInstance$option = tableInstance.options,
      ViewColumnIcon = _tableInstance$option.icons.ViewColumnIcon,
      localization = _tableInstance$option.localization;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideColumns
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideColumns,
    onClick: handleClick
  }, rest), React.createElement(ViewColumnIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var _excluded$2 = ["tableInstance"];
var MRT_ToggleDensePaddingButton = function MRT_ToggleDensePaddingButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      DensityMediumIcon = _tableInstance$option2.DensityMediumIcon,
      DensitySmallIcon = _tableInstance$option2.DensitySmallIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleDensePadding = _tableInstance$option.onMrtToggleDensePadding,
      setIsDensePadding = tableInstance.setIsDensePadding;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleToggleDensePadding = function handleToggleDensePadding(event) {
    onMrtToggleDensePadding == null ? void 0 : onMrtToggleDensePadding({
      event: event,
      isDensePadding: !isDensePadding,
      tableInstance: tableInstance
    });
    setIsDensePadding(!isDensePadding);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleDensePadding
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.toggleDensePadding,
    onClick: handleToggleDensePadding
  }, rest), isDensePadding ? React.createElement(DensitySmallIcon, null) : React.createElement(DensityMediumIcon, null)));
};

var _excluded$3 = ["tableInstance"];
var MRT_ToggleFiltersButton = function MRT_ToggleFiltersButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$3);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleShowFilters = _tableInstance$option.onMrtToggleShowFilters,
      setShowFilters = tableInstance.setShowFilters;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var handleToggleShowFilters = function handleToggleShowFilters(event) {
    onMrtToggleShowFilters == null ? void 0 : onMrtToggleShowFilters({
      event: event,
      showFilters: !showFilters,
      tableInstance: tableInstance
    });
    setShowFilters(!showFilters);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideFilters
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleShowFilters
  }, rest), showFilters ? React.createElement(FilterListOffIcon, null) : React.createElement(FilterListIcon, null)));
};

var _excluded$4 = ["tableInstance"];
var MRT_ToggleGlobalFilterButton = function MRT_ToggleGlobalFilterButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$4);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      SearchOffIcon = _tableInstance$option2.SearchOffIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      onMrtToggleShowGlobalFilter = _tableInstance$option.onMrtToggleShowGlobalFilter,
      setShowGlobalFilter = tableInstance.setShowGlobalFilter;

  var _getState = getState(),
      showGlobalFilter = _getState.showGlobalFilter;

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;

  var handleToggleSearch = function handleToggleSearch(event) {
    onMrtToggleShowGlobalFilter == null ? void 0 : onMrtToggleShowGlobalFilter({
      event: event,
      showGlobalFilter: !showGlobalFilter,
      tableInstance: tableInstance
    });
    setShowGlobalFilter(!showGlobalFilter);
    setTimeout(function () {
      var _document$getElementB, _textFieldProps$id;

      return (_document$getElementB = document.getElementById((_textFieldProps$id = textFieldProps == null ? void 0 : textFieldProps.id) != null ? _textFieldProps$id : "mrt-" + tableId + "-search-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideSearch
  }, React.createElement(IconButton, Object.assign({
    onClick: handleToggleSearch
  }, rest), showGlobalFilter ? React.createElement(SearchOffIcon, null) : React.createElement(SearchIcon, null)));
};

var MRT_SearchTextField = function MRT_SearchTextField(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      setGlobalFilter = tableInstance.setGlobalFilter,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      onMrtGlobalFilterValueChange = _tableInstance$option.onMrtGlobalFilterValueChange;

  var _getState = getState(),
      globalFilter = _getState.globalFilter,
      showGlobalFilter = _getState.showGlobalFilter;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var _useState2 = useState(globalFilter != null ? globalFilter : ''),
      searchValue = _useState2[0],
      setSearchValue = _useState2[1];

  var handleChange = useCallback(debounce(function (event) {
    var _event$target$value;

    setGlobalFilter((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
    onMrtGlobalFilterValueChange == null ? void 0 : onMrtGlobalFilterValueChange({
      event: event,
      tableInstance: tableInstance
    });
  }, 200), []);

  var handleGlobalFilterMenuOpen = function handleGlobalFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setSearchValue('');
    setGlobalFilter(undefined);
  };

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;
  return React.createElement(Collapse, {
    "in": showGlobalFilter,
    orientation: "horizontal"
  }, React.createElement(TextField, Object.assign({
    id: "mrt-" + tableId + "-search-text-field",
    placeholder: localization.search,
    onChange: function onChange(event) {
      setSearchValue(event.target.value);
      handleChange(event);
    },
    value: searchValue != null ? searchValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(Tooltip, {
        arrow: true,
        title: localization.changeSearchMode
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.changeSearchMode,
        onClick: handleGlobalFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(SearchIcon, null))))),
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, {
        "aria-label": localization.clearSearch,
        disabled: (searchValue == null ? void 0 : searchValue.length) === 0,
        onClick: handleClear,
        size: "small",
        title: localization.clearSearch
      }, React.createElement(CloseIcon, null)))
    }
  }, textFieldProps, {
    sx: _extends({
      justifySelf: 'end'
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  })), React.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_ToolbarInternalButtons = function MRT_ToolbarInternalButtons(_ref) {
  var _renderToolbarInterna;

  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableDensePaddingToggle = _tableInstance$option.enableDensePaddingToggle,
      enableFilters = _tableInstance$option.enableFilters,
      enableFullScreenToggle = _tableInstance$option.enableFullScreenToggle,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enableHiding = _tableInstance$option.enableHiding,
      positionGlobalFilter = _tableInstance$option.positionGlobalFilter,
      renderToolbarInternalActions = _tableInstance$option.renderToolbarInternalActions;
  return React.createElement(Box, {
    sx: {
      display: 'flex',
      alignItems: 'center',
      zIndex: 3
    }
  }, (_renderToolbarInterna = renderToolbarInternalActions == null ? void 0 : renderToolbarInternalActions({
    MRT_FullScreenToggleButton: MRT_FullScreenToggleButton,
    MRT_ShowHideColumnsButton: MRT_ShowHideColumnsButton,
    MRT_ToggleDensePaddingButton: MRT_ToggleDensePaddingButton,
    MRT_ToggleFiltersButton: MRT_ToggleFiltersButton,
    MRT_ToggleGlobalFilterButton: MRT_ToggleGlobalFilterButton,
    tableInstance: tableInstance
  })) != null ? _renderToolbarInterna : React.createElement(React.Fragment, null, enableGlobalFilter && positionGlobalFilter === 'right' && React.createElement(MRT_SearchTextField, {
    tableInstance: tableInstance
  }), enableFilters && enableGlobalFilter && React.createElement(MRT_ToggleGlobalFilterButton, {
    tableInstance: tableInstance
  }), enableFilters && enableColumnFilters && React.createElement(MRT_ToggleFiltersButton, {
    tableInstance: tableInstance
  }), enableHiding && React.createElement(MRT_ShowHideColumnsButton, {
    tableInstance: tableInstance
  }), enableDensePaddingToggle && React.createElement(MRT_ToggleDensePaddingButton, {
    tableInstance: tableInstance
  }), enableFullScreenToggle && React.createElement(MRT_FullScreenToggleButton, {
    tableInstance: tableInstance
  })));
};

var MRT_TablePagination = function MRT_TablePagination(_ref) {
  var tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getState = tableInstance.getState,
      setPageIndex = tableInstance.setPageIndex,
      setPageSize = tableInstance.setPageSize,
      muiTablePaginationProps = tableInstance.options.muiTablePaginationProps;

  var _getState = getState(),
      _getState$pagination = _getState.pagination,
      _getState$pagination$ = _getState$pagination.pageSize,
      pageSize = _getState$pagination$ === void 0 ? 10 : _getState$pagination$,
      _getState$pagination$2 = _getState$pagination.pageIndex,
      pageIndex = _getState$pagination$2 === void 0 ? 0 : _getState$pagination$2;

  var tablePaginationProps = muiTablePaginationProps instanceof Function ? muiTablePaginationProps({
    tableInstance: tableInstance
  }) : muiTablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    setPageSize(+event.target.value);
  };

  var showFirstLastPageButtons = getPrePaginationRowModel().rows.length / pageSize > 2;
  return React.createElement(TablePagination, Object.assign({
    SelectProps: {
      sx: {
        m: '0 1rem 0 1ch'
      },
      MenuProps: {
        MenuListProps: {
          disablePadding: true
        }
      }
    },
    component: "div",
    count: getPrePaginationRowModel().rows.length,
    onPageChange: function onPageChange(_, newPage) {
      return setPageIndex(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: pageIndex,
    rowsPerPage: pageSize,
    rowsPerPageOptions: [5, 10, 15, 20, 25, 30, 50, 100],
    showFirstButton: showFirstLastPageButtons,
    showLastButton: showFirstLastPageButtons
  }, tablePaginationProps, {
    sx: _extends({
      m: '0 0.5rem',
      position: 'relative',
      zIndex: 2
    }, tablePaginationProps == null ? void 0 : tablePaginationProps.sx)
  }));
};

var MRT_ToolbarAlertBanner = function MRT_ToolbarAlertBanner(_ref) {
  var _localization$selecte, _localization$selecte2;

  var stackAlertBanner = _ref.stackAlertBanner,
      tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableToolbarAlertBannerProps = _tableInstance$option.muiTableToolbarAlertBannerProps;

  var _getState = getState(),
      grouping = _getState.grouping;

  var alertProps = muiTableToolbarAlertBannerProps instanceof Function ? muiTableToolbarAlertBannerProps({
    tableInstance: tableInstance
  }) : muiTableToolbarAlertBannerProps;
  var selectMessage = getSelectedRowModel().rows.length > 0 ? (_localization$selecte = localization.selectedCountOfRowCountRowsSelected) == null ? void 0 : (_localization$selecte2 = _localization$selecte.replace('{selectedCount}', getSelectedRowModel().rows.length.toString())) == null ? void 0 : _localization$selecte2.replace('{rowCount}', getPrePaginationRowModel().rows.length.toString()) : null;
  var groupedByMessage = grouping.length > 0 ? React.createElement("span", null, localization.groupedBy, ' ', grouping.map(function (columnId, index) {
    return React.createElement(Fragment, {
      key: index + "-" + columnId
    }, index > 0 ? localization.thenBy : '', React.createElement(Chip, {
      color: "secondary",
      label: tableInstance.getColumn(columnId).columnDef.header,
      onDelete: function onDelete() {
        return tableInstance.getColumn(columnId).toggleGrouping();
      }
    }));
  })) : null;
  return React.createElement(Collapse, {
    "in": !!selectMessage || !!groupedByMessage,
    timeout: stackAlertBanner ? 200 : 0
  }, React.createElement(Alert, Object.assign({
    color: "info",
    icon: false,
    sx: _extends({
      borderRadius: 0,
      fontSize: '1rem',
      left: 0,
      p: 0,
      position: 'relative',
      right: 0,
      top: 0,
      width: '100%',
      zIndex: 2
    }, alertProps == null ? void 0 : alertProps.sx)
  }, alertProps), React.createElement(Box, {
    sx: {
      p: '0.5rem 1rem'
    }
  }, selectMessage, selectMessage && groupedByMessage && React.createElement("br", null), groupedByMessage)));
};

var MRT_LinearProgressBar = function MRT_LinearProgressBar(_ref) {
  var alignTo = _ref.alignTo,
      tableInstance = _ref.tableInstance;
  var muiLinearProgressProps = tableInstance.options.muiLinearProgressProps,
      getState = tableInstance.getState;

  var _getState = getState(),
      isLoading = _getState.isLoading,
      showProgressBars = _getState.showProgressBars;

  var linearProgressProps = muiLinearProgressProps instanceof Function ? muiLinearProgressProps({
    tableInstance: tableInstance
  }) : muiLinearProgressProps;
  return React.createElement(Collapse, {
    "in": isLoading || showProgressBars,
    mountOnEnter: true,
    unmountOnExit: true,
    sx: {
      bottom: alignTo === 'bottom' ? 0 : undefined,
      position: 'absolute',
      top: alignTo === 'top' ? 0 : undefined,
      width: '100%'
    }
  }, React.createElement(LinearProgress, Object.assign({
    "aria-label": "Loading",
    "aria-busy": "true",
    sx: {
      position: 'relative'
    }
  }, linearProgressProps)));
};

var commonToolbarStyles = function commonToolbarStyles(_ref) {
  var theme = _ref.theme;
  return {
    backgroundColor: lighten(theme.palette.background["default"], 0.04),
    backgroundImage: 'none',
    display: 'grid',
    minHeight: '3.5rem',
    overflow: 'hidden',
    p: '0 !important',
    transition: 'all 0.2s ease-in-out',
    width: '100%',
    zIndex: 1
  };
};
var MRT_ToolbarTop = function MRT_ToolbarTop(_ref2) {
  var _renderToolbarCustomA;

  var tableInstance = _ref2.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enablePagination = _tableInstance$option.enablePagination,
      enableToolbarInternalActions = _tableInstance$option.enableToolbarInternalActions,
      tableId = _tableInstance$option.tableId,
      muiTableToolbarTopProps = _tableInstance$option.muiTableToolbarTopProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionGlobalFilter = _tableInstance$option.positionGlobalFilter,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen,
      showGlobalFilter = _getState.showGlobalFilter;

  var isMobile = useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarTopProps instanceof Function ? muiTableToolbarTopProps({
    tableInstance: tableInstance
  }) : muiTableToolbarTopProps;
  var stackAlertBanner = isMobile || positionToolbarAlertBanner === 'top' && (!!renderToolbarCustomActions || showGlobalFilter);
  return React.createElement(Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-top",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        position: isFullScreen ? 'sticky' : undefined,
        top: isFullScreen ? '0' : undefined
      }, commonToolbarStyles({
        theme: theme
      }), toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), positionToolbarAlertBanner === 'top' && React.createElement(MRT_ToolbarAlertBanner, {
    stackAlertBanner: stackAlertBanner,
    tableInstance: tableInstance
  }), React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      p: '0.5rem',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0,
      width: renderToolbarCustomActions ? '100%' : undefined
    }
  }, enableGlobalFilter && positionGlobalFilter === 'left' && React.createElement(MRT_SearchTextField, {
    tableInstance: tableInstance
  }), (_renderToolbarCustomA = renderToolbarCustomActions == null ? void 0 : renderToolbarCustomActions({
    tableInstance: tableInstance
  })) != null ? _renderToolbarCustomA : React.createElement("span", null), enableToolbarInternalActions && positionToolbarActions === 'top' && React.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  })), React.createElement("div", null, enablePagination && ['top', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })), React.createElement(MRT_LinearProgressBar, {
    alignTo: "bottom",
    tableInstance: tableInstance
  }));
};

var MRT_ToolbarBottom = function MRT_ToolbarBottom(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableToolbarInternalActions = _tableInstance$option.enableToolbarInternalActions,
      tableId = _tableInstance$option.tableId,
      enablePagination = _tableInstance$option.enablePagination,
      muiTableToolbarBottomProps = _tableInstance$option.muiTableToolbarBottomProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var isMobile = useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarBottomProps instanceof Function ? muiTableToolbarBottomProps({
    tableInstance: tableInstance
  }) : muiTableToolbarBottomProps;
  var stackAlertBanner = isMobile || positionToolbarAlertBanner === 'bottom' && positionToolbarActions === 'bottom' || positionToolbarAlertBanner === 'bottom' && !!renderToolbarCustomActions && positionToolbarActions === 'bottom';
  return React.createElement(Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-bottom",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({}, commonToolbarStyles({
        theme: theme
      }), {
        bottom: isFullScreen ? '0' : undefined,
        boxShadow: "-3px 0 6px " + alpha(theme.palette.common.black, 0.1),
        position: isFullScreen ? 'fixed' : 'relative'
      }, toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), React.createElement(MRT_LinearProgressBar, {
    alignTo: "top",
    tableInstance: tableInstance
  }), positionToolbarAlertBanner === 'bottom' && React.createElement(MRT_ToolbarAlertBanner, {
    tableInstance: tableInstance
  }), React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      width: '100%',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0
    }
  }, enableToolbarInternalActions && positionToolbarActions === 'bottom' ? React.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  }) : React.createElement("span", null), enablePagination && ['bottom', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })));
};

var MRT_FilterTextField = function MRT_FilterTextField(_ref) {
  var _localization$filterB, _localization$filterM, _localization$, _localization$clearFi, _columnDef$filterSele;

  var header = _ref.header,
      inputIndex = _ref.inputIndex,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiTableHeadCellFilterTextFieldProps = _tableInstance$option.muiTableHeadCellFilterTextFieldProps,
      setCurrentFilterFns = tableInstance.setCurrentFilterFns;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var mTableHeadCellFilterTextFieldProps = muiTableHeadCellFilterTextFieldProps instanceof Function ? muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellFilterTextFieldProps;
  var mcTableHeadCellFilterTextFieldProps = columnDef.muiTableHeadCellFilterTextFieldProps instanceof Function ? columnDef.muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellFilterTextFieldProps;

  var textFieldProps = _extends({}, mTableHeadCellFilterTextFieldProps, mcTableHeadCellFilterTextFieldProps);

  var _useState2 = useState(function () {
    var _column$getFilterValu, _column$getFilterValu2, _column$getFilterValu3;

    return inputIndex !== undefined ? (_column$getFilterValu = (_column$getFilterValu2 = column.getFilterValue()) == null ? void 0 : _column$getFilterValu2[inputIndex]) != null ? _column$getFilterValu : '' : (_column$getFilterValu3 = column.getFilterValue()) != null ? _column$getFilterValu3 : '';
  }),
      filterValue = _useState2[0],
      setFilterValue = _useState2[1];

  var handleChangeDebounced = useCallback(debounce(function (event) {
    var _event$target$value;

    return inputIndex !== undefined ? column.setFilterValue(function (old) {
      var newFilterValues = old != null ? old : ['', ''];
      newFilterValues[inputIndex] = event.target.value;
      return newFilterValues;
    }) : column.setFilterValue((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
  }, 150), []);

  var handleFilterMenuOpen = function handleFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setFilterValue('');

    if (inputIndex !== undefined) {
      column.setFilterValue(function (old) {
        var newFilterValues = old != null ? old : ['', ''];
        newFilterValues[inputIndex] = undefined;
        return newFilterValues;
      });
    } else {
      column.setFilterValue(undefined);
    }
  };

  var handleClearFilterChip = function handleClearFilterChip() {
    setFilterValue('');
    column.setFilterValue(undefined);
    setCurrentFilterFns(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = MRT_FILTER_OPTION.FUZZY, _extends2));
    });
  };

  if (columnDef.Filter) {
    return React.createElement(React.Fragment, null, columnDef.Filter == null ? void 0 : columnDef.Filter({
      header: header,
      tableInstance: tableInstance
    }));
  }

  var filterId = "mrt-" + tableId + "-" + header.id + "-filter-text-field" + (inputIndex != null ? inputIndex : '');
  var filterFn = currentFilterFns == null ? void 0 : currentFilterFns[header.id];
  var isSelectFilter = !!columnDef.filterSelectOptions;
  var filterChipLabel = !(filterFn instanceof Function) && [MRT_FILTER_OPTION.EMPTY, MRT_FILTER_OPTION.NOT_EMPTY].includes(filterFn) ? //@ts-ignore
  localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))] : '';
  var filterPlaceholder = inputIndex === undefined ? (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header)) : inputIndex === 0 ? localization.min : inputIndex === 1 ? localization.max : '';
  return React.createElement(React.Fragment, null, React.createElement(TextField, Object.assign({
    fullWidth: true,
    id: filterId,
    inputProps: {
      disabled: !!filterChipLabel,
      sx: {
        textOverflow: 'ellipsis',
        width: filterChipLabel ? 0 : undefined
      },
      title: filterPlaceholder
    },
    helperText: !inputIndex ? React.createElement("label", {
      htmlFor: filterId
    }, filterFn instanceof Function ? (_localization$filterM = localization.filterMode.replace('{filterType}', // @ts-ignore
    (_localization$ = localization["filter" + (filterFn.name.charAt(0).toUpperCase() + filterFn.name.slice(1))]) != null ? _localization$ : '')) != null ? _localization$filterM : '' : localization.filterMode.replace('{filterType}', // @ts-ignore
    localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))])) : null,
    FormHelperTextProps: {
      sx: {
        fontSize: '0.6rem',
        lineHeight: '0.8rem',
        whiteSpace: 'nowrap'
      }
    },
    label: isSelectFilter && !filterValue ? filterPlaceholder : undefined,
    margin: "none",
    placeholder: filterChipLabel || isSelectFilter ? undefined : filterPlaceholder,
    onChange: function onChange(event) {
      setFilterValue(event.target.value);
      handleChangeDebounced(event);
    },
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    select: isSelectFilter,
    value: filterValue != null ? filterValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: !isSelectFilter && !inputIndex && React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(Tooltip, {
        arrow: true,
        title: localization.changeFilterMode
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.changeFilterMode,
        onClick: handleFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(FilterListIcon, null)))), filterChipLabel && React.createElement(Chip, {
        onDelete: handleClearFilterChip,
        label: filterChipLabel
      })),
      endAdornment: !filterChipLabel && React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(Tooltip, {
        arrow: true,
        disableHoverListener: isSelectFilter,
        placement: "right",
        title: (_localization$clearFi = localization.clearFilter) != null ? _localization$clearFi : ''
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.clearFilter,
        disabled: !(filterValue != null && filterValue.length),
        onClick: handleClear,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(CloseIcon, null)))))
    }
  }, textFieldProps, {
    sx: _extends({
      m: '-0.25rem',
      p: 0,
      minWidth: !filterChipLabel ? '8rem' : 'auto',
      width: 'calc(100% + 0.5rem)',
      mt: isSelectFilter && !filterValue ? '-1rem' : undefined,
      '&	.MuiSelect-icon': {
        mr: '1.5rem'
      }
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  }), isSelectFilter && React.createElement(MenuItem, {
    divider: true,
    disabled: !filterValue,
    value: ""
  }, localization.clearFilter), columnDef == null ? void 0 : (_columnDef$filterSele = columnDef.filterSelectOptions) == null ? void 0 : _columnDef$filterSele.map(function (option) {
    var value;
    var text;

    if (typeof option === 'string') {
      value = option;
      text = option;
    } else if (typeof option === 'object') {
      value = option.value;
      text = option.text;
    }

    return React.createElement(MenuItem, {
      key: value,
      value: value
    }, text);
  })), React.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_FilterRangeFields = function MRT_FilterRangeFields(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var localization = tableInstance.options.localization;
  return React.createElement(Box, {
    sx: {
      display: 'grid',
      gridTemplateColumns: '6fr auto 5fr'
    }
  }, React.createElement(MRT_FilterTextField, {
    header: header,
    inputIndex: 0,
    tableInstance: tableInstance
  }), React.createElement(Box, {
    sx: {
      width: '100%',
      minWidth: '5ch',
      textAlign: 'center'
    }
  }, localization.to), React.createElement(MRT_FilterTextField, {
    header: header,
    inputIndex: 1,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCellFilterContainer = function MRT_TableHeadCellFilterContainer(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns,
      showFilters = _getState.showFilters;

  var column = header.column;
  return React.createElement(Collapse, {
    "in": showFilters,
    mountOnEnter: true,
    unmountOnExit: true
  }, currentFilterFns[column.id] === MRT_FILTER_OPTION.BETWEEN ? React.createElement(MRT_FilterRangeFields, {
    header: header,
    tableInstance: tableInstance
  }) : React.createElement(MRT_FilterTextField, {
    header: header,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCellFilterLabel = function MRT_TableHeadCellFilterLabel(_ref) {
  var _getState2, _getState2$currentFil;

  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterAltIcon = _tableInstance$option2.FilterAltIcon,
      FilterAltOffIcon = _tableInstance$option2.FilterAltOffIcon,
      localization = _tableInstance$option.localization,
      setShowFilters = tableInstance.setShowFilters;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var column = header.column;
  var columnDef = column.columnDef;
  var filterFn = (_getState2 = getState()) == null ? void 0 : (_getState2$currentFil = _getState2.currentFilterFns) == null ? void 0 : _getState2$currentFil[header.id];
  var filterTooltip = !!column.getFilterValue() ? localization.filteringByColumn.replace('{column}', String(columnDef.header)).replace('{filterType}', filterFn instanceof Function ? '' : // @ts-ignore
  localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))]).replace('{filterValue}', "\"" + (Array.isArray(column.getFilterValue()) ? column.getFilterValue().join("\" " + localization.and + " \"") : column.getFilterValue()) + "\"").replace('" "', '') : localization.showHideFilters;
  return React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: filterTooltip
  }, React.createElement(IconButton, {
    disableRipple: true,
    onClick: function onClick(event) {
      event.stopPropagation();
      setShowFilters(!showFilters);
    },
    size: "small",
    sx: {
      m: 0,
      opacity: !!column.getFilterValue() || showFilters ? 0.8 : 0,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      transform: 'scale(0.66)',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 0.8
      }
    }
  }, showFilters && !column.getFilterValue() ? React.createElement(FilterAltOffIcon, null) : React.createElement(FilterAltIcon, null)));
};

var MRT_TableHeadCellResizeHandle = function MRT_TableHeadCellResizeHandle(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var column = header.column;
  var columnDefType = column.columnDefType;
  return React.createElement(Divider, {
    flexItem: true,
    orientation: "vertical",
    onDoubleClick: function onDoubleClick() {
      return column.resetSize();
    },
    sx: function sx(theme) {
      return {
        borderRadius: '2px',
        borderRightWidth: '2px',
        cursor: 'col-resize',
        height: showFilters && columnDefType === 'data' ? '4rem' : '2rem',
        opacity: 0.8,
        position: 'absolute',
        right: '1px',
        touchAction: 'none',
        transition: column.getIsResizing() ? undefined : 'all 0.2s ease-in-out',
        userSelect: 'none',
        zIndex: 2000,
        '&:active': {
          backgroundColor: theme.palette.info.main,
          opacity: 1
        }
      };
    },
    onMouseDown: header.getResizeHandler(),
    onTouchStart: header.getResizeHandler(),
    style: {
      transform: column.getIsResizing() ? "translateX(" + getState().columnSizingInfo.deltaOffset + "px)" : 'none'
    }
  });
};

var MRT_TableHeadCellSortLabel = function MRT_TableHeadCellSortLabel(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var localization = tableInstance.options.localization;
  var column = header.column;
  var columnDef = column.columnDef;
  var sortTooltip = !!column.getIsSorted() ? column.getIsSorted() === 'desc' ? localization.sortedByColumnDesc.replace('{column}', columnDef.header) : localization.sortedByColumnAsc.replace('{column}', columnDef.header) : localization.unsorted;
  return React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: sortTooltip
  }, React.createElement(TableSortLabel, {
    "aria-label": sortTooltip,
    active: !!column.getIsSorted(),
    direction: column.getIsSorted() ? column.getIsSorted() : undefined
  }));
};

var MRT_ToggleColumnActionMenuButton = function MRT_ToggleColumnActionMenuButton(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      MoreVertIcon = _tableInstance$option.icons.MoreVertIcon,
      localization = _tableInstance$option.localization,
      muiTableHeadCellColumnActionsButtonProps = _tableInstance$option.muiTableHeadCellColumnActionsButtonProps;
  var column = header.column;
  var columnDef = column.columnDef;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var mTableHeadCellColumnActionsButtonProps = muiTableHeadCellColumnActionsButtonProps instanceof Function ? muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellColumnActionsButtonProps;
  var mcTableHeadCellColumnActionsButtonProps = columnDef.muiTableHeadCellColumnActionsButtonProps instanceof Function ? columnDef.muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellColumnActionsButtonProps;

  var iconButtonProps = _extends({}, mTableHeadCellColumnActionsButtonProps, mcTableHeadCellColumnActionsButtonProps);

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.columnActions
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.columnActions,
    onClick: handleClick,
    size: "small"
  }, iconButtonProps, {
    sx: _extends({
      height: '2rem',
      mr: '2px',
      mt: '-0.2rem',
      opacity: 0.5,
      transition: 'opacity 0.2s',
      width: '2rem',
      '&:hover': {
        opacity: 1
      }
    }, iconButtonProps.sx)
  }), React.createElement(MoreVertIcon, null))), React.createElement(MRT_ColumnActionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _ref2, _ref3, _columnDef$header$len, _columnDef$header;

  var dragRef = _ref.dragRef,
      dropRef = _ref.dropRef,
      header = _ref.header,
      isDragging = _ref.isDragging,
      previewRef = _ref.previewRef,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnActions = _tableInstance$option.enableColumnActions,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableGrouping = _tableInstance$option.enableGrouping,
      muiTableHeadCellProps = _tableInstance$option.muiTableHeadCellProps;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var column = header.column;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;
  var mTableHeadCellProps = muiTableHeadCellProps instanceof Function ? muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellProps;
  var mcTableHeadCellProps = columnDef.muiTableHeadCellProps instanceof Function ? columnDef.muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellProps;

  var tableCellProps = _extends({}, mTableHeadCellProps, mcTableHeadCellProps);

  var headerElement = (_ref2 = (_ref3 = (columnDef == null ? void 0 : columnDef.Header) instanceof Function ? columnDef == null ? void 0 : columnDef.Header == null ? void 0 : columnDef.Header({
    header: header,
    tableInstance: tableInstance
  }) : columnDef == null ? void 0 : columnDef.Header) != null ? _ref3 : header.renderHeader()) != null ? _ref2 : columnDef.header;

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && tableInstance.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (tableInstance.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  return React.createElement(TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: header.colSpan
  }, tableCellProps, {
    ref: columnDefType === 'data' && enableColumnOrdering ? dropRef : undefined,
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() && columnDefType !== 'group' ? alpha(lighten(theme.palette.background["default"], 0.04), 0.95) : 'inherit',
        backgroundImage: 'inherit',
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + alpha(theme.palette.common.black, 0.1) : undefined,
        fontWeight: 'bold',
        height: '100%',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        overflow: 'visible',
        p: isDensePadding ? columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
        pb: columnDefType === 'display' ? 0 : undefined,
        position: column.getIsPinned() && columnDefType !== 'group' ? 'sticky' : undefined,
        pt: columnDefType !== 'data' ? 0 : isDensePadding ? '0.25' : '.75rem',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        transition: "all " + (enableColumnResizing ? 0 : '0.2s') + " ease-in-out",
        verticalAlign: 'text-top',
        zIndex: column.getIsResizing() ? 3 : column.getIsPinned() && columnDefType !== 'group' ? 2 : 1
      }, tableCellProps == null ? void 0 : tableCellProps.sx, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: header.getSize()
      });
    }
  }), header.isPlaceholder ? null : columnDefType === 'display' ? headerElement : React.createElement(Box, {
    ref: previewRef,
    sx: {
      alignItems: 'flex-start',
      display: 'flex',
      justifyContent: columnDefType === 'group' ? 'center' : 'space-between',
      opacity: isDragging ? 0.5 : 1,
      width: '100%'
    }
  }, React.createElement(Box, {
    onClick: function onClick() {
      return column.toggleSorting();
    },
    sx: {
      alignItems: 'center',
      cursor: column.getCanSort() && columnDefType !== 'group' ? 'pointer' : undefined,
      display: 'flex',
      flexWrap: 'nowrap',
      whiteSpace: ((_columnDef$header$len = (_columnDef$header = columnDef.header) == null ? void 0 : _columnDef$header.length) != null ? _columnDef$header$len : 0) < 24 ? 'nowrap' : 'normal'
    }
  }, headerElement, columnDefType === 'data' && column.getCanSort() && React.createElement(MRT_TableHeadCellSortLabel, {
    header: header,
    tableInstance: tableInstance
  }), columnDefType === 'data' && enableColumnFilters && column.getCanFilter() && React.createElement(MRT_TableHeadCellFilterLabel, {
    header: header,
    tableInstance: tableInstance
  })), React.createElement(Box, {
    sx: {
      whiteSpace: 'nowrap'
    }
  }, columnDefType === 'data' && (enableColumnOrdering && columnDef.enableColumnOrdering !== false || enableGrouping && columnDef.enableGrouping !== false) && React.createElement(MRT_GrabHandleButton, {
    ref: dragRef,
    tableInstance: tableInstance
  }), (enableColumnActions || columnDef.enableColumnActions) && columnDef.enableColumnActions !== false && columnDefType !== 'group' && React.createElement(MRT_ToggleColumnActionMenuButton, {
    header: header,
    tableInstance: tableInstance
  })), column.getCanResize() && React.createElement(MRT_TableHeadCellResizeHandle, {
    header: header,
    tableInstance: tableInstance
  })), columnDefType === 'data' && column.getCanFilter() && React.createElement(MRT_TableHeadCellFilterContainer, {
    header: header,
    tableInstance: tableInstance
  }));
};

var MRT_DraggableTableHeadCell = function MRT_DraggableTableHeadCell(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  _objectDestructuringEmpty(tableInstance.options);

  var setColumnOrder = tableInstance.setColumnOrder;

  var _getState = getState(),
      columnOrder = _getState.columnOrder;

  var column = header.column;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var _useDrag = useDrag({
    collect: function collect(monitor) {
      return {
        isDragging: monitor.isDragging()
      };
    },
    item: function item() {
      return column;
    },
    type: 'column'
  }),
      isDragging = _useDrag[0].isDragging,
      dragRef = _useDrag[1],
      previewRef = _useDrag[2];

  return React.createElement(MRT_TableHeadCell, {
    dragRef: dragRef,
    dropRef: dropRef,
    header: header,
    isDragging: isDragging,
    previewRef: previewRef,
    tableInstance: tableInstance
  });
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableGrouping = _tableInstance$option.enableGrouping,
      muiTableHeadRowProps = _tableInstance$option.muiTableHeadRowProps;
  var tableRowProps = muiTableHeadRowProps instanceof Function ? muiTableHeadRowProps({
    headerGroup: headerGroup,
    tableInstance: tableInstance
  }) : muiTableHeadRowProps;
  return React.createElement(TableRow, Object.assign({}, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        boxShadow: "4px 0 8px " + alpha(theme.palette.common.black, 0.1),
        backgroundColor: lighten(theme.palette.background["default"], 0.04)
      }, tableRowProps == null ? void 0 : tableRowProps.sx);
    }
  }), headerGroup.headers.map(function (header, index) {
    return enableColumnOrdering || enableGrouping ? React.createElement(MRT_DraggableTableHeadCell, {
      header: header,
      key: header.id || index,
      tableInstance: tableInstance
    }) : React.createElement(MRT_TableHeadCell, {
      header: header,
      key: header.id || index,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableHead = function MRT_TableHead(_ref) {
  var tableInstance = _ref.tableInstance;
  var getHeaderGroups = tableInstance.getHeaderGroups,
      muiTableHeadProps = tableInstance.options.muiTableHeadProps;
  var tableHeadProps = muiTableHeadProps instanceof Function ? muiTableHeadProps({
    tableInstance: tableInstance
  }) : muiTableHeadProps;
  return React.createElement(TableHead, Object.assign({}, tableHeadProps), getHeaderGroups().map(function (headerGroup) {
    return React.createElement(MRT_TableHeadRow, {
      headerGroup: headerGroup,
      key: headerGroup.id,
      tableInstance: tableInstance
    });
  }));
};

var MRT_EditCellTextField = function MRT_EditCellTextField(_ref) {
  var cell = _ref.cell,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      tableId = _tableInstance$option.tableId,
      enableEditing = _tableInstance$option.enableEditing,
      muiTableBodyCellEditTextFieldProps = _tableInstance$option.muiTableBodyCellEditTextFieldProps,
      onMrtCellEditBlur = _tableInstance$option.onMrtCellEditBlur,
      onMrtCellEditChange = _tableInstance$option.onMrtCellEditChange,
      setCurrentEditingCell = tableInstance.setCurrentEditingCell,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _useState = useState(cell.getValue()),
      value = _useState[0],
      setValue = _useState[1];

  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef;

  var handleChange = function handleChange(event) {
    setValue(event.target.value);
    columnDef.onMrtCellEditChange == null ? void 0 : columnDef.onMrtCellEditChange({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
    onMrtCellEditChange == null ? void 0 : onMrtCellEditChange({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
  };

  var handleBlur = function handleBlur(event) {
    if (getState().currentEditingRow) {
      if (!row._valuesCache) row._valuesCache = {};
      row._valuesCache[column.id] = value;
      setCurrentEditingRow(_extends({}, getState().currentEditingRow));
    }

    setCurrentEditingCell(null);
    columnDef.onMrtCellEditBlur == null ? void 0 : columnDef.onMrtCellEditBlur({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
    onMrtCellEditBlur == null ? void 0 : onMrtCellEditBlur({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
  };

  var mTableBodyCellEditTextFieldProps = muiTableBodyCellEditTextFieldProps instanceof Function ? muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellEditTextFieldProps;
  var mcTableBodyCellEditTextFieldProps = columnDef.muiTableBodyCellEditTextFieldProps instanceof Function ? columnDef.muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellEditTextFieldProps;

  var textFieldProps = _extends({}, mTableBodyCellEditTextFieldProps, mcTableBodyCellEditTextFieldProps);

  if (enableEditing && columnDef.enableEditing !== false && columnDef.Edit) {
    return React.createElement(React.Fragment, null, columnDef.Edit == null ? void 0 : columnDef.Edit({
      cell: cell,
      tableInstance: tableInstance
    }));
  }

  return React.createElement(TextField, Object.assign({
    id: "mrt-" + tableId + "-edit-cell-text-field-" + cell.id,
    margin: "dense",
    onBlur: handleBlur,
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    placeholder: columnDef.header,
    value: value,
    variant: "standard"
  }, textFieldProps));
};

var MRT_CopyButton = function MRT_CopyButton(_ref) {
  var cell = _ref.cell,
      children = _ref.children,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableBodyCellCopyButtonProps = _tableInstance$option.muiTableBodyCellCopyButtonProps;
  var column = cell.column;
  var columnDef = column.columnDef;

  var _useState = useState(false),
      copied = _useState[0],
      setCopied = _useState[1];

  var handleCopy = function handleCopy(text) {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(function () {
      return setCopied(false);
    }, 4000);
  };

  var mTableBodyCellCopyButtonProps = muiTableBodyCellCopyButtonProps instanceof Function ? muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellCopyButtonProps;
  var mcTableBodyCellCopyButtonProps = columnDef.muiTableBodyCellCopyButtonProps instanceof Function ? columnDef.muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellCopyButtonProps;

  var buttonProps = _extends({}, mTableBodyCellCopyButtonProps, mcTableBodyCellCopyButtonProps);

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: copied ? localization.copiedToClipboard : localization.clickToCopy
  }, React.createElement(Button, Object.assign({
    "aria-label": localization.clickToCopy,
    onClick: function onClick() {
      return handleCopy(cell.getValue());
    },
    size: "small",
    type: "button",
    variant: "text"
  }, buttonProps, {
    sx: _extends({
      backgroundColor: 'transparent',
      border: 'none',
      color: 'inherit',
      cursor: 'copy',
      fontFamily: 'inherit',
      fontSize: 'inherit',
      letterSpacing: 'inherit',
      m: '-0.25rem',
      minWidth: 'unset',
      textAlign: 'inherit',
      textTransform: 'inherit'
    }, buttonProps == null ? void 0 : buttonProps.sx)
  }), children));
};

var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var _columnDef$Cell, _row$subRows, _columnDef$Cell2, _row$subRows$length, _row$subRows2;

  var cell = _ref.cell,
      enableHover = _ref.enableHover,
      rowIndex = _ref.rowIndex,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      editingMode = _tableInstance$option.editingMode,
      enableClickToCopy = _tableInstance$option.enableClickToCopy,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableEditing = _tableInstance$option.enableEditing,
      enableRowNumbers = _tableInstance$option.enableRowNumbers,
      muiTableBodyCellProps = _tableInstance$option.muiTableBodyCellProps,
      muiTableBodyCellSkeletonProps = _tableInstance$option.muiTableBodyCellSkeletonProps,
      onMrtCellClick = _tableInstance$option.onMrtCellClick,
      rowNumberMode = _tableInstance$option.rowNumberMode,
      tableId = _tableInstance$option.tableId,
      setColumnOrder = tableInstance.setColumnOrder,
      setCurrentEditingCell = tableInstance.setCurrentEditingCell;

  var _getState = getState(),
      columnOrder = _getState.columnOrder,
      currentEditingCell = _getState.currentEditingCell,
      currentEditingRow = _getState.currentEditingRow,
      isDensePadding = _getState.isDensePadding,
      isLoading = _getState.isLoading,
      showSkeletons = _getState.showSkeletons;

  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var mTableCellBodyProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellProps;
  var mcTableCellBodyProps = columnDef.muiTableBodyCellProps instanceof Function ? columnDef.muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellProps;

  var tableCellProps = _extends({}, mTableCellBodyProps, mcTableCellBodyProps);

  var skeletonWidth = useMemo(function () {
    return columnDefType === 'display' ? column.getSize() / 2 : Math.random() * (column.getSize() - column.getSize() / 3) + column.getSize() / 3;
  }, [columnDefType, column.getSize()]);
  var isEditable = (enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false;
  var isEditing = isEditable && (editingMode === 'table' || (currentEditingRow == null ? void 0 : currentEditingRow.id) === row.id || (currentEditingCell == null ? void 0 : currentEditingCell.id) === cell.id);

  var handleDoubleClick = function handleDoubleClick(_event) {
    if ((enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false && editingMode === 'cell') {
      setCurrentEditingCell(cell);
      setTimeout(function () {
        var textField = document.getElementById("mrt-" + tableId + "-edit-cell-text-field-" + cell.id);

        if (textField) {
          textField.focus();
          textField.select();
        }
      }, 200);
    }
  };

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && tableInstance.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (tableInstance.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  return React.createElement(TableCell, Object.assign({
    onClick: function onClick(event) {
      return onMrtCellClick == null ? void 0 : onMrtCellClick({
        event: event,
        cell: cell,
        tableInstance: tableInstance
      });
    },
    onDoubleClick: handleDoubleClick
  }, tableCellProps, {
    ref: columnDefType === 'data' && enableColumnOrdering ? dropRef : undefined,
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() ? alpha(lighten(theme.palette.background["default"], 0.04), 0.95) : undefined,
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + alpha(theme.palette.common.black, 0.1) : undefined,
        cursor: isEditable && editingMode === 'cell' ? 'pointer' : 'text',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        overflow: 'hidden',
        p: isDensePadding ? columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
        pl: column.id === 'mrt-expand' ? row.depth + (isDensePadding ? 0.5 : 0.75) + "rem" : undefined,
        position: column.getIsPinned() ? 'sticky' : 'relative',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        textOverflow: columnDefType !== 'display' ? 'ellipsis' : undefined,
        transition: 'all 0.2s ease-in-out',
        whiteSpace: isDensePadding ? 'nowrap' : 'normal',
        zIndex: column.getIsPinned() ? 1 : undefined,
        '&:hover': {
          backgroundColor: enableHover && enableEditing && editingMode !== 'row' ? theme.palette.mode === 'dark' ? lighten(theme.palette.background["default"], 0.13) + " !important" : darken(theme.palette.background["default"], 0.07) + " !important" : undefined
        }
      }, tableCellProps == null ? void 0 : tableCellProps.sx, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: column.getSize()
      });
    }
  }), React.createElement(React.Fragment, null, isLoading || showSkeletons ? React.createElement(Skeleton, Object.assign({
    animation: "wave",
    height: 20,
    width: skeletonWidth
  }, muiTableBodyCellSkeletonProps)) : enableRowNumbers && rowNumberMode === 'static' && column.id === 'mrt-row-numbers' ? rowIndex + 1 : columnDefType === 'display' ? columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  }) : cell.getIsPlaceholder() || row.getIsGrouped() && column.id !== row.groupingColumnId ? null : cell.getIsAggregated() ? cell.renderAggregatedCell() : isEditing ? React.createElement(MRT_EditCellTextField, {
    cell: cell,
    tableInstance: tableInstance
  }) : (enableClickToCopy || columnDef.enableClickToCopy) && columnDef.enableClickToCopy !== false ? React.createElement(React.Fragment, null, React.createElement(MRT_CopyButton, {
    cell: cell,
    tableInstance: tableInstance
  }, React.createElement(React.Fragment, null, (_columnDef$Cell = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  })) != null ? _columnDef$Cell : cell.renderCell())), row.getIsGrouped() && React.createElement(React.Fragment, null, " (", (_row$subRows = row.subRows) == null ? void 0 : _row$subRows.length, ")")) : React.createElement(React.Fragment, null, (_columnDef$Cell2 = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  })) != null ? _columnDef$Cell2 : cell.renderCell(), row.getIsGrouped() && React.createElement(React.Fragment, null, " (", (_row$subRows$length = (_row$subRows2 = row.subRows) == null ? void 0 : _row$subRows2.length) != null ? _row$subRows$length : '', ")"))));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getVisibleLeafColumns = tableInstance.getVisibleLeafColumns,
      _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      muiTableDetailPanelProps = _tableInstance$option.muiTableDetailPanelProps,
      onMrtDetailPanelClick = _tableInstance$option.onMrtDetailPanelClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;
  var tableCellProps = muiTableDetailPanelProps instanceof Function ? muiTableDetailPanelProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableDetailPanelProps;
  return React.createElement(TableRow, Object.assign({}, tableRowProps), React.createElement(TableCell, Object.assign({
    colSpan: getVisibleLeafColumns().length,
    onClick: function onClick(event) {
      return onMrtDetailPanelClick == null ? void 0 : onMrtDetailPanelClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    }
  }, tableCellProps, {
    sx: _extends({
      borderBottom: !row.getIsExpanded() ? 'none' : undefined,
      pb: row.getIsExpanded() ? '1rem' : 0,
      pt: row.getIsExpanded() ? '1rem' : 0,
      transition: 'all 0.2s ease-in-out',
      width: tableInstance.getTotalSize() + "px"
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), React.createElement(Collapse, {
    "in": row.getIsExpanded()
  }, renderDetailPanel == null ? void 0 : renderDetailPanel({
    row: row,
    tableInstance: tableInstance
  }))));
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var row = _ref.row,
      rowIndex = _ref.rowIndex,
      tableInstance = _ref.tableInstance;
  var getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      onMrtRowClick = _tableInstance$option.onMrtRowClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;
  return React.createElement(React.Fragment, null, React.createElement(TableRow, Object.assign({
    hover: true,
    onClick: function onClick(event) {
      return onMrtRowClick == null ? void 0 : onMrtRowClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    },
    selected: row.getIsSelected()
  }, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: lighten(theme.palette.background["default"], 0.06),
        transition: 'all 0.2s ease-in-out',
        '&:hover td': {
          backgroundColor: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false && getIsSomeColumnsPinned() ? theme.palette.mode === 'dark' ? "" + lighten(theme.palette.background["default"], 0.12) : "" + darken(theme.palette.background["default"], 0.05) : undefined
        }
      }, tableRowProps == null ? void 0 : tableRowProps.sx);
    }
  }), row.getVisibleCells().map(function (cell) {
    return React.createElement(MRT_TableBodyCell, {
      cell: cell,
      key: cell.id,
      enableHover: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false,
      rowIndex: rowIndex,
      tableInstance: tableInstance
    });
  })), renderDetailPanel && !row.getIsGrouped() && React.createElement(MRT_TableDetailPanel, {
    row: row,
    tableInstance: tableInstance
  }));
};

var MRT_TableBody = function MRT_TableBody(_ref) {
  var tableInstance = _ref.tableInstance,
      tableContainerRef = _ref.tableContainerRef;
  var getPaginationRowModel = tableInstance.getPaginationRowModel,
      getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enablePagination = _tableInstance$option.enablePagination,
      enableRowVirtualization = _tableInstance$option.enableRowVirtualization,
      muiTableBodyProps = _tableInstance$option.muiTableBodyProps,
      virtualizerProps = _tableInstance$option.virtualizerProps;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var tableBodyProps = muiTableBodyProps instanceof Function ? muiTableBodyProps({
    tableInstance: tableInstance
  }) : muiTableBodyProps;
  var rows = enablePagination ? getPaginationRowModel().rows : getPrePaginationRowModel().rows;
  var rowVirtualizer = enableRowVirtualization ? useVirtual(_extends({
    overscan: isDensePadding ? 15 : 5,
    size: rows.length,
    parentRef: tableContainerRef
  }, virtualizerProps)) : {};
  var virtualRows = rowVirtualizer.virtualItems;
  var paddingTop = (virtualRows == null ? void 0 : virtualRows.length) > 0 ? virtualRows[0].start : 0;
  var paddingBottom = (virtualRows == null ? void 0 : virtualRows.length) > 0 ? rowVirtualizer.totalSize - virtualRows[virtualRows.length - 1].end : 0;
  return React.createElement(TableBody, Object.assign({}, tableBodyProps), enableRowVirtualization && paddingTop > 0 && React.createElement("tr", null, React.createElement("td", {
    style: {
      height: paddingTop + "px"
    }
  })), (enableRowVirtualization ? virtualRows : rows).map(function (rowOrVirtualRow, rowIndex) {
    var row = enableRowVirtualization ? rows[rowOrVirtualRow.index] : rowOrVirtualRow;
    return React.createElement(MRT_TableBodyRow, {
      key: row.id,
      row: row,
      rowIndex: enableRowVirtualization ? rowOrVirtualRow.index : rowIndex,
      tableInstance: tableInstance
    });
  }), enableRowVirtualization && paddingBottom > 0 && React.createElement("tr", null, React.createElement("td", {
    style: {
      height: paddingBottom + "px"
    }
  })));
};

var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _ref2, _ref3, _ref4;

  var footer = _ref.footer,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      muiTableFooterCellProps = _tableInstance$option.muiTableFooterCellProps,
      enableColumnResizing = _tableInstance$option.enableColumnResizing;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var column = footer.column;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;
  var mTableFooterCellProps = muiTableFooterCellProps instanceof Function ? muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableFooterCellProps;
  var mcTableFooterCellProps = columnDef.muiTableFooterCellProps instanceof Function ? columnDef.muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableFooterCellProps;

  var tableCellProps = _extends({}, mTableFooterCellProps, mcTableFooterCellProps);

  return React.createElement(TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: footer.colSpan,
    variant: "head"
  }, tableCellProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: theme.palette.background["default"],
        backgroundImage: "linear-gradient(" + alpha(theme.palette.common.white, 0.05) + "," + alpha(theme.palette.common.white, 0.05) + ")",
        fontWeight: 'bold',
        maxWidth: column.getSize() + "px",
        minWidth: column.getSize() + "px",
        p: isDensePadding ? '0.5rem' : '1rem',
        transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out",
        width: column.getSize(),
        verticalAlign: 'text-top'
      }, tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), React.createElement(React.Fragment, null, footer.isPlaceholder ? null : (_ref2 = (_ref3 = (_ref4 = columnDef.Footer instanceof Function ? columnDef.Footer == null ? void 0 : columnDef.Footer({
    footer: footer,
    tableInstance: tableInstance
  }) : columnDef.Footer) != null ? _ref4 : columnDef.footer) != null ? _ref3 : footer.renderFooter()) != null ? _ref2 : null));
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var _footerGroup$headers;

  var footerGroup = _ref.footerGroup,
      tableInstance = _ref.tableInstance;
  var muiTableFooterRowProps = tableInstance.options.muiTableFooterRowProps; // if no content in row, skip row

  if (!((_footerGroup$headers = footerGroup.headers) != null && _footerGroup$headers.some(function (header) {
    return typeof header.column.columnDef.footer === 'string' && !!header.column.columnDef.footer || header.column.columnDef.Footer;
  }))) return null;
  var tableRowProps = muiTableFooterRowProps instanceof Function ? muiTableFooterRowProps({
    footerGroup: footerGroup,
    tableInstance: tableInstance
  }) : muiTableFooterRowProps;
  return React.createElement(TableRow, Object.assign({}, tableRowProps), footerGroup.headers.map(function (footer) {
    return React.createElement(MRT_TableFooterCell, {
      footer: footer,
      key: footer.id,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableFooter = function MRT_TableFooter(_ref) {
  var tableInstance = _ref.tableInstance;
  var getFooterGroups = tableInstance.getFooterGroups,
      muiTableFooterProps = tableInstance.options.muiTableFooterProps;
  var tableFooterProps = muiTableFooterProps instanceof Function ? muiTableFooterProps({
    tableInstance: tableInstance
  }) : muiTableFooterProps;
  return React.createElement(TableFooter, Object.assign({}, tableFooterProps), getFooterGroups().map(function (footerGroup) {
    return React.createElement(MRT_TableFooterRow, {
      footerGroup: footerGroup,
      key: footerGroup.id,
      tableInstance: tableInstance
    });
  }));
};

var MRT_Table = function MRT_Table(_ref) {
  var tableContainerRef = _ref.tableContainerRef,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableRowVirtualization = _tableInstance$option.enableRowVirtualization,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      enableTableFooter = _tableInstance$option.enableTableFooter,
      enableTableHead = _tableInstance$option.enableTableHead,
      muiTableProps = _tableInstance$option.muiTableProps;
  var tableProps = muiTableProps instanceof Function ? muiTableProps({
    tableInstance: tableInstance
  }) : muiTableProps;
  return React.createElement(Table, Object.assign({
    stickyHeader: enableStickyHeader
  }, tableProps, {
    sx: _extends({
      tableLayout: enableColumnResizing || enableRowVirtualization ? 'fixed' : 'auto'
    }, tableProps == null ? void 0 : tableProps.sx)
  }), enableTableHead && React.createElement(MRT_TableHead, {
    tableInstance: tableInstance
  }), React.createElement(MRT_TableBody, {
    tableContainerRef: tableContainerRef,
    tableInstance: tableInstance
  }), enableTableFooter && React.createElement(MRT_TableFooter, {
    tableInstance: tableInstance
  }));
};

var useIsomorphicLayoutEffect = typeof window !== 'undefined' ? useLayoutEffect : useEffect;
var MRT_TableContainer = function MRT_TableContainer(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      muiTableContainerProps = _tableInstance$option.muiTableContainerProps,
      tableId = _tableInstance$option.tableId;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var _useState = useState(0),
      totalToolbarHeight = _useState[0],
      setTotalToolbarHeight = _useState[1];

  var tableContainerProps = muiTableContainerProps instanceof Function ? muiTableContainerProps({
    tableInstance: tableInstance
  }) : muiTableContainerProps;
  useIsomorphicLayoutEffect(function () {
    var _document$getElementB, _document, _document$getElementB2, _document$getElementB3, _document2, _document2$getElement;

    var topToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB = (_document = document) == null ? void 0 : (_document$getElementB2 = _document.getElementById("mrt-" + tableId + "-toolbar-top")) == null ? void 0 : _document$getElementB2.offsetHeight) != null ? _document$getElementB : 0 : 0;
    var bottomToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB3 = (_document2 = document) == null ? void 0 : (_document2$getElement = _document2.getElementById("mrt-" + tableId + "-toolbar-bottom")) == null ? void 0 : _document2$getElement.offsetHeight) != null ? _document$getElementB3 : 0 : 0;
    setTotalToolbarHeight(topToolbarHeight + bottomToolbarHeight);
  });
  var tableContainerRef = React.useRef(null);
  return React.createElement(TableContainer, Object.assign({}, tableContainerProps, {
    ref: tableContainerRef,
    sx: _extends({
      maxWidth: '100%',
      maxHeight: enableStickyHeader ? "clamp(350px, calc(100vh - " + totalToolbarHeight + "px), 2000px)" : undefined,
      overflow: 'auto'
    }, tableContainerProps == null ? void 0 : tableContainerProps.sx),
    style: {
      maxHeight: isFullScreen ? "calc(100vh - " + totalToolbarHeight + "px)" : undefined
    }
  }), React.createElement(MRT_Table, {
    tableContainerRef: tableContainerRef,
    tableInstance: tableInstance
  }));
};

var MRT_TablePaper = function MRT_TablePaper(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableToolbarBottom = _tableInstance$option.enableToolbarBottom,
      enableToolbarTop = _tableInstance$option.enableToolbarTop,
      muiTablePaperProps = _tableInstance$option.muiTablePaperProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  useEffect(function () {
    if (typeof window !== 'undefined') {
      if (isFullScreen) {
        document.body.style.overflow = 'hidden';
        document.body.style.height = '100vh';
      } else {
        document.body.style.overflow = 'auto';
        document.body.style.height = 'auto';
      }
    }
  }, [isFullScreen]);
  var tablePaperProps = muiTablePaperProps instanceof Function ? muiTablePaperProps({
    tableInstance: tableInstance
  }) : muiTablePaperProps;
  return React.createElement(DndProvider, {
    backend: HTML5Backend
  }, React.createElement(Paper, Object.assign({
    elevation: 2
  }, tablePaperProps, {
    sx: _extends({
      transition: 'all 0.2s ease-in-out'
    }, tablePaperProps == null ? void 0 : tablePaperProps.sx),
    style: {
      height: isFullScreen ? '100vh' : undefined,
      margin: isFullScreen ? '0' : undefined,
      maxHeight: isFullScreen ? '100vh' : undefined,
      maxWidth: isFullScreen ? '100vw' : undefined,
      padding: isFullScreen ? '0' : undefined,
      width: isFullScreen ? '100vw' : undefined
    }
  }), enableToolbarTop && React.createElement(MRT_ToolbarTop, {
    tableInstance: tableInstance
  }), React.createElement(MRT_TableContainer, {
    tableInstance: tableInstance
  }), enableToolbarBottom && React.createElement(MRT_ToolbarBottom, {
    tableInstance: tableInstance
  })));
};

var MRT_TableRoot = function MRT_TableRoot(props) {
  var _initialState$current, _initialState$current2, _initialState$isDense, _initialState$isFullS, _initialState$showFil, _initialState$showGlo, _props$globalFilterFn, _props$state3, _props$state4;

  var _useState = useState(props.tableId),
      tableId = _useState[0],
      setIdPrefix = _useState[1];

  useEffect(function () {
    var _props$tableId;

    return setIdPrefix((_props$tableId = props.tableId) != null ? _props$tableId : Math.random().toString(36).substring(2, 9));
  }, [props.tableId]);
  var showActionColumn = props.enableRowActions || props.enableEditing && props.editingMode === 'row';
  var showExpandColumn = props.enableExpanding || props.enableGrouping;
  var initialState = useMemo(function () {
    var _props$initialState, _initState$columnOrde;

    var initState = (_props$initialState = props.initialState) != null ? _props$initialState : {};
    initState.columnOrder = ((_initState$columnOrde = initState == null ? void 0 : initState.columnOrder) != null ? _initState$columnOrde : props.enableColumnOrdering || props.enableGrouping) ? [showActionColumn && 'mrt-row-actions', showExpandColumn && 'mrt-expand', props.enableRowSelection && 'mrt-select', props.enableRowNumbers && 'mrt-row-numbers'].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
      return c.id;
    })).filter(Boolean) : [];

    if (!props.enablePersistentState || !props.tableId) {
      return initState;
    }

    if (typeof window === 'undefined') {
      if (process.env.NODE_ENV !== 'production') {
        console.error('The MRT Persistent Table State feature is not supported if using SSR, but you can wrap your <MaterialReactTable /> in a MUI <NoSsr> tags to let it work');
      }

      return initState;
    }

    var storedState = props.persistentStateMode === 'localStorage' ? localStorage.getItem("mrt-" + tableId + "-table-state") : props.persistentStateMode === 'sessionStorage' ? sessionStorage.getItem("mrt-" + tableId + "-table-state") : '{}';

    if (storedState) {
      var parsedState = JSON.parse(storedState);

      if (parsedState) {
        return _extends({}, initState, parsedState);
      }
    }

    return initState;
  }, []);

  var _useState2 = useState((_initialState$current = initialState == null ? void 0 : initialState.currentEditingCell) != null ? _initialState$current : null),
      currentEditingCell = _useState2[0],
      setCurrentEditingCell = _useState2[1];

  var _useState3 = useState((_initialState$current2 = initialState == null ? void 0 : initialState.currentEditingRow) != null ? _initialState$current2 : null),
      currentEditingRow = _useState3[0],
      setCurrentEditingRow = _useState3[1];

  var _useState4 = useState((_initialState$isDense = initialState == null ? void 0 : initialState.isDensePadding) != null ? _initialState$isDense : false),
      isDensePadding = _useState4[0],
      setIsDensePadding = _useState4[1];

  var _useState5 = useState((_initialState$isFullS = initialState == null ? void 0 : initialState.isFullScreen) != null ? _initialState$isFullS : false),
      isFullScreen = _useState5[0],
      setIsFullScreen = _useState5[1];

  var _useState6 = useState((_initialState$showFil = initialState == null ? void 0 : initialState.showFilters) != null ? _initialState$showFil : false),
      showFilters = _useState6[0],
      setShowFilters = _useState6[1];

  var _useState7 = useState((_initialState$showGlo = initialState == null ? void 0 : initialState.showGlobalFilter) != null ? _initialState$showGlo : false),
      showGlobalFilter = _useState7[0],
      setShowGlobalFilter = _useState7[1];

  var _useState8 = useState(function () {
    return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
      var _ref, _c$filterFn, _initialState$current3, _c$filterSelectOption, _ref2;

      return _ref2 = {}, _ref2[c.id] = (_ref = (_c$filterFn = c.filterFn) != null ? _c$filterFn : initialState == null ? void 0 : (_initialState$current3 = initialState.currentFilterFns) == null ? void 0 : _initialState$current3[c.id]) != null ? _ref : !!((_c$filterSelectOption = c.filterSelectOptions) != null && _c$filterSelectOption.length) ? MRT_FILTER_OPTION.EQUALS : MRT_FILTER_OPTION.FUZZY, _ref2;
    })));
  }),
      currentFilterFns = _useState8[0],
      setCurrentFilterFns = _useState8[1];

  var _useState9 = useState((_props$globalFilterFn = props.globalFilterFn) != null ? _props$globalFilterFn : MRT_FILTER_OPTION.FUZZY),
      currentGlobalFilterFn = _useState9[0],
      setCurrentGlobalFilterFn = _useState9[1];

  var table = useMemo(function () {
    return (// @ts-ignore
      createTable().setOptions({
        //@ts-ignore
        filterFns: defaultFilterFNs,
        getCoreRowModel: getCoreRowModel(),
        getExpandedRowModel: getExpandedRowModel(),
        getFacetedRowModel: getFacetedRowModel(),
        getFilteredRowModel: getFilteredRowModel(),
        getGroupedRowModel: getGroupedRowModel(),
        getPaginationRowModel: getPaginationRowModel(),
        getSortedRowModel: getSortedRowModel(),
        getSubRows: function getSubRows(row) {
          return row == null ? void 0 : row.subRows;
        },
        tableId: tableId,
        initialState: initialState
      })
    );
  }, []);
  var displayColumns = useMemo(function () {
    var _props$localization, _props$localization2, _props$localization3, _props$localization5;

    return [showActionColumn && createDisplayColumn(table, {
      Cell: function Cell(_ref3) {
        var cell = _ref3.cell;
        return React.createElement(MRT_ToggleRowActionMenuButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      header: (_props$localization = props.localization) == null ? void 0 : _props$localization.actions,
      id: 'mrt-row-actions',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 60
    }), showExpandColumn && createDisplayColumn(table, {
      Cell: function Cell(_ref4) {
        var cell = _ref4.cell;
        return React.createElement(MRT_ExpandButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableExpandAll ? React.createElement(MRT_ExpandAllButton, {
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization2 = props.localization) == null ? void 0 : _props$localization2.expand,
      id: 'mrt-expand',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    }), props.enableRowSelection && createDisplayColumn(table, {
      Cell: function Cell(_ref5) {
        var cell = _ref5.cell;
        return React.createElement(MRT_SelectCheckbox, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableSelectAll ? React.createElement(MRT_SelectCheckbox, {
          selectAll: true,
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization3 = props.localization) == null ? void 0 : _props$localization3.select,
      id: 'mrt-select',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    }), props.enableRowNumbers && createDisplayColumn(table, {
      Cell: function Cell(_ref6) {
        var cell = _ref6.cell;
        return cell.row.index + 1;
      },
      Header: function Header() {
        var _props$localization4;

        return (_props$localization4 = props.localization) == null ? void 0 : _props$localization4.rowNumber;
      },
      header: (_props$localization5 = props.localization) == null ? void 0 : _props$localization5.rowNumbers,
      id: 'mrt-row-numbers',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    })].filter(Boolean);
  }, [props.editingMode, props.enableEditing, props.enableExpandAll, props.enableExpanding, props.enableGrouping, props.enableRowActions, props.enableRowNumbers, props.enableRowSelection, props.enableSelectAll, props.localization, table]);
  var columns = useMemo(function () {
    return [].concat(displayColumns, props.columns.map(function (column) {
      return column.columns ? createGroup(table, column, currentFilterFns) : createDataColumn(table, column, currentFilterFns);
    }));
  }, [table, props.columns, currentFilterFns]);
  var data = useMemo(function () {
    var _props$state, _props$state2;

    return ((_props$state = props.state) != null && _props$state.isLoading || (_props$state2 = props.state) != null && _props$state2.showSkeletons) && !props.data.length ? [].concat(Array(10).fill(null)).map(function () {
      return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
        var _ref7;

        return _ref7 = {}, _ref7[c.id] = null, _ref7;
      })));
    }) : props.data;
  }, [props.data, (_props$state3 = props.state) == null ? void 0 : _props$state3.isLoading, (_props$state4 = props.state) == null ? void 0 : _props$state4.showSkeletons]); //@ts-ignore

  var tableInstance = _extends({}, useTableInstance(table, _extends({}, props, {
    //@ts-ignore
    columns: columns,
    data: data,
    //@ts-ignore
    globalFilterFn: currentGlobalFilterFn,
    state: _extends({
      currentEditingCell: currentEditingCell,
      currentEditingRow: currentEditingRow,
      currentFilterFns: currentFilterFns,
      currentGlobalFilterFn: currentGlobalFilterFn,
      isDensePadding: isDensePadding,
      isFullScreen: isFullScreen,
      showFilters: showFilters,
      showGlobalFilter: showGlobalFilter
    }, props.state)
  })), {
    setCurrentEditingCell: setCurrentEditingCell,
    setCurrentEditingRow: setCurrentEditingRow,
    setCurrentFilterFns: setCurrentFilterFns,
    setCurrentGlobalFilterFn: setCurrentGlobalFilterFn,
    setIsDensePadding: setIsDensePadding,
    setIsFullScreen: setIsFullScreen,
    setShowFilters: setShowFilters,
    setShowGlobalFilter: setShowGlobalFilter
  });

  useEffect(function () {
    if (typeof window === 'undefined' || !props.enablePersistentState) {
      return;
    }

    if (!props.tableId && process.env.NODE_ENV !== 'production') {
      console.warn('a unique tableId prop is required for persistent table state to work');
      return;
    }

    var itemArgs = ["mrt-" + tableId + "-table-state", JSON.stringify(tableInstance.getState())];

    if (props.persistentStateMode === 'localStorage') {
      var _localStorage;

      (_localStorage = localStorage).setItem.apply(_localStorage, itemArgs);
    } else if (props.persistentStateMode === 'sessionStorage') {
      var _sessionStorage;

      (_sessionStorage = sessionStorage).setItem.apply(_sessionStorage, itemArgs);
    }
  }, [props.enablePersistentState, props.tableId, props.persistentStateMode, tableInstance]);
  return React.createElement(React.Fragment, null, React.createElement(Dialog, {
    PaperComponent: Box,
    TransitionComponent: Grow,
    disablePortal: true,
    fullScreen: true,
    keepMounted: false,
    onClose: function onClose() {
      return setIsFullScreen(false);
    },
    open: isFullScreen,
    transitionDuration: 400
  }, React.createElement(MRT_TablePaper, {
    tableInstance: tableInstance
  })), !isFullScreen && React.createElement(MRT_TablePaper, {
    tableInstance: tableInstance
  }));
};

var _excluded$5 = ["autoResetExpanded", "columnResizeMode", "defaultColumn", "editingMode", "enableColumnActions", "enableColumnFilters", "enableColumnOrdering", "enableColumnResizing", "enableDensePaddingToggle", "enableExpandAll", "enableFilters", "enableFullScreenToggle", "enableGlobalFilter", "enableGrouping", "enableHiding", "enableMultiRowSelection", "enablePagination", "enablePinning", "enableSelectAll", "enableSorting", "enableStickyHeader", "enableTableFooter", "enableTableHead", "enableToolbarBottom", "enableToolbarInternalActions", "enableToolbarTop", "icons", "localization", "persistentStateMode", "positionActionsColumn", "positionPagination", "positionGlobalFilter", "positionToolbarActions", "positionToolbarAlertBanner", "rowNumberMode", "selectAllMode"];
var MaterialReactTable = (function (_ref) {
  var _ref$autoResetExpande = _ref.autoResetExpanded,
      autoResetExpanded = _ref$autoResetExpande === void 0 ? false : _ref$autoResetExpande,
      _ref$columnResizeMode = _ref.columnResizeMode,
      columnResizeMode = _ref$columnResizeMode === void 0 ? 'onEnd' : _ref$columnResizeMode,
      _ref$defaultColumn = _ref.defaultColumn,
      defaultColumn = _ref$defaultColumn === void 0 ? {
    minSize: 40,
    maxSize: 1000,
    size: 180
  } : _ref$defaultColumn,
      _ref$editingMode = _ref.editingMode,
      editingMode = _ref$editingMode === void 0 ? 'row' : _ref$editingMode,
      _ref$enableColumnActi = _ref.enableColumnActions,
      enableColumnActions = _ref$enableColumnActi === void 0 ? true : _ref$enableColumnActi,
      _ref$enableColumnFilt = _ref.enableColumnFilters,
      enableColumnFilters = _ref$enableColumnFilt === void 0 ? true : _ref$enableColumnFilt,
      _ref$enableColumnOrde = _ref.enableColumnOrdering,
      enableColumnOrdering = _ref$enableColumnOrde === void 0 ? false : _ref$enableColumnOrde,
      _ref$enableColumnResi = _ref.enableColumnResizing,
      enableColumnResizing = _ref$enableColumnResi === void 0 ? false : _ref$enableColumnResi,
      _ref$enableDensePaddi = _ref.enableDensePaddingToggle,
      enableDensePaddingToggle = _ref$enableDensePaddi === void 0 ? true : _ref$enableDensePaddi,
      _ref$enableExpandAll = _ref.enableExpandAll,
      enableExpandAll = _ref$enableExpandAll === void 0 ? true : _ref$enableExpandAll,
      _ref$enableFilters = _ref.enableFilters,
      enableFilters = _ref$enableFilters === void 0 ? true : _ref$enableFilters,
      _ref$enableFullScreen = _ref.enableFullScreenToggle,
      enableFullScreenToggle = _ref$enableFullScreen === void 0 ? true : _ref$enableFullScreen,
      _ref$enableGlobalFilt = _ref.enableGlobalFilter,
      enableGlobalFilter = _ref$enableGlobalFilt === void 0 ? true : _ref$enableGlobalFilt,
      _ref$enableGrouping = _ref.enableGrouping,
      enableGrouping = _ref$enableGrouping === void 0 ? false : _ref$enableGrouping,
      _ref$enableHiding = _ref.enableHiding,
      enableHiding = _ref$enableHiding === void 0 ? true : _ref$enableHiding,
      _ref$enableMultiRowSe = _ref.enableMultiRowSelection,
      enableMultiRowSelection = _ref$enableMultiRowSe === void 0 ? true : _ref$enableMultiRowSe,
      _ref$enablePagination = _ref.enablePagination,
      enablePagination = _ref$enablePagination === void 0 ? true : _ref$enablePagination,
      _ref$enablePinning = _ref.enablePinning,
      enablePinning = _ref$enablePinning === void 0 ? false : _ref$enablePinning,
      _ref$enableSelectAll = _ref.enableSelectAll,
      enableSelectAll = _ref$enableSelectAll === void 0 ? true : _ref$enableSelectAll,
      _ref$enableSorting = _ref.enableSorting,
      enableSorting = _ref$enableSorting === void 0 ? true : _ref$enableSorting,
      _ref$enableStickyHead = _ref.enableStickyHeader,
      enableStickyHeader = _ref$enableStickyHead === void 0 ? true : _ref$enableStickyHead,
      _ref$enableTableFoote = _ref.enableTableFooter,
      enableTableFooter = _ref$enableTableFoote === void 0 ? true : _ref$enableTableFoote,
      _ref$enableTableHead = _ref.enableTableHead,
      enableTableHead = _ref$enableTableHead === void 0 ? true : _ref$enableTableHead,
      _ref$enableToolbarBot = _ref.enableToolbarBottom,
      enableToolbarBottom = _ref$enableToolbarBot === void 0 ? true : _ref$enableToolbarBot,
      _ref$enableToolbarInt = _ref.enableToolbarInternalActions,
      enableToolbarInternalActions = _ref$enableToolbarInt === void 0 ? true : _ref$enableToolbarInt,
      _ref$enableToolbarTop = _ref.enableToolbarTop,
      enableToolbarTop = _ref$enableToolbarTop === void 0 ? true : _ref$enableToolbarTop,
      icons = _ref.icons,
      localization = _ref.localization,
      _ref$persistentStateM = _ref.persistentStateMode,
      persistentStateMode = _ref$persistentStateM === void 0 ? 'sessionStorage' : _ref$persistentStateM,
      _ref$positionActionsC = _ref.positionActionsColumn,
      positionActionsColumn = _ref$positionActionsC === void 0 ? 'first' : _ref$positionActionsC,
      _ref$positionPaginati = _ref.positionPagination,
      positionPagination = _ref$positionPaginati === void 0 ? 'bottom' : _ref$positionPaginati,
      _ref$positionGlobalFi = _ref.positionGlobalFilter,
      positionGlobalFilter = _ref$positionGlobalFi === void 0 ? 'right' : _ref$positionGlobalFi,
      _ref$positionToolbarA = _ref.positionToolbarActions,
      positionToolbarActions = _ref$positionToolbarA === void 0 ? 'top' : _ref$positionToolbarA,
      _ref$positionToolbarA2 = _ref.positionToolbarAlertBanner,
      positionToolbarAlertBanner = _ref$positionToolbarA2 === void 0 ? 'top' : _ref$positionToolbarA2,
      _ref$rowNumberMode = _ref.rowNumberMode,
      rowNumberMode = _ref$rowNumberMode === void 0 ? 'original' : _ref$rowNumberMode,
      _ref$selectAllMode = _ref.selectAllMode,
      selectAllMode = _ref$selectAllMode === void 0 ? 'all' : _ref$selectAllMode,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$5);

  return React.createElement(MRT_TableRoot, Object.assign({
    autoResetExpanded: autoResetExpanded,
    columnResizeMode: columnResizeMode,
    defaultColumn: defaultColumn,
    editingMode: editingMode,
    enableColumnActions: enableColumnActions,
    enableColumnFilters: enableColumnFilters,
    enableColumnOrdering: enableColumnOrdering,
    enableColumnResizing: enableColumnResizing,
    enableDensePaddingToggle: enableDensePaddingToggle,
    enableExpandAll: enableExpandAll,
    enableFilters: enableFilters,
    enableFullScreenToggle: enableFullScreenToggle,
    enableGlobalFilter: enableGlobalFilter,
    enableGrouping: enableGrouping,
    enableHiding: enableHiding,
    enableMultiRowSelection: enableMultiRowSelection,
    enablePagination: enablePagination,
    enablePinning: enablePinning,
    enableSelectAll: enableSelectAll,
    enableSorting: enableSorting,
    enableStickyHeader: enableStickyHeader,
    enableTableFooter: enableTableFooter,
    enableTableHead: enableTableHead,
    enableToolbarBottom: enableToolbarBottom,
    enableToolbarInternalActions: enableToolbarInternalActions,
    enableToolbarTop: enableToolbarTop,
    icons: _extends({}, MRT_Default_Icons, icons),
    localization: _extends({}, MRT_DefaultLocalization_EN, localization),
    persistentStateMode: persistentStateMode,
    positionActionsColumn: positionActionsColumn,
    positionGlobalFilter: positionGlobalFilter,
    positionPagination: positionPagination,
    positionToolbarActions: positionToolbarActions,
    positionToolbarAlertBanner: positionToolbarAlertBanner,
    rowNumberMode: rowNumberMode,
    selectAllMode: selectAllMode
  }, rest));
});

export default MaterialReactTable;
//# sourceMappingURL=material-react-table.esm.js.map
