'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var iconsMaterial = require('@mui/icons-material');
var reactTable = require('@tanstack/react-table');
var material = require('@mui/material');
var matchSorterUtils = require('@tanstack/match-sorter-utils');
var jsxRuntime = require('react/jsx-runtime');

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _objectDestructuringEmpty(obj) {
  if (obj == null) throw new TypeError("Cannot destructure undefined");
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MRT_DefaultLocalization_EN = {
  actions: 'Actions',
  and: 'and',
  cancel: 'Cancel',
  changeFilterMode: 'Change filter mode',
  changeSearchMode: 'Change search mode',
  clearFilter: 'Clear filter',
  clearSearch: 'Clear search',
  clearSort: 'Clear sort',
  clickToCopy: 'Click to copy',
  columnActions: 'Column Actions',
  copiedToClipboard: 'Copied to clipboard',
  edit: 'Edit',
  expand: 'Expand',
  expandAll: 'Expand all',
  filterBetween: 'Between',
  filterByColumn: 'Filter by {column}',
  filterContains: 'Contains',
  filterEmpty: 'Empty',
  filterEndsWith: 'Ends With',
  filterEquals: 'Equals',
  filterFuzzy: 'Fuzzy',
  filterGreaterThan: 'Greater Than',
  filterLessThan: 'Less Than',
  filterMode: 'Filter Mode: {filterType}',
  filterNotEmpty: 'Not Empty',
  filterNotEquals: 'Not Equals',
  filterStartsWith: 'Starts With',
  filteringByColumn: 'Filtering by {column} - {filterType} {filterValue}',
  grab: 'Grab',
  groupByColumn: 'Group by {column}',
  groupedBy: 'Grouped by ',
  hideAll: 'Hide all',
  hideColumn: 'Hide {column} column',
  max: 'Max',
  min: 'Min',
  pinToLeft: 'Pin to left',
  pinToRight: 'Pin to right',
  resetColumnSize: 'Reset column size',
  resetOrder: 'Reset order',
  rowActions: 'Row Actions',
  rowNumber: '#',
  rowNumbers: 'Row Numbers',
  save: 'Save',
  search: 'Search',
  selectedCountOfRowCountRowsSelected: '{selectedCount} of {rowCount} row(s) selected',
  select: 'Select',
  showAll: 'Show all',
  showAllColumns: 'Show all columns',
  showHideColumns: 'Show/Hide columns',
  showHideFilters: 'Show/Hide filters',
  showHideSearch: 'Show/Hide search',
  sortByColumnAsc: 'Sort by {column} ascending',
  sortByColumnDesc: 'Sort by {column} descending',
  sortedByColumnAsc: 'Sorted by {column} ascending',
  sortedByColumnDesc: 'Sorted by {column} descending',
  thenBy: ', then by ',
  to: 'to',
  toggleDensePadding: 'Toggle dense padding',
  toggleFullScreen: 'Toggle full screen',
  toggleSelectAll: 'Toggle select all',
  toggleSelectRow: 'Toggle select row',
  ungroupByColumn: 'Ungroup by {column}',
  unpin: 'Unpin',
  unpinAll: 'Unpin all',
  unsorted: 'Unsorted'
};

var MRT_Default_Icons = {
  ArrowRightIcon: iconsMaterial.ArrowRight,
  CancelIcon: iconsMaterial.Cancel,
  CheckBoxIcon: iconsMaterial.CheckBox,
  ClearAllIcon: iconsMaterial.ClearAll,
  CloseIcon: iconsMaterial.Close,
  DensityMediumIcon: iconsMaterial.DensityMedium,
  DensitySmallIcon: iconsMaterial.DensitySmall,
  KeyboardDoubleArrowDownIcon: iconsMaterial.KeyboardDoubleArrowDown,
  DragHandleIcon: iconsMaterial.DragHandle,
  DynamicFeedIcon: iconsMaterial.DynamicFeed,
  EditIcon: iconsMaterial.Edit,
  ExpandLessIcon: iconsMaterial.ExpandLess,
  ExpandMoreIcon: iconsMaterial.ExpandMore,
  FilterAltIcon: iconsMaterial.FilterAlt,
  FilterAltOffIcon: iconsMaterial.FilterAltOff,
  FilterListIcon: iconsMaterial.FilterList,
  FilterListOffIcon: iconsMaterial.FilterListOff,
  FullscreenExitIcon: iconsMaterial.FullscreenExit,
  FullscreenIcon: iconsMaterial.Fullscreen,
  MoreHorizIcon: iconsMaterial.MoreHoriz,
  MoreVertIcon: iconsMaterial.MoreVert,
  PushPinIcon: iconsMaterial.PushPin,
  RestartAltIcon: iconsMaterial.RestartAlt,
  SaveIcon: iconsMaterial.Save,
  SearchIcon: iconsMaterial.Search,
  SearchOffIcon: iconsMaterial.SearchOff,
  SortIcon: iconsMaterial.Sort,
  ViewColumnIcon: iconsMaterial.ViewColumn,
  VisibilityOffIcon: iconsMaterial.VisibilityOff
};

var MRT_ExpandAllButton = function MRT_ExpandAllButton(_ref) {
  var tableInstance = _ref.tableInstance;
  var getIsAllRowsExpanded = tableInstance.getIsAllRowsExpanded,
      getIsSomeRowsExpanded = tableInstance.getIsSomeRowsExpanded,
      getCanSomeRowsExpand = tableInstance.getCanSomeRowsExpand,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      KeyboardDoubleArrowDownIcon = _tableInstance$option.icons.KeyboardDoubleArrowDownIcon,
      localization = _tableInstance$option.localization,
      renderDetailPanel = _tableInstance$option.renderDetailPanel,
      toggleAllRowsExpanded = tableInstance.toggleAllRowsExpanded;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expandAll
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.expandAll,
    disabled: !getCanSomeRowsExpand() && !renderDetailPanel,
    onClick: function onClick() {
      return toggleAllRowsExpanded(!getIsAllRowsExpanded());
    },
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React__default.createElement(KeyboardDoubleArrowDownIcon, {
    style: {
      transform: "rotate(" + (getIsAllRowsExpanded() ? -180 : getIsSomeRowsExpanded() ? -90 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_ExpandButton = function MRT_ExpandButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      ExpandMoreIcon = _tableInstance$option.icons.ExpandMoreIcon,
      localization = _tableInstance$option.localization,
      onMrtRowExpandChange = _tableInstance$option.onMrtRowExpandChange,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleToggleExpand = function handleToggleExpand(event) {
    row.toggleExpanded();
    onMrtRowExpandChange == null ? void 0 : onMrtRowExpandChange({
      event: event,
      row: row,
      tableInstance: tableInstance
    });
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expand
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.expand,
    disabled: !row.getCanExpand() && !renderDetailPanel,
    onClick: handleToggleExpand,
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React__default.createElement(ExpandMoreIcon, {
    style: {
      transform: "rotate(" + (!row.getCanExpand() && !renderDetailPanel ? -90 : row.getIsExpanded() ? -180 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_FILTER_OPTION;

(function (MRT_FILTER_OPTION) {
  MRT_FILTER_OPTION["BETWEEN"] = "between";
  MRT_FILTER_OPTION["CONTAINS"] = "contains";
  MRT_FILTER_OPTION["EMPTY"] = "empty";
  MRT_FILTER_OPTION["ENDS_WITH"] = "endsWith";
  MRT_FILTER_OPTION["EQUALS"] = "equals";
  MRT_FILTER_OPTION["FUZZY"] = "fuzzy";
  MRT_FILTER_OPTION["GREATER_THAN"] = "greaterThan";
  MRT_FILTER_OPTION["LESS_THAN"] = "lessThan";
  MRT_FILTER_OPTION["NOT_EMPTY"] = "notEmpty";
  MRT_FILTER_OPTION["NOT_EQUALS"] = "notEquals";
  MRT_FILTER_OPTION["STARTS_WITH"] = "startsWith";
})(MRT_FILTER_OPTION || (MRT_FILTER_OPTION = {}));

var fuzzy = function fuzzy(row, columnId, value, addMeta) {
  var itemRank = matchSorterUtils.rankItem(row.getValue(columnId), value, {
    threshold: matchSorterUtils.rankings.MATCHES
  });
  addMeta(itemRank);
  return itemRank.passed;
};

fuzzy.autoRemove = function (val) {
  return !val;
};

var contains = function contains(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().includes(filterValue.toString().toLowerCase().trim());
};

contains.autoRemove = function (val) {
  return !val;
};

var startsWith = function startsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().startsWith(filterValue.toString().toLowerCase().trim());
};

startsWith.autoRemove = function (val) {
  return !val;
};

var endsWith = function endsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().endsWith(filterValue.toString().toLowerCase().trim());
};

endsWith.autoRemove = function (val) {
  return !val;
};

var equals = function equals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() === filterValue.toString().toLowerCase().trim();
};

equals.autoRemove = function (val) {
  return !val;
};

var notEquals = function notEquals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() !== filterValue.toString().toLowerCase().trim();
};

notEquals.autoRemove = function (val) {
  return !val;
};

var greaterThan = function greaterThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) >= +filterValue : row.getValue(id).toString().toLowerCase().trim() > filterValue.toString().toLowerCase().trim();
};

greaterThan.autoRemove = function (val) {
  return !val;
};

var lessThan = function lessThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) <= +filterValue : row.getValue(id).toString().toLowerCase().trim() < filterValue.toString().toLowerCase().trim();
};

lessThan.autoRemove = function (val) {
  return !val;
};

var between = function between(row, id, filterValues) {
  return (['', undefined].includes(filterValues[0]) || greaterThan(row, id, filterValues[0])) && (!isNaN(+filterValues[0]) && !isNaN(+filterValues[1]) && +filterValues[0] > +filterValues[1] || ['', undefined].includes(filterValues[1]) || lessThan(row, id, filterValues[1]));
};

between.autoRemove = function (val) {
  return !val;
};

var empty = function empty(row, id, _filterValue) {
  return !row.getValue(id).toString().trim();
};

empty.autoRemove = function (val) {
  return !val;
};

var notEmpty = function notEmpty(row, id, _filterValue) {
  return !!row.getValue(id).toString().trim();
};

notEmpty.autoRemove = function (val) {
  return !val;
};

var defaultFilterFNs = {
  between: between,
  contains: contains,
  empty: empty,
  endsWith: endsWith,
  equals: equals,
  fuzzy: fuzzy,
  greaterThan: greaterThan,
  lessThan: lessThan,
  notEmpty: notEmpty,
  notEquals: notEquals,
  startsWith: startsWith
};

var commonMenuItemStyles = {
  py: '6px',
  my: 0,
  alignItems: 'center'
};
var MRT_FilterOptionMenu = function MRT_FilterOptionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      onSelect = _ref.onSelect,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enabledGlobalFilterOptions = _tableInstance$option.enabledGlobalFilterOptions,
      localization = _tableInstance$option.localization,
      setCurrentFilterFns = tableInstance.setCurrentFilterFns,
      setCurrentGlobalFilterFn = tableInstance.setCurrentGlobalFilterFn;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      currentFilterFns = _getState.currentFilterFns,
      currentGlobalFilterFn = _getState.currentGlobalFilterFn;

  var _ref2 = header != null ? header : {},
      column = _ref2.column;

  var _ref3 = column != null ? column : {},
      columnDef = _ref3.columnDef;

  var filterOptions = React.useMemo(function () {
    return [{
      option: MRT_FILTER_OPTION.FUZZY,
      label: localization.filterFuzzy,
      divider: false,
      fn: fuzzy
    }, {
      option: MRT_FILTER_OPTION.CONTAINS,
      label: localization.filterContains,
      divider: false,
      fn: contains
    }, {
      option: MRT_FILTER_OPTION.STARTS_WITH,
      label: localization.filterStartsWith,
      divider: false,
      fn: startsWith
    }, {
      option: MRT_FILTER_OPTION.ENDS_WITH,
      label: localization.filterEndsWith,
      divider: true,
      fn: endsWith
    }, {
      option: MRT_FILTER_OPTION.EQUALS,
      label: localization.filterEquals,
      divider: false,
      fn: equals
    }, {
      option: MRT_FILTER_OPTION.NOT_EQUALS,
      label: localization.filterNotEquals,
      divider: true,
      fn: notEquals
    }, {
      option: MRT_FILTER_OPTION.BETWEEN,
      label: localization.filterBetween,
      divider: false,
      fn: between
    }, {
      option: MRT_FILTER_OPTION.GREATER_THAN,
      label: localization.filterGreaterThan,
      divider: false,
      fn: greaterThan
    }, {
      option: MRT_FILTER_OPTION.LESS_THAN,
      label: localization.filterLessThan,
      divider: true,
      fn: lessThan
    }, {
      option: MRT_FILTER_OPTION.EMPTY,
      label: localization.filterEmpty,
      divider: false,
      fn: empty
    }, {
      option: MRT_FILTER_OPTION.NOT_EMPTY,
      label: localization.filterNotEmpty,
      divider: false,
      fn: notEmpty
    }].filter(function (filterType) {
      return columnDef ? !columnDef.enabledColumnFilterOptions || columnDef.enabledColumnFilterOptions.includes(filterType.option) : (!enabledGlobalFilterOptions || enabledGlobalFilterOptions.includes(filterType.option)) && [MRT_FILTER_OPTION.FUZZY, MRT_FILTER_OPTION.CONTAINS].includes(filterType.option);
    });
  }, []);

  var handleSelectFilterType = function handleSelectFilterType(value) {
    if (header && column) {
      setCurrentFilterFns(function (prev) {
        var _extends2;

        return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = value, _extends2));
      });

      if ([MRT_FILTER_OPTION.EMPTY, MRT_FILTER_OPTION.NOT_EMPTY].includes(value)) {
        column.setFilterValue(' ');
      } else if (value === MRT_FILTER_OPTION.BETWEEN) {
        column.setFilterValue(['', '']);
      } else {
        column.setFilterValue('');
      }
    } else {
      setCurrentGlobalFilterFn(value);
    }

    setAnchorEl(null);
    onSelect == null ? void 0 : onSelect();
  };

  var filterOption = !!header ? currentFilterFns[header.id] : currentGlobalFilterFn;
  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    anchorOrigin: {
      vertical: 'center',
      horizontal: 'right'
    },
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    open: !!anchorEl,
    MenuListProps: {
      dense: isDensePadding
    }
  }, filterOptions.map(function (_ref4, index) {
    var option = _ref4.option,
        label = _ref4.label,
        divider = _ref4.divider,
        fn = _ref4.fn;
    return React__default.createElement(material.MenuItem, {
      divider: divider,
      key: index,
      onClick: function onClick() {
        return handleSelectFilterType(option);
      },
      selected: option === filterOption || fn === filterOption,
      sx: commonMenuItemStyles,
      value: option
    }, label);
  }));
};

/**
 * Create the React Context
 */ const DndContext = React.createContext({
    dragDropManager: undefined
});

// Inlined version of the `symbol-observable` polyfill
var $$observable = (function () {
  return typeof Symbol === 'function' && Symbol.observable || '@@observable';
})();

/**
 * These are private action types reserved by Redux.
 * For any unknown actions, you must return the current state.
 * If the current state is undefined, you must return the initial state.
 * Do not reference these action types directly in your code.
 */
var randomString = function randomString() {
  return Math.random().toString(36).substring(7).split('').join('.');
};

var ActionTypes = {
  INIT: "@@redux/INIT" + randomString(),
  REPLACE: "@@redux/REPLACE" + randomString(),
  PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
    return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
  }
};

/**
 * @param {any} obj The object to inspect.
 * @returns {boolean} True if the argument appears to be a plain object.
 */
function isPlainObject(obj) {
  if (typeof obj !== 'object' || obj === null) return false;
  var proto = obj;

  while (Object.getPrototypeOf(proto) !== null) {
    proto = Object.getPrototypeOf(proto);
  }

  return Object.getPrototypeOf(obj) === proto;
}

// Inlined / shortened version of `kindOf` from https://github.com/jonschlinkert/kind-of
function miniKindOf(val) {
  if (val === void 0) return 'undefined';
  if (val === null) return 'null';
  var type = typeof val;

  switch (type) {
    case 'boolean':
    case 'string':
    case 'number':
    case 'symbol':
    case 'function':
      {
        return type;
      }
  }

  if (Array.isArray(val)) return 'array';
  if (isDate(val)) return 'date';
  if (isError(val)) return 'error';
  var constructorName = ctorName(val);

  switch (constructorName) {
    case 'Symbol':
    case 'Promise':
    case 'WeakMap':
    case 'WeakSet':
    case 'Map':
    case 'Set':
      return constructorName;
  } // other


  return type.slice(8, -1).toLowerCase().replace(/\s/g, '');
}

function ctorName(val) {
  return typeof val.constructor === 'function' ? val.constructor.name : null;
}

function isError(val) {
  return val instanceof Error || typeof val.message === 'string' && val.constructor && typeof val.constructor.stackTraceLimit === 'number';
}

function isDate(val) {
  if (val instanceof Date) return true;
  return typeof val.toDateString === 'function' && typeof val.getDate === 'function' && typeof val.setDate === 'function';
}

function kindOf(val) {
  var typeOfVal = typeof val;

  {
    typeOfVal = miniKindOf(val);
  }

  return typeOfVal;
}

/**
 * @deprecated
 *
 * **We recommend using the `configureStore` method
 * of the `@reduxjs/toolkit` package**, which replaces `createStore`.
 *
 * Redux Toolkit is our recommended approach for writing Redux logic today,
 * including store setup, reducers, data fetching, and more.
 *
 * **For more details, please read this Redux docs page:**
 * **https://redux.js.org/introduction/why-rtk-is-redux-today**
 *
 * `configureStore` from Redux Toolkit is an improved version of `createStore` that
 * simplifies setup and helps avoid common bugs.
 *
 * You should not be using the `redux` core package by itself today, except for learning purposes.
 * The `createStore` method from the core `redux` package will not be removed, but we encourage
 * all users to migrate to using Redux Toolkit for all Redux code.
 *
 * If you want to use `createStore` without this visual deprecation warning, use
 * the `legacy_createStore` import instead:
 *
 * `import { legacy_createStore as createStore} from 'redux'`
 *
 */

function createStore(reducer, preloadedState, enhancer) {
  var _ref2;

  if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
    throw new Error( 'It looks like you are passing several store enhancers to ' + 'createStore(). This is not supported. Instead, compose them ' + 'together to a single function. See https://redux.js.org/tutorials/fundamentals/part-4-store#creating-a-store-with-enhancers for an example.');
  }

  if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
    enhancer = preloadedState;
    preloadedState = undefined;
  }

  if (typeof enhancer !== 'undefined') {
    if (typeof enhancer !== 'function') {
      throw new Error( "Expected the enhancer to be a function. Instead, received: '" + kindOf(enhancer) + "'");
    }

    return enhancer(createStore)(reducer, preloadedState);
  }

  if (typeof reducer !== 'function') {
    throw new Error( "Expected the root reducer to be a function. Instead, received: '" + kindOf(reducer) + "'");
  }

  var currentReducer = reducer;
  var currentState = preloadedState;
  var currentListeners = [];
  var nextListeners = currentListeners;
  var isDispatching = false;
  /**
   * This makes a shallow copy of currentListeners so we can use
   * nextListeners as a temporary list while dispatching.
   *
   * This prevents any bugs around consumers calling
   * subscribe/unsubscribe in the middle of a dispatch.
   */

  function ensureCanMutateNextListeners() {
    if (nextListeners === currentListeners) {
      nextListeners = currentListeners.slice();
    }
  }
  /**
   * Reads the state tree managed by the store.
   *
   * @returns {any} The current state tree of your application.
   */


  function getState() {
    if (isDispatching) {
      throw new Error( 'You may not call store.getState() while the reducer is executing. ' + 'The reducer has already received the state as an argument. ' + 'Pass it down from the top reducer instead of reading it from the store.');
    }

    return currentState;
  }
  /**
   * Adds a change listener. It will be called any time an action is dispatched,
   * and some part of the state tree may potentially have changed. You may then
   * call `getState()` to read the current state tree inside the callback.
   *
   * You may call `dispatch()` from a change listener, with the following
   * caveats:
   *
   * 1. The subscriptions are snapshotted just before every `dispatch()` call.
   * If you subscribe or unsubscribe while the listeners are being invoked, this
   * will not have any effect on the `dispatch()` that is currently in progress.
   * However, the next `dispatch()` call, whether nested or not, will use a more
   * recent snapshot of the subscription list.
   *
   * 2. The listener should not expect to see all state changes, as the state
   * might have been updated multiple times during a nested `dispatch()` before
   * the listener is called. It is, however, guaranteed that all subscribers
   * registered before the `dispatch()` started will be called with the latest
   * state by the time it exits.
   *
   * @param {Function} listener A callback to be invoked on every dispatch.
   * @returns {Function} A function to remove this change listener.
   */


  function subscribe(listener) {
    if (typeof listener !== 'function') {
      throw new Error( "Expected the listener to be a function. Instead, received: '" + kindOf(listener) + "'");
    }

    if (isDispatching) {
      throw new Error( 'You may not call store.subscribe() while the reducer is executing. ' + 'If you would like to be notified after the store has been updated, subscribe from a ' + 'component and invoke store.getState() in the callback to access the latest state. ' + 'See https://redux.js.org/api/store#subscribelistener for more details.');
    }

    var isSubscribed = true;
    ensureCanMutateNextListeners();
    nextListeners.push(listener);
    return function unsubscribe() {
      if (!isSubscribed) {
        return;
      }

      if (isDispatching) {
        throw new Error( 'You may not unsubscribe from a store listener while the reducer is executing. ' + 'See https://redux.js.org/api/store#subscribelistener for more details.');
      }

      isSubscribed = false;
      ensureCanMutateNextListeners();
      var index = nextListeners.indexOf(listener);
      nextListeners.splice(index, 1);
      currentListeners = null;
    };
  }
  /**
   * Dispatches an action. It is the only way to trigger a state change.
   *
   * The `reducer` function, used to create the store, will be called with the
   * current state tree and the given `action`. Its return value will
   * be considered the **next** state of the tree, and the change listeners
   * will be notified.
   *
   * The base implementation only supports plain object actions. If you want to
   * dispatch a Promise, an Observable, a thunk, or something else, you need to
   * wrap your store creating function into the corresponding middleware. For
   * example, see the documentation for the `redux-thunk` package. Even the
   * middleware will eventually dispatch plain object actions using this method.
   *
   * @param {Object} action A plain object representing “what changed”. It is
   * a good idea to keep actions serializable so you can record and replay user
   * sessions, or use the time travelling `redux-devtools`. An action must have
   * a `type` property which may not be `undefined`. It is a good idea to use
   * string constants for action types.
   *
   * @returns {Object} For convenience, the same action object you dispatched.
   *
   * Note that, if you use a custom middleware, it may wrap `dispatch()` to
   * return something else (for example, a Promise you can await).
   */


  function dispatch(action) {
    if (!isPlainObject(action)) {
      throw new Error( "Actions must be plain objects. Instead, the actual type was: '" + kindOf(action) + "'. You may need to add middleware to your store setup to handle dispatching other values, such as 'redux-thunk' to handle dispatching functions. See https://redux.js.org/tutorials/fundamentals/part-4-store#middleware and https://redux.js.org/tutorials/fundamentals/part-6-async-logic#using-the-redux-thunk-middleware for examples.");
    }

    if (typeof action.type === 'undefined') {
      throw new Error( 'Actions may not have an undefined "type" property. You may have misspelled an action type string constant.');
    }

    if (isDispatching) {
      throw new Error( 'Reducers may not dispatch actions.');
    }

    try {
      isDispatching = true;
      currentState = currentReducer(currentState, action);
    } finally {
      isDispatching = false;
    }

    var listeners = currentListeners = nextListeners;

    for (var i = 0; i < listeners.length; i++) {
      var listener = listeners[i];
      listener();
    }

    return action;
  }
  /**
   * Replaces the reducer currently used by the store to calculate the state.
   *
   * You might need this if your app implements code splitting and you want to
   * load some of the reducers dynamically. You might also need this if you
   * implement a hot reloading mechanism for Redux.
   *
   * @param {Function} nextReducer The reducer for the store to use instead.
   * @returns {void}
   */


  function replaceReducer(nextReducer) {
    if (typeof nextReducer !== 'function') {
      throw new Error( "Expected the nextReducer to be a function. Instead, received: '" + kindOf(nextReducer));
    }

    currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
    // Any reducers that existed in both the new and old rootReducer
    // will receive the previous state. This effectively populates
    // the new state tree with any relevant data from the old one.

    dispatch({
      type: ActionTypes.REPLACE
    });
  }
  /**
   * Interoperability point for observable/reactive libraries.
   * @returns {observable} A minimal observable of state changes.
   * For more information, see the observable proposal:
   * https://github.com/tc39/proposal-observable
   */


  function observable() {
    var _ref;

    var outerSubscribe = subscribe;
    return _ref = {
      /**
       * The minimal observable subscription method.
       * @param {Object} observer Any object that can be used as an observer.
       * The observer object should have a `next` method.
       * @returns {subscription} An object with an `unsubscribe` method that can
       * be used to unsubscribe the observable from the store, and prevent further
       * emission of values from the observable.
       */
      subscribe: function subscribe(observer) {
        if (typeof observer !== 'object' || observer === null) {
          throw new Error( "Expected the observer to be an object. Instead, received: '" + kindOf(observer) + "'");
        }

        function observeState() {
          if (observer.next) {
            observer.next(getState());
          }
        }

        observeState();
        var unsubscribe = outerSubscribe(observeState);
        return {
          unsubscribe: unsubscribe
        };
      }
    }, _ref[$$observable] = function () {
      return this;
    }, _ref;
  } // When a store is created, an "INIT" action is dispatched so that every
  // reducer returns their initial state. This effectively populates
  // the initial state tree.


  dispatch({
    type: ActionTypes.INIT
  });
  return _ref2 = {
    dispatch: dispatch,
    subscribe: subscribe,
    getState: getState,
    replaceReducer: replaceReducer
  }, _ref2[$$observable] = observable, _ref2;
}

/**
 * Prints a warning in the console if it exists.
 *
 * @param {String} message The warning message.
 * @returns {void}
 */
function warning(message) {
  /* eslint-disable no-console */
  if (typeof console !== 'undefined' && typeof console.error === 'function') {
    console.error(message);
  }
  /* eslint-enable no-console */


  try {
    // This error was thrown as a convenience so that if you enable
    // "break on all exceptions" in your console,
    // it would pause the execution at this line.
    throw new Error(message);
  } catch (e) {} // eslint-disable-line no-empty

}

/*
 * This is a dummy function to check if the function name has been altered by minification.
 * If the function has been minified and NODE_ENV !== 'production', warn the user.
 */

function isCrushed() {}

if ( typeof isCrushed.name === 'string' && isCrushed.name !== 'isCrushed') {
  warning('You are currently using minified code outside of NODE_ENV === "production". ' + 'This means that you are running a slower development build of Redux. ' + 'You can use loose-envify (https://github.com/zertosh/loose-envify) for browserify ' + 'or setting mode to production in webpack (https://webpack.js.org/concepts/mode/) ' + 'to ensure you have the correct code for your production build.');
}

/**
 * Use invariant() to assert state which your program assumes to be true.
 *
 * Provide sprintf-style format (only %s is supported) and arguments
 * to provide information about what broke and what you were
 * expecting.
 *
 * The invariant message will be stripped in production, but the invariant
 * will remain to ensure logic does not differ in production.
 */ function invariant(condition, format, ...args) {
    if (isProduction()) {
        if (format === undefined) {
            throw new Error('invariant requires an error message argument');
        }
    }
    if (!condition) {
        let error;
        if (format === undefined) {
            error = new Error('Minified exception occurred; use the non-minified dev environment ' + 'for the full error message and additional helpful warnings.');
        } else {
            let argIndex = 0;
            error = new Error(format.replace(/%s/g, function() {
                return args[argIndex++];
            }));
            error.name = 'Invariant Violation';
        }
        error.framesToPop = 1 // we don't care about invariant's own frame
        ;
        throw error;
    }
}
function isProduction() {
    return typeof process !== 'undefined' && process.env['NODE_ENV'] === 'production';
}

// cheap lodash replacements
/**
 * drop-in replacement for _.get
 * @param obj
 * @param path
 * @param defaultValue
 */ function get(obj, path, defaultValue) {
    return path.split('.').reduce((a, c)=>a && a[c] ? a[c] : defaultValue || null
    , obj);
}
/**
 * drop-in replacement for _.without
 */ function without(items, item) {
    return items.filter((i)=>i !== item
    );
}
/**
 * drop-in replacement for _.isString
 * @param input
 */ function isObject(input) {
    return typeof input === 'object';
}
/**
 * replacement for _.xor
 * @param itemsA
 * @param itemsB
 */ function xor(itemsA, itemsB) {
    const map = new Map();
    const insertItem = (item)=>{
        map.set(item, map.has(item) ? map.get(item) + 1 : 1);
    };
    itemsA.forEach(insertItem);
    itemsB.forEach(insertItem);
    const result = [];
    map.forEach((count, key)=>{
        if (count === 1) {
            result.push(key);
        }
    });
    return result;
}
/**
 * replacement for _.intersection
 * @param itemsA
 * @param itemsB
 */ function intersection(itemsA, itemsB) {
    return itemsA.filter((t)=>itemsB.indexOf(t) > -1
    );
}

const INIT_COORDS = 'dnd-core/INIT_COORDS';
const BEGIN_DRAG = 'dnd-core/BEGIN_DRAG';
const PUBLISH_DRAG_SOURCE = 'dnd-core/PUBLISH_DRAG_SOURCE';
const HOVER = 'dnd-core/HOVER';
const DROP = 'dnd-core/DROP';
const END_DRAG = 'dnd-core/END_DRAG';

function setClientOffset(clientOffset, sourceClientOffset) {
    return {
        type: INIT_COORDS,
        payload: {
            sourceClientOffset: sourceClientOffset || null,
            clientOffset: clientOffset || null
        }
    };
}

const ResetCoordinatesAction = {
    type: INIT_COORDS,
    payload: {
        clientOffset: null,
        sourceClientOffset: null
    }
};
function createBeginDrag(manager) {
    return function beginDrag(sourceIds = [], options = {
        publishSource: true
    }) {
        const { publishSource =true , clientOffset , getSourceClientOffset ,  } = options;
        const monitor = manager.getMonitor();
        const registry = manager.getRegistry();
        // Initialize the coordinates using the client offset
        manager.dispatch(setClientOffset(clientOffset));
        verifyInvariants(sourceIds, monitor, registry);
        // Get the draggable source
        const sourceId = getDraggableSource(sourceIds, monitor);
        if (sourceId == null) {
            manager.dispatch(ResetCoordinatesAction);
            return;
        }
        // Get the source client offset
        let sourceClientOffset = null;
        if (clientOffset) {
            if (!getSourceClientOffset) {
                throw new Error('getSourceClientOffset must be defined');
            }
            verifyGetSourceClientOffsetIsFunction(getSourceClientOffset);
            sourceClientOffset = getSourceClientOffset(sourceId);
        }
        // Initialize the full coordinates
        manager.dispatch(setClientOffset(clientOffset, sourceClientOffset));
        const source = registry.getSource(sourceId);
        const item = source.beginDrag(monitor, sourceId);
        // If source.beginDrag returns null, this is an indicator to cancel the drag
        if (item == null) {
            return undefined;
        }
        verifyItemIsObject(item);
        registry.pinSource(sourceId);
        const itemType = registry.getSourceType(sourceId);
        return {
            type: BEGIN_DRAG,
            payload: {
                itemType,
                item,
                sourceId,
                clientOffset: clientOffset || null,
                sourceClientOffset: sourceClientOffset || null,
                isSourcePublic: !!publishSource
            }
        };
    };
}
function verifyInvariants(sourceIds, monitor, registry) {
    invariant(!monitor.isDragging(), 'Cannot call beginDrag while dragging.');
    sourceIds.forEach(function(sourceId) {
        invariant(registry.getSource(sourceId), 'Expected sourceIds to be registered.');
    });
}
function verifyGetSourceClientOffsetIsFunction(getSourceClientOffset) {
    invariant(typeof getSourceClientOffset === 'function', 'When clientOffset is provided, getSourceClientOffset must be a function.');
}
function verifyItemIsObject(item) {
    invariant(isObject(item), 'Item must be an object.');
}
function getDraggableSource(sourceIds, monitor) {
    let sourceId = null;
    for(let i = sourceIds.length - 1; i >= 0; i--){
        if (monitor.canDragSource(sourceIds[i])) {
            sourceId = sourceIds[i];
            break;
        }
    }
    return sourceId;
}

function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function createDrop(manager) {
    return function drop(options = {}) {
        const monitor = manager.getMonitor();
        const registry = manager.getRegistry();
        verifyInvariants$1(monitor);
        const targetIds = getDroppableTargets(monitor);
        // Multiple actions are dispatched here, which is why this doesn't return an action
        targetIds.forEach((targetId, index)=>{
            const dropResult = determineDropResult(targetId, index, registry, monitor);
            const action = {
                type: DROP,
                payload: {
                    dropResult: _objectSpread({}, options, dropResult)
                }
            };
            manager.dispatch(action);
        });
    };
}
function verifyInvariants$1(monitor) {
    invariant(monitor.isDragging(), 'Cannot call drop while not dragging.');
    invariant(!monitor.didDrop(), 'Cannot call drop twice during one drag operation.');
}
function determineDropResult(targetId, index, registry, monitor) {
    const target = registry.getTarget(targetId);
    let dropResult = target ? target.drop(monitor, targetId) : undefined;
    verifyDropResultType(dropResult);
    if (typeof dropResult === 'undefined') {
        dropResult = index === 0 ? {} : monitor.getDropResult();
    }
    return dropResult;
}
function verifyDropResultType(dropResult) {
    invariant(typeof dropResult === 'undefined' || isObject(dropResult), 'Drop result must either be an object or undefined.');
}
function getDroppableTargets(monitor) {
    const targetIds = monitor.getTargetIds().filter(monitor.canDropOnTarget, monitor);
    targetIds.reverse();
    return targetIds;
}

function createEndDrag(manager) {
    return function endDrag() {
        const monitor = manager.getMonitor();
        const registry = manager.getRegistry();
        verifyIsDragging(monitor);
        const sourceId = monitor.getSourceId();
        if (sourceId != null) {
            const source = registry.getSource(sourceId, true);
            source.endDrag(monitor, sourceId);
            registry.unpinSource();
        }
        return {
            type: END_DRAG
        };
    };
}
function verifyIsDragging(monitor) {
    invariant(monitor.isDragging(), 'Cannot call endDrag while not dragging.');
}

function matchesType(targetType, draggedItemType) {
    if (draggedItemType === null) {
        return targetType === null;
    }
    return Array.isArray(targetType) ? targetType.some((t)=>t === draggedItemType
    ) : targetType === draggedItemType;
}

function createHover(manager) {
    return function hover(targetIdsArg, { clientOffset  } = {}) {
        verifyTargetIdsIsArray(targetIdsArg);
        const targetIds = targetIdsArg.slice(0);
        const monitor = manager.getMonitor();
        const registry = manager.getRegistry();
        const draggedItemType = monitor.getItemType();
        removeNonMatchingTargetIds(targetIds, registry, draggedItemType);
        checkInvariants(targetIds, monitor, registry);
        hoverAllTargets(targetIds, monitor, registry);
        return {
            type: HOVER,
            payload: {
                targetIds,
                clientOffset: clientOffset || null
            }
        };
    };
}
function verifyTargetIdsIsArray(targetIdsArg) {
    invariant(Array.isArray(targetIdsArg), 'Expected targetIds to be an array.');
}
function checkInvariants(targetIds, monitor, registry) {
    invariant(monitor.isDragging(), 'Cannot call hover while not dragging.');
    invariant(!monitor.didDrop(), 'Cannot call hover after drop.');
    for(let i = 0; i < targetIds.length; i++){
        const targetId = targetIds[i];
        invariant(targetIds.lastIndexOf(targetId) === i, 'Expected targetIds to be unique in the passed array.');
        const target = registry.getTarget(targetId);
        invariant(target, 'Expected targetIds to be registered.');
    }
}
function removeNonMatchingTargetIds(targetIds, registry, draggedItemType) {
    // Remove those targetIds that don't match the targetType.  This
    // fixes shallow isOver which would only be non-shallow because of
    // non-matching targets.
    for(let i = targetIds.length - 1; i >= 0; i--){
        const targetId = targetIds[i];
        const targetType = registry.getTargetType(targetId);
        if (!matchesType(targetType, draggedItemType)) {
            targetIds.splice(i, 1);
        }
    }
}
function hoverAllTargets(targetIds, monitor, registry) {
    // Finally call hover on all matching targets.
    targetIds.forEach(function(targetId) {
        const target = registry.getTarget(targetId);
        target.hover(monitor, targetId);
    });
}

function createPublishDragSource(manager) {
    return function publishDragSource() {
        const monitor = manager.getMonitor();
        if (monitor.isDragging()) {
            return {
                type: PUBLISH_DRAG_SOURCE
            };
        }
        return;
    };
}

function createDragDropActions(manager) {
    return {
        beginDrag: createBeginDrag(manager),
        publishDragSource: createPublishDragSource(manager),
        hover: createHover(manager),
        drop: createDrop(manager),
        endDrag: createEndDrag(manager)
    };
}

class DragDropManagerImpl {
    receiveBackend(backend) {
        this.backend = backend;
    }
    getMonitor() {
        return this.monitor;
    }
    getBackend() {
        return this.backend;
    }
    getRegistry() {
        return this.monitor.registry;
    }
    getActions() {
        /* eslint-disable-next-line @typescript-eslint/no-this-alias */ const manager = this;
        const { dispatch  } = this.store;
        function bindActionCreator(actionCreator) {
            return (...args)=>{
                const action = actionCreator.apply(manager, args);
                if (typeof action !== 'undefined') {
                    dispatch(action);
                }
            };
        }
        const actions = createDragDropActions(this);
        return Object.keys(actions).reduce((boundActions, key)=>{
            const action = actions[key];
            boundActions[key] = bindActionCreator(action);
            return boundActions;
        }, {});
    }
    dispatch(action) {
        this.store.dispatch(action);
    }
    constructor(store, monitor){
        this.isSetUp = false;
        this.handleRefCountChange = ()=>{
            const shouldSetUp = this.store.getState().refCount > 0;
            if (this.backend) {
                if (shouldSetUp && !this.isSetUp) {
                    this.backend.setup();
                    this.isSetUp = true;
                } else if (!shouldSetUp && this.isSetUp) {
                    this.backend.teardown();
                    this.isSetUp = false;
                }
            }
        };
        this.store = store;
        this.monitor = monitor;
        store.subscribe(this.handleRefCountChange);
    }
}

/**
 * Coordinate addition
 * @param a The first coordinate
 * @param b The second coordinate
 */ function add(a, b) {
    return {
        x: a.x + b.x,
        y: a.y + b.y
    };
}
/**
 * Coordinate subtraction
 * @param a The first coordinate
 * @param b The second coordinate
 */ function subtract(a, b) {
    return {
        x: a.x - b.x,
        y: a.y - b.y
    };
}
/**
 * Returns the cartesian distance of the drag source component's position, based on its position
 * at the time when the current drag operation has started, and the movement difference.
 *
 * Returns null if no item is being dragged.
 *
 * @param state The offset state to compute from
 */ function getSourceClientOffset(state) {
    const { clientOffset , initialClientOffset , initialSourceClientOffset  } = state;
    if (!clientOffset || !initialClientOffset || !initialSourceClientOffset) {
        return null;
    }
    return subtract(add(clientOffset, initialSourceClientOffset), initialClientOffset);
}
/**
 * Determines the x,y offset between the client offset and the initial client offset
 *
 * @param state The offset state to compute from
 */ function getDifferenceFromInitialOffset(state) {
    const { clientOffset , initialClientOffset  } = state;
    if (!clientOffset || !initialClientOffset) {
        return null;
    }
    return subtract(clientOffset, initialClientOffset);
}

const NONE = [];
const ALL = [];
NONE.__IS_NONE__ = true;
ALL.__IS_ALL__ = true;
/**
 * Determines if the given handler IDs are dirty or not.
 *
 * @param dirtyIds The set of dirty handler ids
 * @param handlerIds The set of handler ids to check
 */ function areDirty(dirtyIds, handlerIds) {
    if (dirtyIds === NONE) {
        return false;
    }
    if (dirtyIds === ALL || typeof handlerIds === 'undefined') {
        return true;
    }
    const commonIds = intersection(handlerIds, dirtyIds);
    return commonIds.length > 0;
}

class DragDropMonitorImpl {
    subscribeToStateChange(listener, options = {}) {
        const { handlerIds  } = options;
        invariant(typeof listener === 'function', 'listener must be a function.');
        invariant(typeof handlerIds === 'undefined' || Array.isArray(handlerIds), 'handlerIds, when specified, must be an array of strings.');
        let prevStateId = this.store.getState().stateId;
        const handleChange = ()=>{
            const state = this.store.getState();
            const currentStateId = state.stateId;
            try {
                const canSkipListener = currentStateId === prevStateId || currentStateId === prevStateId + 1 && !areDirty(state.dirtyHandlerIds, handlerIds);
                if (!canSkipListener) {
                    listener();
                }
            } finally{
                prevStateId = currentStateId;
            }
        };
        return this.store.subscribe(handleChange);
    }
    subscribeToOffsetChange(listener) {
        invariant(typeof listener === 'function', 'listener must be a function.');
        let previousState = this.store.getState().dragOffset;
        const handleChange = ()=>{
            const nextState = this.store.getState().dragOffset;
            if (nextState === previousState) {
                return;
            }
            previousState = nextState;
            listener();
        };
        return this.store.subscribe(handleChange);
    }
    canDragSource(sourceId) {
        if (!sourceId) {
            return false;
        }
        const source = this.registry.getSource(sourceId);
        invariant(source, `Expected to find a valid source. sourceId=${sourceId}`);
        if (this.isDragging()) {
            return false;
        }
        return source.canDrag(this, sourceId);
    }
    canDropOnTarget(targetId) {
        // undefined on initial render
        if (!targetId) {
            return false;
        }
        const target = this.registry.getTarget(targetId);
        invariant(target, `Expected to find a valid target. targetId=${targetId}`);
        if (!this.isDragging() || this.didDrop()) {
            return false;
        }
        const targetType = this.registry.getTargetType(targetId);
        const draggedItemType = this.getItemType();
        return matchesType(targetType, draggedItemType) && target.canDrop(this, targetId);
    }
    isDragging() {
        return Boolean(this.getItemType());
    }
    isDraggingSource(sourceId) {
        // undefined on initial render
        if (!sourceId) {
            return false;
        }
        const source = this.registry.getSource(sourceId, true);
        invariant(source, `Expected to find a valid source. sourceId=${sourceId}`);
        if (!this.isDragging() || !this.isSourcePublic()) {
            return false;
        }
        const sourceType = this.registry.getSourceType(sourceId);
        const draggedItemType = this.getItemType();
        if (sourceType !== draggedItemType) {
            return false;
        }
        return source.isDragging(this, sourceId);
    }
    isOverTarget(targetId, options = {
        shallow: false
    }) {
        // undefined on initial render
        if (!targetId) {
            return false;
        }
        const { shallow  } = options;
        if (!this.isDragging()) {
            return false;
        }
        const targetType = this.registry.getTargetType(targetId);
        const draggedItemType = this.getItemType();
        if (draggedItemType && !matchesType(targetType, draggedItemType)) {
            return false;
        }
        const targetIds = this.getTargetIds();
        if (!targetIds.length) {
            return false;
        }
        const index = targetIds.indexOf(targetId);
        if (shallow) {
            return index === targetIds.length - 1;
        } else {
            return index > -1;
        }
    }
    getItemType() {
        return this.store.getState().dragOperation.itemType;
    }
    getItem() {
        return this.store.getState().dragOperation.item;
    }
    getSourceId() {
        return this.store.getState().dragOperation.sourceId;
    }
    getTargetIds() {
        return this.store.getState().dragOperation.targetIds;
    }
    getDropResult() {
        return this.store.getState().dragOperation.dropResult;
    }
    didDrop() {
        return this.store.getState().dragOperation.didDrop;
    }
    isSourcePublic() {
        return Boolean(this.store.getState().dragOperation.isSourcePublic);
    }
    getInitialClientOffset() {
        return this.store.getState().dragOffset.initialClientOffset;
    }
    getInitialSourceClientOffset() {
        return this.store.getState().dragOffset.initialSourceClientOffset;
    }
    getClientOffset() {
        return this.store.getState().dragOffset.clientOffset;
    }
    getSourceClientOffset() {
        return getSourceClientOffset(this.store.getState().dragOffset);
    }
    getDifferenceFromInitialOffset() {
        return getDifferenceFromInitialOffset(this.store.getState().dragOffset);
    }
    constructor(store, registry){
        this.store = store;
        this.registry = registry;
    }
}

// Safari 6 and 6.1 for desktop, iPad, and iPhone are the only browsers that
// have WebKitMutationObserver but not un-prefixed MutationObserver.
// Must use `global` or `self` instead of `window` to work in both frames and web
// workers. `global` is a provision of Browserify, Mr, Mrs, or Mop.
/* globals self */ const scope = typeof global !== 'undefined' ? global : self;
const BrowserMutationObserver = scope.MutationObserver || scope.WebKitMutationObserver;
function makeRequestCallFromTimer(callback) {
    return function requestCall() {
        // We dispatch a timeout with a specified delay of 0 for engines that
        // can reliably accommodate that request. This will usually be snapped
        // to a 4 milisecond delay, but once we're flushing, there's no delay
        // between events.
        const timeoutHandle = setTimeout(handleTimer, 0);
        // However, since this timer gets frequently dropped in Firefox
        // workers, we enlist an interval handle that will try to fire
        // an event 20 times per second until it succeeds.
        const intervalHandle = setInterval(handleTimer, 50);
        function handleTimer() {
            // Whichever timer succeeds will cancel both timers and
            // execute the callback.
            clearTimeout(timeoutHandle);
            clearInterval(intervalHandle);
            callback();
        }
    };
}
// To request a high priority event, we induce a mutation observer by toggling
// the text of a text node between "1" and "-1".
function makeRequestCallFromMutationObserver(callback) {
    let toggle = 1;
    const observer = new BrowserMutationObserver(callback);
    const node = document.createTextNode('');
    observer.observe(node, {
        characterData: true
    });
    return function requestCall() {
        toggle = -toggle;
        node.data = toggle;
    };
}
const makeRequestCall = typeof BrowserMutationObserver === 'function' ? // reliably everywhere they are implemented.
// They are implemented in all modern browsers.
//
// - Android 4-4.3
// - Chrome 26-34
// - Firefox 14-29
// - Internet Explorer 11
// - iPad Safari 6-7.1
// - iPhone Safari 7-7.1
// - Safari 6-7
makeRequestCallFromMutationObserver : // task queue, are implemented in Internet Explorer 10, Safari 5.0-1, and Opera
// 11-12, and in web workers in many engines.
// Although message channels yield to any queued rendering and IO tasks, they
// would be better than imposing the 4ms delay of timers.
// However, they do not work reliably in Internet Explorer or Safari.
// Internet Explorer 10 is the only browser that has setImmediate but does
// not have MutationObservers.
// Although setImmediate yields to the browser's renderer, it would be
// preferrable to falling back to setTimeout since it does not have
// the minimum 4ms penalty.
// Unfortunately there appears to be a bug in Internet Explorer 10 Mobile (and
// Desktop to a lesser extent) that renders both setImmediate and
// MessageChannel useless for the purposes of ASAP.
// https://github.com/kriskowal/q/issues/396
// Timers are implemented universally.
// We fall back to timers in workers in most engines, and in foreground
// contexts in the following browsers.
// However, note that even this simple case requires nuances to operate in a
// broad spectrum of browsers.
//
// - Firefox 3-13
// - Internet Explorer 6-9
// - iPad Safari 4.3
// - Lynx 2.8.7
makeRequestCallFromTimer;

class AsapQueue {
    // Use the fastest means possible to execute a task in its own turn, with
    // priority over other events including IO, animation, reflow, and redraw
    // events in browsers.
    //
    // An exception thrown by a task will permanently interrupt the processing of
    // subsequent tasks. The higher level `asap` function ensures that if an
    // exception is thrown by a task, that the task queue will continue flushing as
    // soon as possible, but if you use `rawAsap` directly, you are responsible to
    // either ensure that no exceptions are thrown from your task, or to manually
    // call `rawAsap.requestFlush` if an exception is thrown.
    enqueueTask(task) {
        const { queue: q , requestFlush  } = this;
        if (!q.length) {
            requestFlush();
            this.flushing = true;
        }
        // Equivalent to push, but avoids a function call.
        q[q.length] = task;
    }
    constructor(){
        this.queue = [];
        // We queue errors to ensure they are thrown in right order (FIFO).
        // Array-as-queue is good enough here, since we are just dealing with exceptions.
        this.pendingErrors = [];
        // Once a flush has been requested, no further calls to `requestFlush` are
        // necessary until the next `flush` completes.
        // @ts-ignore
        this.flushing = false;
        // The position of the next task to execute in the task queue. This is
        // preserved between calls to `flush` so that it can be resumed if
        // a task throws an exception.
        this.index = 0;
        // If a task schedules additional tasks recursively, the task queue can grow
        // unbounded. To prevent memory exhaustion, the task queue will periodically
        // truncate already-completed tasks.
        this.capacity = 1024;
        // The flush function processes all tasks that have been scheduled with
        // `rawAsap` unless and until one of those tasks throws an exception.
        // If a task throws an exception, `flush` ensures that its state will remain
        // consistent and will resume where it left off when called again.
        // However, `flush` does not make any arrangements to be called again if an
        // exception is thrown.
        this.flush = ()=>{
            const { queue: q  } = this;
            while(this.index < q.length){
                const currentIndex = this.index;
                // Advance the index before calling the task. This ensures that we will
                // begin flushing on the next task the task throws an error.
                this.index++;
                q[currentIndex].call();
                // Prevent leaking memory for long chains of recursive calls to `asap`.
                // If we call `asap` within tasks scheduled by `asap`, the queue will
                // grow, but to avoid an O(n) walk for every task we execute, we don't
                // shift tasks off the queue after they have been executed.
                // Instead, we periodically shift 1024 tasks off the queue.
                if (this.index > this.capacity) {
                    // Manually shift all values starting at the index back to the
                    // beginning of the queue.
                    for(let scan = 0, newLength = q.length - this.index; scan < newLength; scan++){
                        q[scan] = q[scan + this.index];
                    }
                    q.length -= this.index;
                    this.index = 0;
                }
            }
            q.length = 0;
            this.index = 0;
            this.flushing = false;
        };
        // In a web browser, exceptions are not fatal. However, to avoid
        // slowing down the queue of pending tasks, we rethrow the error in a
        // lower priority turn.
        this.registerPendingError = (err)=>{
            this.pendingErrors.push(err);
            this.requestErrorThrow();
        };
        // `requestFlush` requests that the high priority event queue be flushed as
        // soon as possible.
        // This is useful to prevent an error thrown in a task from stalling the event
        // queue if the exception handled by Node.js’s
        // `process.on("uncaughtException")` or by a domain.
        // `requestFlush` is implemented using a strategy based on data collected from
        // every available SauceLabs Selenium web driver worker at time of writing.
        // https://docs.google.com/spreadsheets/d/1mG-5UYGup5qxGdEMWkhP6BWCz053NUb2E1QoUTU16uA/edit#gid=783724593
        this.requestFlush = makeRequestCall(this.flush);
        this.requestErrorThrow = makeRequestCallFromTimer(()=>{
            // Throw first error
            if (this.pendingErrors.length) {
                throw this.pendingErrors.shift();
            }
        });
    }
} // The message channel technique was discovered by Malte Ubl and was the
 // original foundation for this library.
 // http://www.nonblocking.io/2011/06/windownexttick.html
 // Safari 6.0.5 (at least) intermittently fails to create message ports on a
 // page's first load. Thankfully, this version of Safari supports
 // MutationObservers, so we don't need to fall back in that case.
 // function makeRequestCallFromMessageChannel(callback) {
 //     var channel = new MessageChannel();
 //     channel.port1.onmessage = callback;
 //     return function requestCall() {
 //         channel.port2.postMessage(0);
 //     };
 // }
 // For reasons explained above, we are also unable to use `setImmediate`
 // under any circumstances.
 // Even if we were, there is another bug in Internet Explorer 10.
 // It is not sufficient to assign `setImmediate` to `requestFlush` because
 // `setImmediate` must be called *by name* and therefore must be wrapped in a
 // closure.
 // Never forget.
 // function makeRequestCallFromSetImmediate(callback) {
 //     return function requestCall() {
 //         setImmediate(callback);
 //     };
 // }
 // Safari 6.0 has a problem where timers will get lost while the user is
 // scrolling. This problem does not impact ASAP because Safari 6.0 supports
 // mutation observers, so that implementation is used instead.
 // However, if we ever elect to use timers in Safari, the prevalent work-around
 // is to add a scroll event listener that calls for a flush.
 // `setTimeout` does not call the passed callback if the delay is less than
 // approximately 7 in web workers in Firefox 8 through 18, and sometimes not
 // even then.
 // This is for `asap.js` only.
 // Its name will be periodically randomized to break any code that depends on
 // // its existence.
 // rawAsap.makeRequestCallFromTimer = makeRequestCallFromTimer
 // ASAP was originally a nextTick shim included in Q. This was factored out
 // into this ASAP package. It was later adapted to RSVP which made further
 // amendments. These decisions, particularly to marginalize MessageChannel and
 // to capture the MutationObserver implementation in a closure, were integrated
 // back into ASAP proper.
 // https://github.com/tildeio/rsvp.js/blob/cddf7232546a9cf858524b75cde6f9edf72620a7/lib/rsvp/asap.js

// `call`, just like a function.
class RawTask {
    call() {
        try {
            this.task && this.task();
        } catch (error) {
            this.onError(error);
        } finally{
            this.task = null;
            this.release(this);
        }
    }
    constructor(onError, release){
        this.onError = onError;
        this.release = release;
        this.task = null;
    }
}

class TaskFactory {
    create(task) {
        const tasks = this.freeTasks;
        const t1 = tasks.length ? tasks.pop() : new RawTask(this.onError, (t)=>tasks[tasks.length] = t
        );
        t1.task = task;
        return t1;
    }
    constructor(onError){
        this.onError = onError;
        this.freeTasks = [];
    }
}

const asapQueue = new AsapQueue();
const taskFactory = new TaskFactory(asapQueue.registerPendingError);
/**
 * Calls a task as soon as possible after returning, in its own event, with priority
 * over other events like animation, reflow, and repaint. An error thrown from an
 * event will not interrupt, nor even substantially slow down the processing of
 * other events, but will be rather postponed to a lower priority event.
 * @param {{call}} task A callable object, typically a function that takes no
 * arguments.
 */ function asap(task) {
    asapQueue.enqueueTask(taskFactory.create(task));
}

const ADD_SOURCE = 'dnd-core/ADD_SOURCE';
const ADD_TARGET = 'dnd-core/ADD_TARGET';
const REMOVE_SOURCE = 'dnd-core/REMOVE_SOURCE';
const REMOVE_TARGET = 'dnd-core/REMOVE_TARGET';
function addSource(sourceId) {
    return {
        type: ADD_SOURCE,
        payload: {
            sourceId
        }
    };
}
function addTarget(targetId) {
    return {
        type: ADD_TARGET,
        payload: {
            targetId
        }
    };
}
function removeSource(sourceId) {
    return {
        type: REMOVE_SOURCE,
        payload: {
            sourceId
        }
    };
}
function removeTarget(targetId) {
    return {
        type: REMOVE_TARGET,
        payload: {
            targetId
        }
    };
}

function validateSourceContract(source) {
    invariant(typeof source.canDrag === 'function', 'Expected canDrag to be a function.');
    invariant(typeof source.beginDrag === 'function', 'Expected beginDrag to be a function.');
    invariant(typeof source.endDrag === 'function', 'Expected endDrag to be a function.');
}
function validateTargetContract(target) {
    invariant(typeof target.canDrop === 'function', 'Expected canDrop to be a function.');
    invariant(typeof target.hover === 'function', 'Expected hover to be a function.');
    invariant(typeof target.drop === 'function', 'Expected beginDrag to be a function.');
}
function validateType(type, allowArray) {
    if (allowArray && Array.isArray(type)) {
        type.forEach((t)=>validateType(t, false)
        );
        return;
    }
    invariant(typeof type === 'string' || typeof type === 'symbol', allowArray ? 'Type can only be a string, a symbol, or an array of either.' : 'Type can only be a string or a symbol.');
}

var HandlerRole;
(function(HandlerRole) {
    HandlerRole["SOURCE"] = "SOURCE";
    HandlerRole["TARGET"] = "TARGET";
})(HandlerRole || (HandlerRole = {}));

let nextUniqueId = 0;
function getNextUniqueId() {
    return nextUniqueId++;
}

function getNextHandlerId(role) {
    const id = getNextUniqueId().toString();
    switch(role){
        case HandlerRole.SOURCE:
            return `S${id}`;
        case HandlerRole.TARGET:
            return `T${id}`;
        default:
            throw new Error(`Unknown Handler Role: ${role}`);
    }
}
function parseRoleFromHandlerId(handlerId) {
    switch(handlerId[0]){
        case 'S':
            return HandlerRole.SOURCE;
        case 'T':
            return HandlerRole.TARGET;
        default:
            throw new Error(`Cannot parse handler ID: ${handlerId}`);
    }
}
function mapContainsValue(map, searchValue) {
    const entries = map.entries();
    let isDone = false;
    do {
        const { done , value: [, value] ,  } = entries.next();
        if (value === searchValue) {
            return true;
        }
        isDone = !!done;
    }while (!isDone)
    return false;
}
class HandlerRegistryImpl {
    addSource(type, source) {
        validateType(type);
        validateSourceContract(source);
        const sourceId = this.addHandler(HandlerRole.SOURCE, type, source);
        this.store.dispatch(addSource(sourceId));
        return sourceId;
    }
    addTarget(type, target) {
        validateType(type, true);
        validateTargetContract(target);
        const targetId = this.addHandler(HandlerRole.TARGET, type, target);
        this.store.dispatch(addTarget(targetId));
        return targetId;
    }
    containsHandler(handler) {
        return mapContainsValue(this.dragSources, handler) || mapContainsValue(this.dropTargets, handler);
    }
    getSource(sourceId, includePinned = false) {
        invariant(this.isSourceId(sourceId), 'Expected a valid source ID.');
        const isPinned = includePinned && sourceId === this.pinnedSourceId;
        const source = isPinned ? this.pinnedSource : this.dragSources.get(sourceId);
        return source;
    }
    getTarget(targetId) {
        invariant(this.isTargetId(targetId), 'Expected a valid target ID.');
        return this.dropTargets.get(targetId);
    }
    getSourceType(sourceId) {
        invariant(this.isSourceId(sourceId), 'Expected a valid source ID.');
        return this.types.get(sourceId);
    }
    getTargetType(targetId) {
        invariant(this.isTargetId(targetId), 'Expected a valid target ID.');
        return this.types.get(targetId);
    }
    isSourceId(handlerId) {
        const role = parseRoleFromHandlerId(handlerId);
        return role === HandlerRole.SOURCE;
    }
    isTargetId(handlerId) {
        const role = parseRoleFromHandlerId(handlerId);
        return role === HandlerRole.TARGET;
    }
    removeSource(sourceId) {
        invariant(this.getSource(sourceId), 'Expected an existing source.');
        this.store.dispatch(removeSource(sourceId));
        asap(()=>{
            this.dragSources.delete(sourceId);
            this.types.delete(sourceId);
        });
    }
    removeTarget(targetId) {
        invariant(this.getTarget(targetId), 'Expected an existing target.');
        this.store.dispatch(removeTarget(targetId));
        this.dropTargets.delete(targetId);
        this.types.delete(targetId);
    }
    pinSource(sourceId) {
        const source = this.getSource(sourceId);
        invariant(source, 'Expected an existing source.');
        this.pinnedSourceId = sourceId;
        this.pinnedSource = source;
    }
    unpinSource() {
        invariant(this.pinnedSource, 'No source is pinned at the time.');
        this.pinnedSourceId = null;
        this.pinnedSource = null;
    }
    addHandler(role, type, handler) {
        const id = getNextHandlerId(role);
        this.types.set(id, type);
        if (role === HandlerRole.SOURCE) {
            this.dragSources.set(id, handler);
        } else if (role === HandlerRole.TARGET) {
            this.dropTargets.set(id, handler);
        }
        return id;
    }
    constructor(store){
        this.types = new Map();
        this.dragSources = new Map();
        this.dropTargets = new Map();
        this.pinnedSourceId = null;
        this.pinnedSource = null;
        this.store = store;
    }
}

const strictEquality = (a, b)=>a === b
;
/**
 * Determine if two cartesian coordinate offsets are equal
 * @param offsetA
 * @param offsetB
 */ function areCoordsEqual(offsetA, offsetB) {
    if (!offsetA && !offsetB) {
        return true;
    } else if (!offsetA || !offsetB) {
        return false;
    } else {
        return offsetA.x === offsetB.x && offsetA.y === offsetB.y;
    }
}
/**
 * Determines if two arrays of items are equal
 * @param a The first array of items
 * @param b The second array of items
 */ function areArraysEqual(a, b, isEqual = strictEquality) {
    if (a.length !== b.length) {
        return false;
    }
    for(let i = 0; i < a.length; ++i){
        if (!isEqual(a[i], b[i])) {
            return false;
        }
    }
    return true;
}

function reduce(// eslint-disable-next-line @typescript-eslint/no-unused-vars
_state = NONE, action) {
    switch(action.type){
        case HOVER:
            break;
        case ADD_SOURCE:
        case ADD_TARGET:
        case REMOVE_TARGET:
        case REMOVE_SOURCE:
            return NONE;
        case BEGIN_DRAG:
        case PUBLISH_DRAG_SOURCE:
        case END_DRAG:
        case DROP:
        default:
            return ALL;
    }
    const { targetIds =[] , prevTargetIds =[]  } = action.payload;
    const result = xor(targetIds, prevTargetIds);
    const didChange = result.length > 0 || !areArraysEqual(targetIds, prevTargetIds);
    if (!didChange) {
        return NONE;
    }
    // Check the target ids at the innermost position. If they are valid, add them
    // to the result
    const prevInnermostTargetId = prevTargetIds[prevTargetIds.length - 1];
    const innermostTargetId = targetIds[targetIds.length - 1];
    if (prevInnermostTargetId !== innermostTargetId) {
        if (prevInnermostTargetId) {
            result.push(prevInnermostTargetId);
        }
        if (innermostTargetId) {
            result.push(innermostTargetId);
        }
    }
    return result;
}

function _defineProperty$1(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread$1(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty$1(target, key, source[key]);
        });
    }
    return target;
}
const initialState = {
    initialSourceClientOffset: null,
    initialClientOffset: null,
    clientOffset: null
};
function reduce$1(state = initialState, action) {
    const { payload  } = action;
    switch(action.type){
        case INIT_COORDS:
        case BEGIN_DRAG:
            return {
                initialSourceClientOffset: payload.sourceClientOffset,
                initialClientOffset: payload.clientOffset,
                clientOffset: payload.clientOffset
            };
        case HOVER:
            if (areCoordsEqual(state.clientOffset, payload.clientOffset)) {
                return state;
            }
            return _objectSpread$1({}, state, {
                clientOffset: payload.clientOffset
            });
        case END_DRAG:
        case DROP:
            return initialState;
        default:
            return state;
    }
}

function _defineProperty$2(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread$2(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty$2(target, key, source[key]);
        });
    }
    return target;
}
const initialState$1 = {
    itemType: null,
    item: null,
    sourceId: null,
    targetIds: [],
    dropResult: null,
    didDrop: false,
    isSourcePublic: null
};
function reduce$2(state = initialState$1, action) {
    const { payload  } = action;
    switch(action.type){
        case BEGIN_DRAG:
            return _objectSpread$2({}, state, {
                itemType: payload.itemType,
                item: payload.item,
                sourceId: payload.sourceId,
                isSourcePublic: payload.isSourcePublic,
                dropResult: null,
                didDrop: false
            });
        case PUBLISH_DRAG_SOURCE:
            return _objectSpread$2({}, state, {
                isSourcePublic: true
            });
        case HOVER:
            return _objectSpread$2({}, state, {
                targetIds: payload.targetIds
            });
        case REMOVE_TARGET:
            if (state.targetIds.indexOf(payload.targetId) === -1) {
                return state;
            }
            return _objectSpread$2({}, state, {
                targetIds: without(state.targetIds, payload.targetId)
            });
        case DROP:
            return _objectSpread$2({}, state, {
                dropResult: payload.dropResult,
                didDrop: true,
                targetIds: []
            });
        case END_DRAG:
            return _objectSpread$2({}, state, {
                itemType: null,
                item: null,
                sourceId: null,
                dropResult: null,
                didDrop: false,
                isSourcePublic: null,
                targetIds: []
            });
        default:
            return state;
    }
}

function reduce$3(state = 0, action) {
    switch(action.type){
        case ADD_SOURCE:
        case ADD_TARGET:
            return state + 1;
        case REMOVE_SOURCE:
        case REMOVE_TARGET:
            return state - 1;
        default:
            return state;
    }
}

function reduce$4(state = 0) {
    return state + 1;
}

function _defineProperty$3(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread$3(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty$3(target, key, source[key]);
        });
    }
    return target;
}
function reduce$5(state = {}, action) {
    return {
        dirtyHandlerIds: reduce(state.dirtyHandlerIds, {
            type: action.type,
            payload: _objectSpread$3({}, action.payload, {
                prevTargetIds: get(state, 'dragOperation.targetIds', [])
            })
        }),
        dragOffset: reduce$1(state.dragOffset, action),
        refCount: reduce$3(state.refCount, action),
        dragOperation: reduce$2(state.dragOperation, action),
        stateId: reduce$4(state.stateId)
    };
}

function createDragDropManager(backendFactory, globalContext = undefined, backendOptions = {}, debugMode = false) {
    const store = makeStoreInstance(debugMode);
    const monitor = new DragDropMonitorImpl(store, new HandlerRegistryImpl(store));
    const manager = new DragDropManagerImpl(store, monitor);
    const backend = backendFactory(manager, globalContext, backendOptions);
    manager.receiveBackend(backend);
    return manager;
}
function makeStoreInstance(debugMode) {
    // TODO: if we ever make a react-native version of this,
    // we'll need to consider how to pull off dev-tooling
    const reduxDevTools = typeof window !== 'undefined' && window.__REDUX_DEVTOOLS_EXTENSION__;
    return createStore(reduce$5, debugMode && reduxDevTools && reduxDevTools({
        name: 'dnd-core',
        instanceId: 'dnd-core'
    }));
}

function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};
    var target = _objectWithoutPropertiesLoose$1(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose$1(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
let refCount = 0;
const INSTANCE_SYM = Symbol.for('__REACT_DND_CONTEXT_INSTANCE__');
var DndProvider = /*#__PURE__*/ React.memo(function DndProvider(_param) {
    var { children  } = _param, props = _objectWithoutProperties(_param, [
        "children"
    ]);
    const [manager, isGlobalInstance] = getDndContextValue(props) // memoized from props
    ;
    /**
		 * If the global context was used to store the DND context
		 * then where theres no more references to it we should
		 * clean it up to avoid memory leaks
		 */ React.useEffect(()=>{
        if (isGlobalInstance) {
            const context = getGlobalContext();
            ++refCount;
            return ()=>{
                if (--refCount === 0) {
                    context[INSTANCE_SYM] = null;
                }
            };
        }
        return;
    }, []);
    return /*#__PURE__*/ jsxRuntime.jsx(DndContext.Provider, {
        value: manager,
        children: children
    });
});
function getDndContextValue(props) {
    if ('manager' in props) {
        const manager = {
            dragDropManager: props.manager
        };
        return [
            manager,
            false
        ];
    }
    const manager = createSingletonDndContext(props.backend, props.context, props.options, props.debugMode);
    const isGlobalInstance = !props.context;
    return [
        manager,
        isGlobalInstance
    ];
}
function createSingletonDndContext(backend, context = getGlobalContext(), options, debugMode) {
    const ctx = context;
    if (!ctx[INSTANCE_SYM]) {
        ctx[INSTANCE_SYM] = {
            dragDropManager: createDragDropManager(backend, context, options, debugMode)
        };
    }
    return ctx[INSTANCE_SYM];
}
function getGlobalContext() {
    return typeof global !== 'undefined' ? global : window;
}

// do not edit .js files directly - edit src/index.jst



var fastDeepEqual = function equal(a, b) {
  if (a === b) return true;

  if (a && b && typeof a == 'object' && typeof b == 'object') {
    if (a.constructor !== b.constructor) return false;

    var length, i, keys;
    if (Array.isArray(a)) {
      length = a.length;
      if (length != b.length) return false;
      for (i = length; i-- !== 0;)
        if (!equal(a[i], b[i])) return false;
      return true;
    }



    if (a.constructor === RegExp) return a.source === b.source && a.flags === b.flags;
    if (a.valueOf !== Object.prototype.valueOf) return a.valueOf() === b.valueOf();
    if (a.toString !== Object.prototype.toString) return a.toString() === b.toString();

    keys = Object.keys(a);
    length = keys.length;
    if (length !== Object.keys(b).length) return false;

    for (i = length; i-- !== 0;)
      if (!Object.prototype.hasOwnProperty.call(b, keys[i])) return false;

    for (i = length; i-- !== 0;) {
      var key = keys[i];

      if (!equal(a[key], b[key])) return false;
    }

    return true;
  }

  // true if both NaN, false otherwise
  return a!==a && b!==b;
};

// suppress the useLayoutEffect warning on server side.
const useIsomorphicLayoutEffect = typeof window !== 'undefined' ? React.useLayoutEffect : React.useEffect;

/**
 *
 * @param monitor The monitor to collect state from
 * @param collect The collecting function
 * @param onUpdate A method to invoke when updates occur
 */ function useCollector(monitor, collect, onUpdate) {
    const [collected, setCollected] = React.useState(()=>collect(monitor)
    );
    const updateCollected = React.useCallback(()=>{
        const nextValue = collect(monitor);
        // This needs to be a deep-equality check because some monitor-collected values
        // include XYCoord objects that may be equivalent, but do not have instance equality.
        if (!fastDeepEqual(collected, nextValue)) {
            setCollected(nextValue);
            if (onUpdate) {
                onUpdate();
            }
        }
    }, [
        collected,
        monitor,
        onUpdate
    ]);
    // update the collected properties after react renders.
    // Note that the "Dustbin Stress Test" fails if this is not
    // done when the component updates
    useIsomorphicLayoutEffect(updateCollected);
    return [
        collected,
        updateCollected
    ];
}

function useMonitorOutput(monitor, collect, onCollect) {
    const [collected, updateCollected] = useCollector(monitor, collect, onCollect);
    useIsomorphicLayoutEffect(function subscribeToMonitorStateChange() {
        const handlerId = monitor.getHandlerId();
        if (handlerId == null) {
            return;
        }
        return monitor.subscribeToStateChange(updateCollected, {
            handlerIds: [
                handlerId
            ]
        });
    }, [
        monitor,
        updateCollected
    ]);
    return collected;
}

function useCollectedProps(collector, monitor, connector) {
    return useMonitorOutput(monitor, collector || (()=>({})
    ), ()=>connector.reconnect()
    );
}

function useOptionalFactory(arg, deps) {
    const memoDeps = [
        ...deps || []
    ];
    if (deps == null && typeof arg !== 'function') {
        memoDeps.push(arg);
    }
    return React.useMemo(()=>{
        return typeof arg === 'function' ? arg() : arg;
    }, memoDeps);
}

function useConnectDragSource(connector) {
    return React.useMemo(()=>connector.hooks.dragSource()
    , [
        connector
    ]);
}
function useConnectDragPreview(connector) {
    return React.useMemo(()=>connector.hooks.dragPreview()
    , [
        connector
    ]);
}

let isCallingCanDrag = false;
let isCallingIsDragging = false;
class DragSourceMonitorImpl {
    receiveHandlerId(sourceId) {
        this.sourceId = sourceId;
    }
    getHandlerId() {
        return this.sourceId;
    }
    canDrag() {
        invariant(!isCallingCanDrag, 'You may not call monitor.canDrag() inside your canDrag() implementation. ' + 'Read more: http://react-dnd.github.io/react-dnd/docs/api/drag-source-monitor');
        try {
            isCallingCanDrag = true;
            return this.internalMonitor.canDragSource(this.sourceId);
        } finally{
            isCallingCanDrag = false;
        }
    }
    isDragging() {
        if (!this.sourceId) {
            return false;
        }
        invariant(!isCallingIsDragging, 'You may not call monitor.isDragging() inside your isDragging() implementation. ' + 'Read more: http://react-dnd.github.io/react-dnd/docs/api/drag-source-monitor');
        try {
            isCallingIsDragging = true;
            return this.internalMonitor.isDraggingSource(this.sourceId);
        } finally{
            isCallingIsDragging = false;
        }
    }
    subscribeToStateChange(listener, options) {
        return this.internalMonitor.subscribeToStateChange(listener, options);
    }
    isDraggingSource(sourceId) {
        return this.internalMonitor.isDraggingSource(sourceId);
    }
    isOverTarget(targetId, options) {
        return this.internalMonitor.isOverTarget(targetId, options);
    }
    getTargetIds() {
        return this.internalMonitor.getTargetIds();
    }
    isSourcePublic() {
        return this.internalMonitor.isSourcePublic();
    }
    getSourceId() {
        return this.internalMonitor.getSourceId();
    }
    subscribeToOffsetChange(listener) {
        return this.internalMonitor.subscribeToOffsetChange(listener);
    }
    canDragSource(sourceId) {
        return this.internalMonitor.canDragSource(sourceId);
    }
    canDropOnTarget(targetId) {
        return this.internalMonitor.canDropOnTarget(targetId);
    }
    getItemType() {
        return this.internalMonitor.getItemType();
    }
    getItem() {
        return this.internalMonitor.getItem();
    }
    getDropResult() {
        return this.internalMonitor.getDropResult();
    }
    didDrop() {
        return this.internalMonitor.didDrop();
    }
    getInitialClientOffset() {
        return this.internalMonitor.getInitialClientOffset();
    }
    getInitialSourceClientOffset() {
        return this.internalMonitor.getInitialSourceClientOffset();
    }
    getSourceClientOffset() {
        return this.internalMonitor.getSourceClientOffset();
    }
    getClientOffset() {
        return this.internalMonitor.getClientOffset();
    }
    getDifferenceFromInitialOffset() {
        return this.internalMonitor.getDifferenceFromInitialOffset();
    }
    constructor(manager){
        this.sourceId = null;
        this.internalMonitor = manager.getMonitor();
    }
}

let isCallingCanDrop = false;
class DropTargetMonitorImpl {
    receiveHandlerId(targetId) {
        this.targetId = targetId;
    }
    getHandlerId() {
        return this.targetId;
    }
    subscribeToStateChange(listener, options) {
        return this.internalMonitor.subscribeToStateChange(listener, options);
    }
    canDrop() {
        // Cut out early if the target id has not been set. This should prevent errors
        // where the user has an older version of dnd-core like in
        // https://github.com/react-dnd/react-dnd/issues/1310
        if (!this.targetId) {
            return false;
        }
        invariant(!isCallingCanDrop, 'You may not call monitor.canDrop() inside your canDrop() implementation. ' + 'Read more: http://react-dnd.github.io/react-dnd/docs/api/drop-target-monitor');
        try {
            isCallingCanDrop = true;
            return this.internalMonitor.canDropOnTarget(this.targetId);
        } finally{
            isCallingCanDrop = false;
        }
    }
    isOver(options) {
        if (!this.targetId) {
            return false;
        }
        return this.internalMonitor.isOverTarget(this.targetId, options);
    }
    getItemType() {
        return this.internalMonitor.getItemType();
    }
    getItem() {
        return this.internalMonitor.getItem();
    }
    getDropResult() {
        return this.internalMonitor.getDropResult();
    }
    didDrop() {
        return this.internalMonitor.didDrop();
    }
    getInitialClientOffset() {
        return this.internalMonitor.getInitialClientOffset();
    }
    getInitialSourceClientOffset() {
        return this.internalMonitor.getInitialSourceClientOffset();
    }
    getSourceClientOffset() {
        return this.internalMonitor.getSourceClientOffset();
    }
    getClientOffset() {
        return this.internalMonitor.getClientOffset();
    }
    getDifferenceFromInitialOffset() {
        return this.internalMonitor.getDifferenceFromInitialOffset();
    }
    constructor(manager){
        this.targetId = null;
        this.internalMonitor = manager.getMonitor();
    }
}

function registerTarget(type, target, manager) {
    const registry = manager.getRegistry();
    const targetId = registry.addTarget(type, target);
    return [
        targetId,
        ()=>registry.removeTarget(targetId)
    ];
}
function registerSource(type, source, manager) {
    const registry = manager.getRegistry();
    const sourceId = registry.addSource(type, source);
    return [
        sourceId,
        ()=>registry.removeSource(sourceId)
    ];
}

function shallowEqual(objA, objB, compare, compareContext) {
    let compareResult = compare ? compare.call(compareContext, objA, objB) : void 0;
    if (compareResult !== void 0) {
        return !!compareResult;
    }
    if (objA === objB) {
        return true;
    }
    if (typeof objA !== 'object' || !objA || typeof objB !== 'object' || !objB) {
        return false;
    }
    const keysA = Object.keys(objA);
    const keysB = Object.keys(objB);
    if (keysA.length !== keysB.length) {
        return false;
    }
    const bHasOwnProperty = Object.prototype.hasOwnProperty.bind(objB);
    // Test for A's keys different from B.
    for(let idx = 0; idx < keysA.length; idx++){
        const key = keysA[idx];
        if (!bHasOwnProperty(key)) {
            return false;
        }
        const valueA = objA[key];
        const valueB = objB[key];
        compareResult = compare ? compare.call(compareContext, valueA, valueB, key) : void 0;
        if (compareResult === false || compareResult === void 0 && valueA !== valueB) {
            return false;
        }
    }
    return true;
}

function isRef(obj) {
    return(// eslint-disable-next-line no-prototype-builtins
    obj !== null && typeof obj === 'object' && Object.prototype.hasOwnProperty.call(obj, 'current'));
}

function throwIfCompositeComponentElement(element) {
    // Custom components can no longer be wrapped directly in React DnD 2.0
    // so that we don't need to depend on findDOMNode() from react-dom.
    if (typeof element.type === 'string') {
        return;
    }
    const displayName = element.type.displayName || element.type.name || 'the component';
    throw new Error('Only native element nodes can now be passed to React DnD connectors.' + `You can either wrap ${displayName} into a <div>, or turn it into a ` + 'drag source or a drop target itself.');
}
function wrapHookToRecognizeElement(hook) {
    return (elementOrNode = null, options = null)=>{
        // When passed a node, call the hook straight away.
        if (!React.isValidElement(elementOrNode)) {
            const node = elementOrNode;
            hook(node, options);
            // return the node so it can be chained (e.g. when within callback refs
            // <div ref={node => connectDragSource(connectDropTarget(node))}/>
            return node;
        }
        // If passed a ReactElement, clone it and attach this function as a ref.
        // This helps us achieve a neat API where user doesn't even know that refs
        // are being used under the hood.
        const element = elementOrNode;
        throwIfCompositeComponentElement(element);
        // When no options are passed, use the hook directly
        const ref = options ? (node)=>hook(node, options)
         : hook;
        return cloneWithRef(element, ref);
    };
}
function wrapConnectorHooks(hooks) {
    const wrappedHooks = {};
    Object.keys(hooks).forEach((key)=>{
        const hook = hooks[key];
        // ref objects should be passed straight through without wrapping
        if (key.endsWith('Ref')) {
            wrappedHooks[key] = hooks[key];
        } else {
            const wrappedHook = wrapHookToRecognizeElement(hook);
            wrappedHooks[key] = ()=>wrappedHook
            ;
        }
    });
    return wrappedHooks;
}
function setRef(ref, node) {
    if (typeof ref === 'function') {
        ref(node);
    } else {
        ref.current = node;
    }
}
function cloneWithRef(element, newRef) {
    const previousRef = element.ref;
    invariant(typeof previousRef !== 'string', 'Cannot connect React DnD to an element with an existing string ref. ' + 'Please convert it to use a callback ref instead, or wrap it into a <span> or <div>. ' + 'Read more: https://reactjs.org/docs/refs-and-the-dom.html#callback-refs');
    if (!previousRef) {
        // When there is no ref on the element, use the new ref directly
        return React.cloneElement(element, {
            ref: newRef
        });
    } else {
        return React.cloneElement(element, {
            ref: (node)=>{
                setRef(previousRef, node);
                setRef(newRef, node);
            }
        });
    }
}

class SourceConnector {
    receiveHandlerId(newHandlerId) {
        if (this.handlerId === newHandlerId) {
            return;
        }
        this.handlerId = newHandlerId;
        this.reconnect();
    }
    get connectTarget() {
        return this.dragSource;
    }
    get dragSourceOptions() {
        return this.dragSourceOptionsInternal;
    }
    set dragSourceOptions(options) {
        this.dragSourceOptionsInternal = options;
    }
    get dragPreviewOptions() {
        return this.dragPreviewOptionsInternal;
    }
    set dragPreviewOptions(options) {
        this.dragPreviewOptionsInternal = options;
    }
    reconnect() {
        const didChange = this.reconnectDragSource();
        this.reconnectDragPreview(didChange);
    }
    reconnectDragSource() {
        const dragSource = this.dragSource;
        // if nothing has changed then don't resubscribe
        const didChange = this.didHandlerIdChange() || this.didConnectedDragSourceChange() || this.didDragSourceOptionsChange();
        if (didChange) {
            this.disconnectDragSource();
        }
        if (!this.handlerId) {
            return didChange;
        }
        if (!dragSource) {
            this.lastConnectedDragSource = dragSource;
            return didChange;
        }
        if (didChange) {
            this.lastConnectedHandlerId = this.handlerId;
            this.lastConnectedDragSource = dragSource;
            this.lastConnectedDragSourceOptions = this.dragSourceOptions;
            this.dragSourceUnsubscribe = this.backend.connectDragSource(this.handlerId, dragSource, this.dragSourceOptions);
        }
        return didChange;
    }
    reconnectDragPreview(forceDidChange = false) {
        const dragPreview = this.dragPreview;
        // if nothing has changed then don't resubscribe
        const didChange = forceDidChange || this.didHandlerIdChange() || this.didConnectedDragPreviewChange() || this.didDragPreviewOptionsChange();
        if (didChange) {
            this.disconnectDragPreview();
        }
        if (!this.handlerId) {
            return;
        }
        if (!dragPreview) {
            this.lastConnectedDragPreview = dragPreview;
            return;
        }
        if (didChange) {
            this.lastConnectedHandlerId = this.handlerId;
            this.lastConnectedDragPreview = dragPreview;
            this.lastConnectedDragPreviewOptions = this.dragPreviewOptions;
            this.dragPreviewUnsubscribe = this.backend.connectDragPreview(this.handlerId, dragPreview, this.dragPreviewOptions);
        }
    }
    didHandlerIdChange() {
        return this.lastConnectedHandlerId !== this.handlerId;
    }
    didConnectedDragSourceChange() {
        return this.lastConnectedDragSource !== this.dragSource;
    }
    didConnectedDragPreviewChange() {
        return this.lastConnectedDragPreview !== this.dragPreview;
    }
    didDragSourceOptionsChange() {
        return !shallowEqual(this.lastConnectedDragSourceOptions, this.dragSourceOptions);
    }
    didDragPreviewOptionsChange() {
        return !shallowEqual(this.lastConnectedDragPreviewOptions, this.dragPreviewOptions);
    }
    disconnectDragSource() {
        if (this.dragSourceUnsubscribe) {
            this.dragSourceUnsubscribe();
            this.dragSourceUnsubscribe = undefined;
        }
    }
    disconnectDragPreview() {
        if (this.dragPreviewUnsubscribe) {
            this.dragPreviewUnsubscribe();
            this.dragPreviewUnsubscribe = undefined;
            this.dragPreviewNode = null;
            this.dragPreviewRef = null;
        }
    }
    get dragSource() {
        return this.dragSourceNode || this.dragSourceRef && this.dragSourceRef.current;
    }
    get dragPreview() {
        return this.dragPreviewNode || this.dragPreviewRef && this.dragPreviewRef.current;
    }
    clearDragSource() {
        this.dragSourceNode = null;
        this.dragSourceRef = null;
    }
    clearDragPreview() {
        this.dragPreviewNode = null;
        this.dragPreviewRef = null;
    }
    constructor(backend){
        this.hooks = wrapConnectorHooks({
            dragSource: (node, options)=>{
                this.clearDragSource();
                this.dragSourceOptions = options || null;
                if (isRef(node)) {
                    this.dragSourceRef = node;
                } else {
                    this.dragSourceNode = node;
                }
                this.reconnectDragSource();
            },
            dragPreview: (node, options)=>{
                this.clearDragPreview();
                this.dragPreviewOptions = options || null;
                if (isRef(node)) {
                    this.dragPreviewRef = node;
                } else {
                    this.dragPreviewNode = node;
                }
                this.reconnectDragPreview();
            }
        });
        this.handlerId = null;
        // The drop target may either be attached via ref or connect function
        this.dragSourceRef = null;
        this.dragSourceOptionsInternal = null;
        // The drag preview may either be attached via ref or connect function
        this.dragPreviewRef = null;
        this.dragPreviewOptionsInternal = null;
        this.lastConnectedHandlerId = null;
        this.lastConnectedDragSource = null;
        this.lastConnectedDragSourceOptions = null;
        this.lastConnectedDragPreview = null;
        this.lastConnectedDragPreviewOptions = null;
        this.backend = backend;
    }
}

class TargetConnector {
    get connectTarget() {
        return this.dropTarget;
    }
    reconnect() {
        // if nothing has changed then don't resubscribe
        const didChange = this.didHandlerIdChange() || this.didDropTargetChange() || this.didOptionsChange();
        if (didChange) {
            this.disconnectDropTarget();
        }
        const dropTarget = this.dropTarget;
        if (!this.handlerId) {
            return;
        }
        if (!dropTarget) {
            this.lastConnectedDropTarget = dropTarget;
            return;
        }
        if (didChange) {
            this.lastConnectedHandlerId = this.handlerId;
            this.lastConnectedDropTarget = dropTarget;
            this.lastConnectedDropTargetOptions = this.dropTargetOptions;
            this.unsubscribeDropTarget = this.backend.connectDropTarget(this.handlerId, dropTarget, this.dropTargetOptions);
        }
    }
    receiveHandlerId(newHandlerId) {
        if (newHandlerId === this.handlerId) {
            return;
        }
        this.handlerId = newHandlerId;
        this.reconnect();
    }
    get dropTargetOptions() {
        return this.dropTargetOptionsInternal;
    }
    set dropTargetOptions(options) {
        this.dropTargetOptionsInternal = options;
    }
    didHandlerIdChange() {
        return this.lastConnectedHandlerId !== this.handlerId;
    }
    didDropTargetChange() {
        return this.lastConnectedDropTarget !== this.dropTarget;
    }
    didOptionsChange() {
        return !shallowEqual(this.lastConnectedDropTargetOptions, this.dropTargetOptions);
    }
    disconnectDropTarget() {
        if (this.unsubscribeDropTarget) {
            this.unsubscribeDropTarget();
            this.unsubscribeDropTarget = undefined;
        }
    }
    get dropTarget() {
        return this.dropTargetNode || this.dropTargetRef && this.dropTargetRef.current;
    }
    clearDropTarget() {
        this.dropTargetRef = null;
        this.dropTargetNode = null;
    }
    constructor(backend){
        this.hooks = wrapConnectorHooks({
            dropTarget: (node, options)=>{
                this.clearDropTarget();
                this.dropTargetOptions = options;
                if (isRef(node)) {
                    this.dropTargetRef = node;
                } else {
                    this.dropTargetNode = node;
                }
                this.reconnect();
            }
        });
        this.handlerId = null;
        // The drop target may either be attached via ref or connect function
        this.dropTargetRef = null;
        this.dropTargetOptionsInternal = null;
        this.lastConnectedHandlerId = null;
        this.lastConnectedDropTarget = null;
        this.lastConnectedDropTargetOptions = null;
        this.backend = backend;
    }
}

/**
 * A hook to retrieve the DragDropManager from Context
 */ function useDragDropManager() {
    const { dragDropManager  } = React.useContext(DndContext);
    invariant(dragDropManager != null, 'Expected drag drop context');
    return dragDropManager;
}

function useDragSourceConnector(dragSourceOptions, dragPreviewOptions) {
    const manager = useDragDropManager();
    const connector = React.useMemo(()=>new SourceConnector(manager.getBackend())
    , [
        manager
    ]);
    useIsomorphicLayoutEffect(()=>{
        connector.dragSourceOptions = dragSourceOptions || null;
        connector.reconnect();
        return ()=>connector.disconnectDragSource()
        ;
    }, [
        connector,
        dragSourceOptions
    ]);
    useIsomorphicLayoutEffect(()=>{
        connector.dragPreviewOptions = dragPreviewOptions || null;
        connector.reconnect();
        return ()=>connector.disconnectDragPreview()
        ;
    }, [
        connector,
        dragPreviewOptions
    ]);
    return connector;
}

function useDragSourceMonitor() {
    const manager = useDragDropManager();
    return React.useMemo(()=>new DragSourceMonitorImpl(manager)
    , [
        manager
    ]);
}

class DragSourceImpl {
    beginDrag() {
        const spec = this.spec;
        const monitor = this.monitor;
        let result = null;
        if (typeof spec.item === 'object') {
            result = spec.item;
        } else if (typeof spec.item === 'function') {
            result = spec.item(monitor);
        } else {
            result = {};
        }
        return result !== null && result !== void 0 ? result : null;
    }
    canDrag() {
        const spec = this.spec;
        const monitor = this.monitor;
        if (typeof spec.canDrag === 'boolean') {
            return spec.canDrag;
        } else if (typeof spec.canDrag === 'function') {
            return spec.canDrag(monitor);
        } else {
            return true;
        }
    }
    isDragging(globalMonitor, target) {
        const spec = this.spec;
        const monitor = this.monitor;
        const { isDragging  } = spec;
        return isDragging ? isDragging(monitor) : target === globalMonitor.getSourceId();
    }
    endDrag() {
        const spec = this.spec;
        const monitor = this.monitor;
        const connector = this.connector;
        const { end  } = spec;
        if (end) {
            end(monitor.getItem(), monitor);
        }
        connector.reconnect();
    }
    constructor(spec, monitor, connector){
        this.spec = spec;
        this.monitor = monitor;
        this.connector = connector;
    }
}

function useDragSource(spec, monitor, connector) {
    const handler = React.useMemo(()=>new DragSourceImpl(spec, monitor, connector)
    , [
        monitor,
        connector
    ]);
    React.useEffect(()=>{
        handler.spec = spec;
    }, [
        spec
    ]);
    return handler;
}

function useDragType(spec) {
    return React.useMemo(()=>{
        const result = spec.type;
        invariant(result != null, 'spec.type must be defined');
        return result;
    }, [
        spec
    ]);
}

function useRegisteredDragSource(spec, monitor, connector) {
    const manager = useDragDropManager();
    const handler = useDragSource(spec, monitor, connector);
    const itemType = useDragType(spec);
    useIsomorphicLayoutEffect(function registerDragSource() {
        if (itemType != null) {
            const [handlerId, unregister] = registerSource(itemType, handler, manager);
            monitor.receiveHandlerId(handlerId);
            connector.receiveHandlerId(handlerId);
            return unregister;
        }
        return;
    }, [
        manager,
        monitor,
        connector,
        handler,
        itemType
    ]);
}

/**
 * useDragSource hook
 * @param sourceSpec The drag source specification (object or function, function preferred)
 * @param deps The memoization deps array to use when evaluating spec changes
 */ function useDrag(specArg, deps) {
    const spec = useOptionalFactory(specArg, deps);
    invariant(!spec.begin, `useDrag::spec.begin was deprecated in v14. Replace spec.begin() with spec.item(). (see more here - https://react-dnd.github.io/react-dnd/docs/api/use-drag)`);
    const monitor = useDragSourceMonitor();
    const connector = useDragSourceConnector(spec.options, spec.previewOptions);
    useRegisteredDragSource(spec, monitor, connector);
    return [
        useCollectedProps(spec.collect, monitor, connector),
        useConnectDragSource(connector),
        useConnectDragPreview(connector), 
    ];
}

function useConnectDropTarget(connector) {
    return React.useMemo(()=>connector.hooks.dropTarget()
    , [
        connector
    ]);
}

function useDropTargetConnector(options) {
    const manager = useDragDropManager();
    const connector = React.useMemo(()=>new TargetConnector(manager.getBackend())
    , [
        manager
    ]);
    useIsomorphicLayoutEffect(()=>{
        connector.dropTargetOptions = options || null;
        connector.reconnect();
        return ()=>connector.disconnectDropTarget()
        ;
    }, [
        options
    ]);
    return connector;
}

function useDropTargetMonitor() {
    const manager = useDragDropManager();
    return React.useMemo(()=>new DropTargetMonitorImpl(manager)
    , [
        manager
    ]);
}

/**
 * Internal utility hook to get an array-version of spec.accept.
 * The main utility here is that we aren't creating a new array on every render if a non-array spec.accept is passed in.
 * @param spec
 */ function useAccept(spec) {
    const { accept  } = spec;
    return React.useMemo(()=>{
        invariant(spec.accept != null, 'accept must be defined');
        return Array.isArray(accept) ? accept : [
            accept
        ];
    }, [
        accept
    ]);
}

class DropTargetImpl {
    canDrop() {
        const spec = this.spec;
        const monitor = this.monitor;
        return spec.canDrop ? spec.canDrop(monitor.getItem(), monitor) : true;
    }
    hover() {
        const spec = this.spec;
        const monitor = this.monitor;
        if (spec.hover) {
            spec.hover(monitor.getItem(), monitor);
        }
    }
    drop() {
        const spec = this.spec;
        const monitor = this.monitor;
        if (spec.drop) {
            return spec.drop(monitor.getItem(), monitor);
        }
        return;
    }
    constructor(spec, monitor){
        this.spec = spec;
        this.monitor = monitor;
    }
}

function useDropTarget(spec, monitor) {
    const dropTarget = React.useMemo(()=>new DropTargetImpl(spec, monitor)
    , [
        monitor
    ]);
    React.useEffect(()=>{
        dropTarget.spec = spec;
    }, [
        spec
    ]);
    return dropTarget;
}

function useRegisteredDropTarget(spec, monitor, connector) {
    const manager = useDragDropManager();
    const dropTarget = useDropTarget(spec, monitor);
    const accept = useAccept(spec);
    useIsomorphicLayoutEffect(function registerDropTarget() {
        const [handlerId, unregister] = registerTarget(accept, dropTarget, manager);
        monitor.receiveHandlerId(handlerId);
        connector.receiveHandlerId(handlerId);
        return unregister;
    }, [
        manager,
        monitor,
        dropTarget,
        connector,
        accept.map((a)=>a.toString()
        ).join('|'), 
    ]);
}

/**
 * useDropTarget Hook
 * @param spec The drop target specification (object or function, function preferred)
 * @param deps The memoization deps array to use when evaluating spec changes
 */ function useDrop(specArg, deps) {
    const spec = useOptionalFactory(specArg, deps);
    const monitor = useDropTargetMonitor();
    const connector = useDropTargetConnector(spec.options);
    useRegisteredDropTarget(spec, monitor, connector);
    return [
        useCollectedProps(spec.collect, monitor, connector),
        useConnectDropTarget(connector), 
    ];
}

var MRT_ColumnPinningButtons = function MRT_ColumnPinningButtons(_ref) {
  var column = _ref.column,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      PushPinIcon = _tableInstance$option.icons.PushPinIcon,
      localization = _tableInstance$option.localization;

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
  };

  return React__default.createElement(material.Box, {
    sx: {
      minWidth: '70px',
      textAlign: 'center'
    }
  }, column.getIsPinned() ? React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.unpin
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, null))) : React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.pinToLeft
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  }))), React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.pinToRight
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })))));
};

var MRT_GrabHandleButton = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      DragHandleIcon = _tableInstance$option.icons.DragHandleIcon,
      localization = _tableInstance$option.localization;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.grab
  }, React__default.createElement(material.IconButton, {
    disableRipple: true,
    ref: ref,
    size: "small",
    sx: {
      cursor: 'grab',
      m: 0,
      opacity: 0.5,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 1
      },
      '&:active': {
        cursor: 'grabbing'
      }
    }
  }, React__default.createElement(DragHandleIcon, null)));
});

var getAllLeafColumnDefs = function getAllLeafColumnDefs(columns) {
  var lowestLevelColumns = columns;
  var currentCols = columns;

  while (!!((_currentCols = currentCols) != null && _currentCols.length) && currentCols.some(function (col) {
    return col.columns;
  })) {
    var _currentCols;

    var nextCols = currentCols.filter(function (col) {
      return !!col.columns;
    }).map(function (col) {
      return col.columns;
    }).flat();

    if (nextCols.every(function (col) {
      return !(col != null && col.columns);
    })) {
      lowestLevelColumns = [].concat(lowestLevelColumns, nextCols);
    }

    currentCols = nextCols;
  }

  return lowestLevelColumns.filter(function (col) {
    return !col.columns;
  });
};
var createGroup = function createGroup(table, column, currentFilterFns) {
  var _column$columns;

  return table.createGroup(_extends({}, column, {
    columns: column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.map == null ? void 0 : _column$columns.map(function (col) {
      return col.columns ? createGroup(table, col, currentFilterFns) : createDataColumn(table, col, currentFilterFns);
    })
  }));
};
var createDataColumn = function createDataColumn(table, column, currentFilterFns) {
  return (// @ts-ignore
    table.createDataColumn(column.id, _extends({
      filterFn: currentFilterFns[column.id] instanceof Function ? currentFilterFns[column.id] : defaultFilterFNs[currentFilterFns[column.id]]
    }, column))
  );
};
var createDisplayColumn = function createDisplayColumn(table, column) {
  return table.createDisplayColumn(column);
};
var reorderColumn = function reorderColumn(movingColumn, receivingColumn, columnOrder, setColumnOrder) {
  if (movingColumn.getCanPin()) {
    movingColumn.pin(receivingColumn.getIsPinned());
  }

  columnOrder.splice(columnOrder.indexOf(receivingColumn.id), 0, columnOrder.splice(columnOrder.indexOf(movingColumn.id), 1)[0]);
  setColumnOrder([].concat(columnOrder));
};

var MRT_ShowHideColumnsMenuItems = function MRT_ShowHideColumnsMenuItems(_ref) {
  var _column$columns2;

  var allColumns = _ref.allColumns,
      column = _ref.column,
      isSubMenu = _ref.isSubMenu,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      onMrtToggleColumnVisibility = _tableInstance$option.onMrtToggleColumnVisibility,
      setColumnOrder = tableInstance.setColumnOrder;

  var _getState = getState(),
      columnOrder = _getState.columnOrder,
      columnVisibility = _getState.columnVisibility;

  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var _useDrag = useDrag({
    collect: function collect(monitor) {
      return {
        isDragging: monitor.isDragging()
      };
    },
    item: function item() {
      return column;
    },
    type: 'column'
  }),
      dragRef = _useDrag[1],
      previewRef = _useDrag[2];

  var switchChecked = columnDefType !== 'group' && column.getIsVisible() || columnDefType === 'group' && column.getLeafColumns().some(function (col) {
    return col.getIsVisible();
  });

  var handleToggleColumnHidden = function handleToggleColumnHidden(column) {
    if (columnDefType === 'group') {
      var _column$columns;

      column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.forEach == null ? void 0 : _column$columns.forEach(function (childColumn) {
        childColumn.toggleVisibility(!switchChecked);
      });
    } else {
      column.toggleVisibility();
    }

    onMrtToggleColumnVisibility == null ? void 0 : onMrtToggleColumnVisibility({
      column: column,
      columnVisibility: columnVisibility,
      tableInstance: tableInstance
    });
  };

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.MenuItem, {
    ref: columnDefType === 'data' ? dropRef : undefined,
    sx: {
      alignItems: 'center',
      justifyContent: 'flex-start',
      my: 0,
      pl: (column.depth + 0.5) * 2 + "rem",
      py: '6px'
    }
  }, React__default.createElement(material.Box, {
    ref: previewRef,
    sx: {
      display: 'flex',
      flexWrap: 'nowrap',
      gap: '8px'
    }
  }, columnDefType !== 'group' && enableColumnOrdering && columnDef.enableColumnOrdering !== false && !allColumns.some(function (col) {
    return col.columnDefType === 'group';
  }) && React__default.createElement(MRT_GrabHandleButton, {
    ref: dragRef,
    tableInstance: tableInstance
  }), !isSubMenu && column.getCanPin() && React__default.createElement(MRT_ColumnPinningButtons, {
    column: column,
    tableInstance: tableInstance
  }), React__default.createElement(material.FormControlLabel, {
    componentsProps: {
      typography: {
        sx: {
          mb: 0,
          opacity: columnDefType !== 'display' ? 1 : 0.5
        }
      }
    },
    checked: switchChecked,
    control: React__default.createElement(material.Switch, null),
    disabled: isSubMenu && switchChecked || !column.getCanHide() || column.getIsGrouped(),
    label: columnDef.header,
    onChange: function onChange() {
      return handleToggleColumnHidden(column);
    }
  }))), (_column$columns2 = column.columns) == null ? void 0 : _column$columns2.map(function (c, i) {
    return React__default.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      key: i + "-" + c.id,
      column: c,
      isSubMenu: isSubMenu,
      tableInstance: tableInstance
    });
  }));
};

var MRT_ShowHideColumnsMenu = function MRT_ShowHideColumnsMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      isSubMenu = _ref.isSubMenu,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getAllColumns = tableInstance.getAllColumns,
      getAllLeafColumns = tableInstance.getAllLeafColumns,
      getCenterLeafColumns = tableInstance.getCenterLeafColumns,
      getIsAllColumnsVisible = tableInstance.getIsAllColumnsVisible,
      getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      getIsSomeColumnsVisible = tableInstance.getIsSomeColumnsVisible,
      getLeftLeafColumns = tableInstance.getLeftLeafColumns,
      getRightLeafColumns = tableInstance.getRightLeafColumns,
      getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      enablePinning = _tableInstance$option.enablePinning,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      columnOrder = _getState.columnOrder,
      columnPinning = _getState.columnPinning;

  var hideAllColumns = function hideAllColumns() {
    getAllLeafColumns().filter(function (col) {
      return col.columnDef.enableHiding !== false;
    }).forEach(function (col) {
      return col.toggleVisibility(false);
    });
  };

  var allColumns = React.useMemo(function () {
    var columns = getAllColumns();

    if (columnOrder.length > 0 && !columns.some(function (col) {
      return col.columnDefType === 'group';
    })) {
      return [].concat(getLeftLeafColumns(), Array.from(new Set(columnOrder)).map(function (colId) {
        return getCenterLeafColumns().find(function (col) {
          return (col == null ? void 0 : col.id) === colId;
        });
      }), getRightLeafColumns()).filter(Boolean);
    }

    return columns;
  }, [columnOrder, columnPinning, getAllColumns(), getCenterLeafColumns(), getLeftLeafColumns(), getRightLeafColumns()]);
  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: isSubMenu ? 'center' : 'space-between',
      p: '0.5rem',
      pt: 0
    }
  }, !isSubMenu && React__default.createElement(material.Button, {
    disabled: !getIsSomeColumnsVisible(),
    onClick: hideAllColumns
  }, localization.hideAll), !isSubMenu && enableColumnOrdering && React__default.createElement(material.Button, {
    onClick: function onClick() {
      return tableInstance.resetColumnOrder();
    }
  }, localization.resetOrder), !isSubMenu && enablePinning && React__default.createElement(material.Button, {
    disabled: !getIsSomeColumnsPinned(),
    onClick: function onClick() {
      return tableInstance.resetColumnPinning(true);
    }
  }, localization.unpinAll), React__default.createElement(material.Button, {
    disabled: getIsAllColumnsVisible(),
    onClick: function onClick() {
      return toggleAllColumnsVisible(true);
    }
  }, localization.showAll)), React__default.createElement(material.Divider, null), allColumns.map(function (column, index) {
    return React__default.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      column: column,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id,
      tableInstance: tableInstance
    });
  }));
};

var commonMenuItemStyles$1 = {
  py: '6px',
  my: 0,
  justifyContent: 'space-between',
  alignItems: 'center'
};
var commonListItemStyles = {
  display: 'flex',
  alignItems: 'center'
};
var MRT_ColumnActionMenu = function MRT_ColumnActionMenu(_ref) {
  var _localization$sortByC, _localization$sortByC2, _localization$filterB, _localization, _localization$hideCol, _localization$showAll;

  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      setColumnOrder = tableInstance.setColumnOrder,
      _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableGrouping = _tableInstance$option.enableGrouping,
      enableHiding = _tableInstance$option.enableHiding,
      enablePinning = _tableInstance$option.enablePinning,
      enableSorting = _tableInstance$option.enableSorting,
      _tableInstance$option2 = _tableInstance$option.icons,
      ArrowRightIcon = _tableInstance$option2.ArrowRightIcon,
      ClearAllIcon = _tableInstance$option2.ClearAllIcon,
      ViewColumnIcon = _tableInstance$option2.ViewColumnIcon,
      DynamicFeedIcon = _tableInstance$option2.DynamicFeedIcon,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      PushPinIcon = _tableInstance$option2.PushPinIcon,
      SortIcon = _tableInstance$option2.SortIcon,
      RestartAltIcon = _tableInstance$option2.RestartAltIcon,
      VisibilityOffIcon = _tableInstance$option2.VisibilityOffIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      setShowFilters = tableInstance.setShowFilters;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      columnSizing = _getState.columnSizing,
      columnVisibility = _getState.columnVisibility,
      isDensePadding = _getState.isDensePadding;

  var _useState = React.useState(null),
      filterMenuAnchorEl = _useState[0],
      setFilterMenuAnchorEl = _useState[1];

  var _useState2 = React.useState(null),
      showHideColumnsMenuAnchorEl = _useState2[0],
      setShowHideColumnsMenuAnchorEl = _useState2[1];

  var handleClearSort = function handleClearSort() {
    column.clearSorting();
    setAnchorEl(null);
  };

  var handleSortAsc = function handleSortAsc() {
    column.toggleSorting(false);
    setAnchorEl(null);
  };

  var handleSortDesc = function handleSortDesc() {
    column.toggleSorting(true);
    setAnchorEl(null);
  };

  var handleResetColumnSize = function handleResetColumnSize() {
    column.resetSize();
    setAnchorEl(null);
  };

  var handleHideColumn = function handleHideColumn() {
    column.toggleVisibility(false);
    setAnchorEl(null);
  };

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
    setAnchorEl(null);
  };

  var handleGroupByColumn = function handleGroupByColumn() {
    column.toggleGrouping();
    setColumnOrder(function (old) {
      return ['mrt-expand'].concat(old);
    });
    setAnchorEl(null);
  };

  var handleClearFilter = function handleClearFilter() {
    column.setFilterValue('');
    setAnchorEl(null);
  };

  var handleFilterByColumn = function handleFilterByColumn() {
    setShowFilters(true);
    setTimeout(function () {
      var _document$getElementB, _header$muiTableHeadC, _header$muiTableHeadC2;

      return (_document$getElementB = document.getElementById( // @ts-ignore
      (_header$muiTableHeadC = (_header$muiTableHeadC2 = header.muiTableHeadCellFilterTextFieldProps) == null ? void 0 : _header$muiTableHeadC2.id) != null ? _header$muiTableHeadC : "mrt-" + tableId + "-" + header.id + "-filter-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
    setAnchorEl(null);
  };

  var handleShowAllColumns = function handleShowAllColumns() {
    toggleAllColumnsVisible(true);
    setAnchorEl(null);
  };

  var handleOpenFilterModeMenu = function handleOpenFilterModeMenu(event) {
    event.stopPropagation();
    setFilterMenuAnchorEl(event.currentTarget);
  };

  var handleOpenShowHideColumnsMenu = function handleOpenShowHideColumnsMenu(event) {
    event.stopPropagation();
    setShowHideColumnsMenuAnchorEl(event.currentTarget);
  };

  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableSorting && column.getCanSort() && [React__default.createElement(material.MenuItem, {
    disabled: !column.getIsSorted(),
    key: 0,
    onClick: handleClearSort,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(ClearAllIcon, null)), localization.clearSort)), React__default.createElement(material.MenuItem, {
    disabled: column.getIsSorted() === 'asc',
    key: 1,
    onClick: handleSortAsc,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(SortIcon, null)), (_localization$sortByC = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC.replace('{column}', String(columnDef.header)))), React__default.createElement(material.MenuItem, {
    divider: enableColumnFilters || enableGrouping || enableHiding,
    key: 2,
    disabled: column.getIsSorted() === 'desc',
    onClick: handleSortDesc,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(SortIcon, {
    style: {
      transform: 'rotate(180deg) scaleX(-1)'
    }
  })), (_localization$sortByC2 = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC2.replace('{column}', String(columnDef.header))))], enableColumnFilters && column.getCanFilter() && [React__default.createElement(material.MenuItem, {
    disabled: !column.getFilterValue(),
    key: 0,
    onClick: handleClearFilter,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(FilterListOffIcon, null)), localization.clearFilter)), React__default.createElement(material.MenuItem, {
    divider: enableGrouping || enableHiding,
    key: 1,
    onClick: handleFilterByColumn,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(FilterListIcon, null)), (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header))), !columnDef.filterSelectOptions && React__default.createElement(material.IconButton, {
    onClick: handleOpenFilterModeMenu,
    onMouseEnter: handleOpenFilterModeMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React__default.createElement(ArrowRightIcon, null))), React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: filterMenuAnchorEl,
    header: header,
    key: 2,
    onSelect: handleFilterByColumn,
    setAnchorEl: setFilterMenuAnchorEl,
    tableInstance: tableInstance
  })], enableGrouping && column.getCanGroup() && [React__default.createElement(material.MenuItem, {
    divider: enablePinning,
    key: 0,
    onClick: handleGroupByColumn,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(DynamicFeedIcon, null)), (_localization = localization[column.getIsGrouped() ? 'ungroupByColumn' : 'groupByColumn']) == null ? void 0 : _localization.replace('{column}', String(columnDef.header))))], enablePinning && column.getCanPin() && [React__default.createElement(material.MenuItem, {
    disabled: column.getIsPinned() === 'left' || !column.getCanPin(),
    key: 0,
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  })), localization.pinToLeft)), React__default.createElement(material.MenuItem, {
    disabled: column.getIsPinned() === 'right' || !column.getCanPin(),
    key: 1,
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })), localization.pinToRight)), React__default.createElement(material.MenuItem, {
    disabled: !column.getIsPinned(),
    divider: enableHiding,
    key: 2,
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, null)), localization.unpin))], enableColumnResizing && [React__default.createElement(material.MenuItem, {
    disabled: !column.getCanResize() || !columnSizing[column.id],
    key: 0,
    onClick: handleResetColumnSize,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(RestartAltIcon, null)), localization.resetColumnSize))], enableHiding && [React__default.createElement(material.MenuItem, {
    disabled: columnDef.enableHiding === false,
    key: 0,
    onClick: handleHideColumn,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(VisibilityOffIcon, null)), (_localization$hideCol = localization.hideColumn) == null ? void 0 : _localization$hideCol.replace('{column}', String(columnDef.header)))), React__default.createElement(material.MenuItem, {
    disabled: !Object.values(columnVisibility).filter(function (visible) {
      return !visible;
    }).length,
    key: 1,
    onClick: handleShowAllColumns,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(ViewColumnIcon, null)), (_localization$showAll = localization.showAllColumns) == null ? void 0 : _localization$showAll.replace('{column}', String(columnDef.header))), React__default.createElement(material.IconButton, {
    onClick: handleOpenShowHideColumnsMenu,
    onMouseEnter: handleOpenShowHideColumnsMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React__default.createElement(ArrowRightIcon, null))), React__default.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: showHideColumnsMenuAnchorEl,
    isSubMenu: true,
    key: 2,
    setAnchorEl: setShowHideColumnsMenuAnchorEl,
    tableInstance: tableInstance
  })]);
};

var MRT_RowActionMenu = function MRT_RowActionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      handleEdit = _ref.handleEdit,
      row = _ref.row,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      EditIcon = _tableInstance$option.icons.EditIcon,
      enableEditing = _tableInstance$option.enableEditing,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableEditing && React__default.createElement(material.MenuItem, {
    onClick: handleEdit,
    sx: commonMenuItemStyles$1
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(EditIcon, null)), localization.edit)), renderRowActionMenuItems == null ? void 0 : renderRowActionMenuItems({
    row: row,
    tableInstance: tableInstance,
    closeMenu: function closeMenu() {
      return setAnchorEl(null);
    }
  }));
};

var MRT_EditActionButtons = function MRT_EditActionButtons(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      CancelIcon = _tableInstance$option2.CancelIcon,
      SaveIcon = _tableInstance$option2.SaveIcon,
      localization = _tableInstance$option.localization,
      onMrtEditRowSubmit = _tableInstance$option.onMrtEditRowSubmit,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var handleCancel = function handleCancel() {
    var _row$original;

    row._valuesCache = (_row$original = row.original) != null ? _row$original : {};
    setCurrentEditingRow(null);
  };

  var handleSave = function handleSave() {
    onMrtEditRowSubmit == null ? void 0 : onMrtEditRowSubmit({
      row: currentEditingRow != null ? currentEditingRow : row,
      tableInstance: tableInstance
    });
    setCurrentEditingRow(null);
  };

  return React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      gap: '0.75rem'
    }
  }, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.cancel
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.cancel,
    onClick: handleCancel
  }, React__default.createElement(CancelIcon, null))), React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.save
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.save,
    color: "info",
    onClick: handleSave
  }, React__default.createElement(SaveIcon, null))));
};

var commonIconButtonStyles = {
  height: '2rem',
  ml: '10px',
  opacity: 0.5,
  transition: 'opacity 0.2s',
  width: '2rem',
  '&:hover': {
    opacity: 1
  }
};
var MRT_ToggleRowActionMenuButton = function MRT_ToggleRowActionMenuButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableEditing = _tableInstance$option.enableEditing,
      _tableInstance$option2 = _tableInstance$option.icons,
      EditIcon = _tableInstance$option2.EditIcon,
      MoreHorizIcon = _tableInstance$option2.MoreHorizIcon,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems,
      renderRowActions = _tableInstance$option.renderRowActions,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleOpenRowActionMenu = function handleOpenRowActionMenu(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var handleStartEditMode = function handleStartEditMode() {
    setCurrentEditingRow(_extends({}, row));
    setAnchorEl(null);
  };

  return React__default.createElement(React__default.Fragment, null, renderRowActions ? React__default.createElement(React__default.Fragment, null, renderRowActions({
    row: row,
    tableInstance: tableInstance
  })) : row.id === (currentEditingRow == null ? void 0 : currentEditingRow.id) ? React__default.createElement(MRT_EditActionButtons, {
    row: row,
    tableInstance: tableInstance
  }) : !renderRowActionMenuItems && enableEditing ? React__default.createElement(material.Tooltip, {
    placement: "right",
    arrow: true,
    title: localization.edit
  }, React__default.createElement(material.IconButton, {
    sx: commonIconButtonStyles,
    onClick: handleStartEditMode
  }, React__default.createElement(EditIcon, null))) : renderRowActionMenuItems ? React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.rowActions
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.rowActions,
    onClick: handleOpenRowActionMenu,
    size: "small",
    sx: commonIconButtonStyles
  }, React__default.createElement(MoreHorizIcon, null))), React__default.createElement(MRT_RowActionMenu, {
    anchorEl: anchorEl,
    handleEdit: handleStartEditMode,
    row: row,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  })) : null);
};

var MRT_SelectCheckbox = function MRT_SelectCheckbox(_ref) {
  var row = _ref.row,
      selectAll = _ref.selectAll,
      tableInstance = _ref.tableInstance;
  var getRowModel = tableInstance.getRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiSelectCheckboxProps = _tableInstance$option.muiSelectCheckboxProps,
      onMrtSelectRowChange = _tableInstance$option.onMrtSelectRowChange,
      onMrtSelectAllChange = _tableInstance$option.onMrtSelectAllChange,
      selectAllMode = _tableInstance$option.selectAllMode;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleSelectChange = function handleSelectChange(event) {
    if (selectAll) {
      if (selectAllMode === 'all') {
        tableInstance.getToggleAllRowsSelectedHandler()(event);
      } else if (selectAllMode === 'page') {
        tableInstance.getToggleAllPageRowsSelectedHandler()(event);
      }

      onMrtSelectAllChange == null ? void 0 : onMrtSelectAllChange({
        event: event,
        selectedRows: event.target.checked ? getRowModel().flatRows : [],
        tableInstance: tableInstance
      });
    } else if (row) {
      row == null ? void 0 : row.getToggleSelectedHandler()(event);
      onMrtSelectRowChange == null ? void 0 : onMrtSelectRowChange({
        event: event,
        row: row,
        selectedRows: event.target.checked ? [].concat(getSelectedRowModel().flatRows, [row]) : getSelectedRowModel().flatRows.filter(function (selectedRow) {
          return selectedRow.id !== row.id;
        }),
        tableInstance: tableInstance
      });
    }
  };

  var checkboxProps = muiSelectCheckboxProps instanceof Function ? muiSelectCheckboxProps({
    isSelectAll: !!selectAll,
    row: row,
    tableInstance: tableInstance
  }) : muiSelectCheckboxProps;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
  }, React__default.createElement(material.Checkbox, Object.assign({
    checked: selectAll ? tableInstance.getIsAllRowsSelected() : row == null ? void 0 : row.getIsSelected(),
    indeterminate: selectAll ? tableInstance.getIsSomeRowsSelected() : row == null ? void 0 : row.getIsSomeSelected(),
    inputProps: {
      'aria-label': selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
    },
    onChange: handleSelectChange,
    size: isDensePadding ? 'small' : 'medium'
  }, checkboxProps, {
    sx: _extends({
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }, checkboxProps == null ? void 0 : checkboxProps.sx)
  })));
};

// cheap lodash replacements
function memoize(fn) {
    let result = null;
    const memoized = ()=>{
        if (result == null) {
            result = fn();
        }
        return result;
    };
    return memoized;
}
/**
 * drop-in replacement for _.without
 */ function without$1(items, item) {
    return items.filter((i)=>i !== item
    );
}
function union(itemsA, itemsB) {
    const set = new Set();
    const insertItem = (item)=>set.add(item)
    ;
    itemsA.forEach(insertItem);
    itemsB.forEach(insertItem);
    const result = [];
    set.forEach((key)=>result.push(key)
    );
    return result;
}

class EnterLeaveCounter {
    enter(enteringNode) {
        const previousLength = this.entered.length;
        const isNodeEntered = (node)=>this.isNodeInDocument(node) && (!node.contains || node.contains(enteringNode))
        ;
        this.entered = union(this.entered.filter(isNodeEntered), [
            enteringNode
        ]);
        return previousLength === 0 && this.entered.length > 0;
    }
    leave(leavingNode) {
        const previousLength = this.entered.length;
        this.entered = without$1(this.entered.filter(this.isNodeInDocument), leavingNode);
        return previousLength > 0 && this.entered.length === 0;
    }
    reset() {
        this.entered = [];
    }
    constructor(isNodeInDocument){
        this.entered = [];
        this.isNodeInDocument = isNodeInDocument;
    }
}

class NativeDragSource {
    initializeExposedProperties() {
        Object.keys(this.config.exposeProperties).forEach((property)=>{
            Object.defineProperty(this.item, property, {
                configurable: true,
                enumerable: true,
                get () {
                    // eslint-disable-next-line no-console
                    console.warn(`Browser doesn't allow reading "${property}" until the drop event.`);
                    return null;
                }
            });
        });
    }
    loadDataTransfer(dataTransfer) {
        if (dataTransfer) {
            const newProperties = {};
            Object.keys(this.config.exposeProperties).forEach((property)=>{
                const propertyFn = this.config.exposeProperties[property];
                if (propertyFn != null) {
                    newProperties[property] = {
                        value: propertyFn(dataTransfer, this.config.matchesTypes),
                        configurable: true,
                        enumerable: true
                    };
                }
            });
            Object.defineProperties(this.item, newProperties);
        }
    }
    canDrag() {
        return true;
    }
    beginDrag() {
        return this.item;
    }
    isDragging(monitor, handle) {
        return handle === monitor.getSourceId();
    }
    endDrag() {
    // empty
    }
    constructor(config){
        this.config = config;
        this.item = {};
        this.initializeExposedProperties();
    }
}

const FILE = '__NATIVE_FILE__';
const URL = '__NATIVE_URL__';
const TEXT = '__NATIVE_TEXT__';
const HTML = '__NATIVE_HTML__';

var NativeTypes = {
  __proto__: null,
  FILE: FILE,
  URL: URL,
  TEXT: TEXT,
  HTML: HTML
};

function getDataFromDataTransfer(dataTransfer, typesToTry, defaultValue) {
    const result = typesToTry.reduce((resultSoFar, typeToTry)=>resultSoFar || dataTransfer.getData(typeToTry)
    , '');
    return result != null ? result : defaultValue;
}

const nativeTypesConfig = {
    [FILE]: {
        exposeProperties: {
            files: (dataTransfer)=>Array.prototype.slice.call(dataTransfer.files)
            ,
            items: (dataTransfer)=>dataTransfer.items
            ,
            dataTransfer: (dataTransfer)=>dataTransfer
        },
        matchesTypes: [
            'Files'
        ]
    },
    [HTML]: {
        exposeProperties: {
            html: (dataTransfer, matchesTypes)=>getDataFromDataTransfer(dataTransfer, matchesTypes, '')
            ,
            dataTransfer: (dataTransfer)=>dataTransfer
        },
        matchesTypes: [
            'Html',
            'text/html'
        ]
    },
    [URL]: {
        exposeProperties: {
            urls: (dataTransfer, matchesTypes)=>getDataFromDataTransfer(dataTransfer, matchesTypes, '').split('\n')
            ,
            dataTransfer: (dataTransfer)=>dataTransfer
        },
        matchesTypes: [
            'Url',
            'text/uri-list'
        ]
    },
    [TEXT]: {
        exposeProperties: {
            text: (dataTransfer, matchesTypes)=>getDataFromDataTransfer(dataTransfer, matchesTypes, '')
            ,
            dataTransfer: (dataTransfer)=>dataTransfer
        },
        matchesTypes: [
            'Text',
            'text/plain'
        ]
    }
};

function createNativeDragSource(type, dataTransfer) {
    const config = nativeTypesConfig[type];
    if (!config) {
        throw new Error(`native type ${type} has no configuration`);
    }
    const result = new NativeDragSource(config);
    result.loadDataTransfer(dataTransfer);
    return result;
}
function matchNativeItemType(dataTransfer) {
    if (!dataTransfer) {
        return null;
    }
    const dataTransferTypes = Array.prototype.slice.call(dataTransfer.types || []);
    return Object.keys(nativeTypesConfig).filter((nativeItemType)=>{
        const typeConfig = nativeTypesConfig[nativeItemType];
        if (!(typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.matchesTypes)) {
            return false;
        }
        return typeConfig.matchesTypes.some((t)=>dataTransferTypes.indexOf(t) > -1
        );
    })[0] || null;
}

const isFirefox = memoize(()=>/firefox/i.test(navigator.userAgent)
);
const isSafari = memoize(()=>Boolean(window.safari)
);

class MonotonicInterpolant {
    interpolate(x) {
        const { xs , ys , c1s , c2s , c3s  } = this;
        // The rightmost point in the dataset should give an exact result
        let i = xs.length - 1;
        if (x === xs[i]) {
            return ys[i];
        }
        // Search for the interval x is in, returning the corresponding y if x is one of the original xs
        let low = 0;
        let high = c3s.length - 1;
        let mid;
        while(low <= high){
            mid = Math.floor(0.5 * (low + high));
            const xHere = xs[mid];
            if (xHere < x) {
                low = mid + 1;
            } else if (xHere > x) {
                high = mid - 1;
            } else {
                return ys[mid];
            }
        }
        i = Math.max(0, high);
        // Interpolate
        const diff = x - xs[i];
        const diffSq = diff * diff;
        return ys[i] + c1s[i] * diff + c2s[i] * diffSq + c3s[i] * diff * diffSq;
    }
    constructor(xs, ys){
        const { length  } = xs;
        const dxs = [];
        const ms = [];
        let dx;
        let dy;
        for(let i1 = 0; i1 < length - 1; i1++){
            dx = xs[i1 + 1] - xs[i1];
            dy = ys[i1 + 1] - ys[i1];
            dxs.push(dx);
            ms.push(dy / dx);
        }
        // Get degree-1 coefficients
        const c1s = [
            ms[0]
        ];
        for(let i2 = 0; i2 < dxs.length - 1; i2++){
            const m2 = ms[i2];
            const mNext = ms[i2 + 1];
            if (m2 * mNext <= 0) {
                c1s.push(0);
            } else {
                dx = dxs[i2];
                const dxNext = dxs[i2 + 1];
                const common = dx + dxNext;
                c1s.push(3 * common / ((common + dxNext) / m2 + (common + dx) / mNext));
            }
        }
        c1s.push(ms[ms.length - 1]);
        // Get degree-2 and degree-3 coefficients
        const c2s = [];
        const c3s = [];
        let m;
        for(let i3 = 0; i3 < c1s.length - 1; i3++){
            m = ms[i3];
            const c1 = c1s[i3];
            const invDx = 1 / dxs[i3];
            const common = c1 + c1s[i3 + 1] - m - m;
            c2s.push((m - c1 - common) * invDx);
            c3s.push(common * invDx * invDx);
        }
        this.xs = xs;
        this.ys = ys;
        this.c1s = c1s;
        this.c2s = c2s;
        this.c3s = c3s;
    }
}

const ELEMENT_NODE = 1;
function getNodeClientOffset(node) {
    const el = node.nodeType === ELEMENT_NODE ? node : node.parentElement;
    if (!el) {
        return null;
    }
    const { top , left  } = el.getBoundingClientRect();
    return {
        x: left,
        y: top
    };
}
function getEventClientOffset(e) {
    return {
        x: e.clientX,
        y: e.clientY
    };
}
function isImageNode(node) {
    var ref;
    return node.nodeName === 'IMG' && (isFirefox() || !((ref = document.documentElement) === null || ref === void 0 ? void 0 : ref.contains(node)));
}
function getDragPreviewSize(isImage, dragPreview, sourceWidth, sourceHeight) {
    let dragPreviewWidth = isImage ? dragPreview.width : sourceWidth;
    let dragPreviewHeight = isImage ? dragPreview.height : sourceHeight;
    // Work around @2x coordinate discrepancies in browsers
    if (isSafari() && isImage) {
        dragPreviewHeight /= window.devicePixelRatio;
        dragPreviewWidth /= window.devicePixelRatio;
    }
    return {
        dragPreviewWidth,
        dragPreviewHeight
    };
}
function getDragPreviewOffset(sourceNode, dragPreview, clientOffset, anchorPoint, offsetPoint) {
    // The browsers will use the image intrinsic size under different conditions.
    // Firefox only cares if it's an image, but WebKit also wants it to be detached.
    const isImage = isImageNode(dragPreview);
    const dragPreviewNode = isImage ? sourceNode : dragPreview;
    const dragPreviewNodeOffsetFromClient = getNodeClientOffset(dragPreviewNode);
    const offsetFromDragPreview = {
        x: clientOffset.x - dragPreviewNodeOffsetFromClient.x,
        y: clientOffset.y - dragPreviewNodeOffsetFromClient.y
    };
    const { offsetWidth: sourceWidth , offsetHeight: sourceHeight  } = sourceNode;
    const { anchorX , anchorY  } = anchorPoint;
    const { dragPreviewWidth , dragPreviewHeight  } = getDragPreviewSize(isImage, dragPreview, sourceWidth, sourceHeight);
    const calculateYOffset = ()=>{
        const interpolantY = new MonotonicInterpolant([
            0,
            0.5,
            1
        ], [
            // Dock to the top
            offsetFromDragPreview.y,
            // Align at the center
            (offsetFromDragPreview.y / sourceHeight) * dragPreviewHeight,
            // Dock to the bottom
            offsetFromDragPreview.y + dragPreviewHeight - sourceHeight, 
        ]);
        let y = interpolantY.interpolate(anchorY);
        // Work around Safari 8 positioning bug
        if (isSafari() && isImage) {
            // We'll have to wait for @3x to see if this is entirely correct
            y += (window.devicePixelRatio - 1) * dragPreviewHeight;
        }
        return y;
    };
    const calculateXOffset = ()=>{
        // Interpolate coordinates depending on anchor point
        // If you know a simpler way to do this, let me know
        const interpolantX = new MonotonicInterpolant([
            0,
            0.5,
            1
        ], [
            // Dock to the left
            offsetFromDragPreview.x,
            // Align at the center
            (offsetFromDragPreview.x / sourceWidth) * dragPreviewWidth,
            // Dock to the right
            offsetFromDragPreview.x + dragPreviewWidth - sourceWidth, 
        ]);
        return interpolantX.interpolate(anchorX);
    };
    // Force offsets if specified in the options.
    const { offsetX , offsetY  } = offsetPoint;
    const isManualOffsetX = offsetX === 0 || offsetX;
    const isManualOffsetY = offsetY === 0 || offsetY;
    return {
        x: isManualOffsetX ? offsetX : calculateXOffset(),
        y: isManualOffsetY ? offsetY : calculateYOffset()
    };
}

class OptionsReader {
    get window() {
        if (this.globalContext) {
            return this.globalContext;
        } else if (typeof window !== 'undefined') {
            return window;
        }
        return undefined;
    }
    get document() {
        var ref;
        if ((ref = this.globalContext) === null || ref === void 0 ? void 0 : ref.document) {
            return this.globalContext.document;
        } else if (this.window) {
            return this.window.document;
        } else {
            return undefined;
        }
    }
    get rootElement() {
        var ref;
        return ((ref = this.optionsArgs) === null || ref === void 0 ? void 0 : ref.rootElement) || this.window;
    }
    constructor(globalContext, options){
        this.ownerDocument = null;
        this.globalContext = globalContext;
        this.optionsArgs = options;
    }
}

function _defineProperty$4(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread$4(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty$4(target, key, source[key]);
        });
    }
    return target;
}
class HTML5BackendImpl {
    /**
	 * Generate profiling statistics for the HTML5Backend.
	 */ profile() {
        var ref, ref1;
        return {
            sourcePreviewNodes: this.sourcePreviewNodes.size,
            sourcePreviewNodeOptions: this.sourcePreviewNodeOptions.size,
            sourceNodeOptions: this.sourceNodeOptions.size,
            sourceNodes: this.sourceNodes.size,
            dragStartSourceIds: ((ref = this.dragStartSourceIds) === null || ref === void 0 ? void 0 : ref.length) || 0,
            dropTargetIds: this.dropTargetIds.length,
            dragEnterTargetIds: this.dragEnterTargetIds.length,
            dragOverTargetIds: ((ref1 = this.dragOverTargetIds) === null || ref1 === void 0 ? void 0 : ref1.length) || 0
        };
    }
    // public for test
    get window() {
        return this.options.window;
    }
    get document() {
        return this.options.document;
    }
    /**
	 * Get the root element to use for event subscriptions
	 */ get rootElement() {
        return this.options.rootElement;
    }
    setup() {
        const root = this.rootElement;
        if (root === undefined) {
            return;
        }
        if (root.__isReactDndBackendSetUp) {
            throw new Error('Cannot have two HTML5 backends at the same time.');
        }
        root.__isReactDndBackendSetUp = true;
        this.addEventListeners(root);
    }
    teardown() {
        const root = this.rootElement;
        if (root === undefined) {
            return;
        }
        root.__isReactDndBackendSetUp = false;
        this.removeEventListeners(this.rootElement);
        this.clearCurrentDragSourceNode();
        if (this.asyncEndDragFrameId) {
            var ref;
            (ref = this.window) === null || ref === void 0 ? void 0 : ref.cancelAnimationFrame(this.asyncEndDragFrameId);
        }
    }
    connectDragPreview(sourceId, node, options) {
        this.sourcePreviewNodeOptions.set(sourceId, options);
        this.sourcePreviewNodes.set(sourceId, node);
        return ()=>{
            this.sourcePreviewNodes.delete(sourceId);
            this.sourcePreviewNodeOptions.delete(sourceId);
        };
    }
    connectDragSource(sourceId, node, options) {
        this.sourceNodes.set(sourceId, node);
        this.sourceNodeOptions.set(sourceId, options);
        const handleDragStart = (e)=>this.handleDragStart(e, sourceId)
        ;
        const handleSelectStart = (e)=>this.handleSelectStart(e)
        ;
        node.setAttribute('draggable', 'true');
        node.addEventListener('dragstart', handleDragStart);
        node.addEventListener('selectstart', handleSelectStart);
        return ()=>{
            this.sourceNodes.delete(sourceId);
            this.sourceNodeOptions.delete(sourceId);
            node.removeEventListener('dragstart', handleDragStart);
            node.removeEventListener('selectstart', handleSelectStart);
            node.setAttribute('draggable', 'false');
        };
    }
    connectDropTarget(targetId, node) {
        const handleDragEnter = (e)=>this.handleDragEnter(e, targetId)
        ;
        const handleDragOver = (e)=>this.handleDragOver(e, targetId)
        ;
        const handleDrop = (e)=>this.handleDrop(e, targetId)
        ;
        node.addEventListener('dragenter', handleDragEnter);
        node.addEventListener('dragover', handleDragOver);
        node.addEventListener('drop', handleDrop);
        return ()=>{
            node.removeEventListener('dragenter', handleDragEnter);
            node.removeEventListener('dragover', handleDragOver);
            node.removeEventListener('drop', handleDrop);
        };
    }
    addEventListeners(target) {
        // SSR Fix (https://github.com/react-dnd/react-dnd/pull/813
        if (!target.addEventListener) {
            return;
        }
        target.addEventListener('dragstart', this.handleTopDragStart);
        target.addEventListener('dragstart', this.handleTopDragStartCapture, true);
        target.addEventListener('dragend', this.handleTopDragEndCapture, true);
        target.addEventListener('dragenter', this.handleTopDragEnter);
        target.addEventListener('dragenter', this.handleTopDragEnterCapture, true);
        target.addEventListener('dragleave', this.handleTopDragLeaveCapture, true);
        target.addEventListener('dragover', this.handleTopDragOver);
        target.addEventListener('dragover', this.handleTopDragOverCapture, true);
        target.addEventListener('drop', this.handleTopDrop);
        target.addEventListener('drop', this.handleTopDropCapture, true);
    }
    removeEventListeners(target) {
        // SSR Fix (https://github.com/react-dnd/react-dnd/pull/813
        if (!target.removeEventListener) {
            return;
        }
        target.removeEventListener('dragstart', this.handleTopDragStart);
        target.removeEventListener('dragstart', this.handleTopDragStartCapture, true);
        target.removeEventListener('dragend', this.handleTopDragEndCapture, true);
        target.removeEventListener('dragenter', this.handleTopDragEnter);
        target.removeEventListener('dragenter', this.handleTopDragEnterCapture, true);
        target.removeEventListener('dragleave', this.handleTopDragLeaveCapture, true);
        target.removeEventListener('dragover', this.handleTopDragOver);
        target.removeEventListener('dragover', this.handleTopDragOverCapture, true);
        target.removeEventListener('drop', this.handleTopDrop);
        target.removeEventListener('drop', this.handleTopDropCapture, true);
    }
    getCurrentSourceNodeOptions() {
        const sourceId = this.monitor.getSourceId();
        const sourceNodeOptions = this.sourceNodeOptions.get(sourceId);
        return _objectSpread$4({
            dropEffect: this.altKeyPressed ? 'copy' : 'move'
        }, sourceNodeOptions || {});
    }
    getCurrentDropEffect() {
        if (this.isDraggingNativeItem()) {
            // It makes more sense to default to 'copy' for native resources
            return 'copy';
        }
        return this.getCurrentSourceNodeOptions().dropEffect;
    }
    getCurrentSourcePreviewNodeOptions() {
        const sourceId = this.monitor.getSourceId();
        const sourcePreviewNodeOptions = this.sourcePreviewNodeOptions.get(sourceId);
        return _objectSpread$4({
            anchorX: 0.5,
            anchorY: 0.5,
            captureDraggingState: false
        }, sourcePreviewNodeOptions || {});
    }
    isDraggingNativeItem() {
        const itemType = this.monitor.getItemType();
        return Object.keys(NativeTypes).some((key)=>NativeTypes[key] === itemType
        );
    }
    beginDragNativeItem(type, dataTransfer) {
        this.clearCurrentDragSourceNode();
        this.currentNativeSource = createNativeDragSource(type, dataTransfer);
        this.currentNativeHandle = this.registry.addSource(type, this.currentNativeSource);
        this.actions.beginDrag([
            this.currentNativeHandle
        ]);
    }
    setCurrentDragSourceNode(node) {
        this.clearCurrentDragSourceNode();
        this.currentDragSourceNode = node;
        // A timeout of > 0 is necessary to resolve Firefox issue referenced
        // See:
        //   * https://github.com/react-dnd/react-dnd/pull/928
        //   * https://github.com/react-dnd/react-dnd/issues/869
        const MOUSE_MOVE_TIMEOUT = 1000;
        // Receiving a mouse event in the middle of a dragging operation
        // means it has ended and the drag source node disappeared from DOM,
        // so the browser didn't dispatch the dragend event.
        //
        // We need to wait before we start listening for mousemove events.
        // This is needed because the drag preview needs to be drawn or else it fires an 'mousemove' event
        // immediately in some browsers.
        //
        // See:
        //   * https://github.com/react-dnd/react-dnd/pull/928
        //   * https://github.com/react-dnd/react-dnd/issues/869
        //
        this.mouseMoveTimeoutTimer = setTimeout(()=>{
            var ref;
            return (ref = this.rootElement) === null || ref === void 0 ? void 0 : ref.addEventListener('mousemove', this.endDragIfSourceWasRemovedFromDOM, true);
        }, MOUSE_MOVE_TIMEOUT);
    }
    clearCurrentDragSourceNode() {
        if (this.currentDragSourceNode) {
            this.currentDragSourceNode = null;
            if (this.rootElement) {
                var ref;
                (ref = this.window) === null || ref === void 0 ? void 0 : ref.clearTimeout(this.mouseMoveTimeoutTimer || undefined);
                this.rootElement.removeEventListener('mousemove', this.endDragIfSourceWasRemovedFromDOM, true);
            }
            this.mouseMoveTimeoutTimer = null;
            return true;
        }
        return false;
    }
    handleDragStart(e, sourceId) {
        if (e.defaultPrevented) {
            return;
        }
        if (!this.dragStartSourceIds) {
            this.dragStartSourceIds = [];
        }
        this.dragStartSourceIds.unshift(sourceId);
    }
    handleDragEnter(_e, targetId) {
        this.dragEnterTargetIds.unshift(targetId);
    }
    handleDragOver(_e, targetId) {
        if (this.dragOverTargetIds === null) {
            this.dragOverTargetIds = [];
        }
        this.dragOverTargetIds.unshift(targetId);
    }
    handleDrop(_e, targetId) {
        this.dropTargetIds.unshift(targetId);
    }
    constructor(manager, globalContext, options){
        this.sourcePreviewNodes = new Map();
        this.sourcePreviewNodeOptions = new Map();
        this.sourceNodes = new Map();
        this.sourceNodeOptions = new Map();
        this.dragStartSourceIds = null;
        this.dropTargetIds = [];
        this.dragEnterTargetIds = [];
        this.currentNativeSource = null;
        this.currentNativeHandle = null;
        this.currentDragSourceNode = null;
        this.altKeyPressed = false;
        this.mouseMoveTimeoutTimer = null;
        this.asyncEndDragFrameId = null;
        this.dragOverTargetIds = null;
        this.lastClientOffset = null;
        this.hoverRafId = null;
        this.getSourceClientOffset = (sourceId)=>{
            const source = this.sourceNodes.get(sourceId);
            return source && getNodeClientOffset(source) || null;
        };
        this.endDragNativeItem = ()=>{
            if (!this.isDraggingNativeItem()) {
                return;
            }
            this.actions.endDrag();
            if (this.currentNativeHandle) {
                this.registry.removeSource(this.currentNativeHandle);
            }
            this.currentNativeHandle = null;
            this.currentNativeSource = null;
        };
        this.isNodeInDocument = (node)=>{
            // Check the node either in the main document or in the current context
            return Boolean(node && this.document && this.document.body && this.document.body.contains(node));
        };
        this.endDragIfSourceWasRemovedFromDOM = ()=>{
            const node = this.currentDragSourceNode;
            if (node == null || this.isNodeInDocument(node)) {
                return;
            }
            if (this.clearCurrentDragSourceNode() && this.monitor.isDragging()) {
                this.actions.endDrag();
            }
            this.cancelHover();
        };
        this.scheduleHover = (dragOverTargetIds)=>{
            if (this.hoverRafId === null && typeof requestAnimationFrame !== 'undefined') {
                this.hoverRafId = requestAnimationFrame(()=>{
                    if (this.monitor.isDragging()) {
                        this.actions.hover(dragOverTargetIds || [], {
                            clientOffset: this.lastClientOffset
                        });
                    }
                    this.hoverRafId = null;
                });
            }
        };
        this.cancelHover = ()=>{
            if (this.hoverRafId !== null && typeof cancelAnimationFrame !== 'undefined') {
                cancelAnimationFrame(this.hoverRafId);
                this.hoverRafId = null;
            }
        };
        this.handleTopDragStartCapture = ()=>{
            this.clearCurrentDragSourceNode();
            this.dragStartSourceIds = [];
        };
        this.handleTopDragStart = (e)=>{
            if (e.defaultPrevented) {
                return;
            }
            const { dragStartSourceIds  } = this;
            this.dragStartSourceIds = null;
            const clientOffset = getEventClientOffset(e);
            // Avoid crashing if we missed a drop event or our previous drag died
            if (this.monitor.isDragging()) {
                this.actions.endDrag();
                this.cancelHover();
            }
            // Don't publish the source just yet (see why below)
            this.actions.beginDrag(dragStartSourceIds || [], {
                publishSource: false,
                getSourceClientOffset: this.getSourceClientOffset,
                clientOffset
            });
            const { dataTransfer  } = e;
            const nativeType = matchNativeItemType(dataTransfer);
            if (this.monitor.isDragging()) {
                if (dataTransfer && typeof dataTransfer.setDragImage === 'function') {
                    // Use custom drag image if user specifies it.
                    // If child drag source refuses drag but parent agrees,
                    // use parent's node as drag image. Neither works in IE though.
                    const sourceId = this.monitor.getSourceId();
                    const sourceNode = this.sourceNodes.get(sourceId);
                    const dragPreview = this.sourcePreviewNodes.get(sourceId) || sourceNode;
                    if (dragPreview) {
                        const { anchorX , anchorY , offsetX , offsetY  } = this.getCurrentSourcePreviewNodeOptions();
                        const anchorPoint = {
                            anchorX,
                            anchorY
                        };
                        const offsetPoint = {
                            offsetX,
                            offsetY
                        };
                        const dragPreviewOffset = getDragPreviewOffset(sourceNode, dragPreview, clientOffset, anchorPoint, offsetPoint);
                        dataTransfer.setDragImage(dragPreview, dragPreviewOffset.x, dragPreviewOffset.y);
                    }
                }
                try {
                    // Firefox won't drag without setting data
                    dataTransfer === null || dataTransfer === void 0 ? void 0 : dataTransfer.setData('application/json', {});
                } catch (err) {
                // IE doesn't support MIME types in setData
                }
                // Store drag source node so we can check whether
                // it is removed from DOM and trigger endDrag manually.
                this.setCurrentDragSourceNode(e.target);
                // Now we are ready to publish the drag source.. or are we not?
                const { captureDraggingState  } = this.getCurrentSourcePreviewNodeOptions();
                if (!captureDraggingState) {
                    // Usually we want to publish it in the next tick so that browser
                    // is able to screenshot the current (not yet dragging) state.
                    //
                    // It also neatly avoids a situation where render() returns null
                    // in the same tick for the source element, and browser freaks out.
                    setTimeout(()=>this.actions.publishDragSource()
                    , 0);
                } else {
                    // In some cases the user may want to override this behavior, e.g.
                    // to work around IE not supporting custom drag previews.
                    //
                    // When using a custom drag layer, the only way to prevent
                    // the default drag preview from drawing in IE is to screenshot
                    // the dragging state in which the node itself has zero opacity
                    // and height. In this case, though, returning null from render()
                    // will abruptly end the dragging, which is not obvious.
                    //
                    // This is the reason such behavior is strictly opt-in.
                    this.actions.publishDragSource();
                }
            } else if (nativeType) {
                // A native item (such as URL) dragged from inside the document
                this.beginDragNativeItem(nativeType);
            } else if (dataTransfer && !dataTransfer.types && (e.target && !e.target.hasAttribute || !e.target.hasAttribute('draggable'))) {
                // Looks like a Safari bug: dataTransfer.types is null, but there was no draggable.
                // Just let it drag. It's a native type (URL or text) and will be picked up in
                // dragenter handler.
                return;
            } else {
                // If by this time no drag source reacted, tell browser not to drag.
                e.preventDefault();
            }
        };
        this.handleTopDragEndCapture = ()=>{
            if (this.clearCurrentDragSourceNode() && this.monitor.isDragging()) {
                // Firefox can dispatch this event in an infinite loop
                // if dragend handler does something like showing an alert.
                // Only proceed if we have not handled it already.
                this.actions.endDrag();
            }
            this.cancelHover();
        };
        this.handleTopDragEnterCapture = (e)=>{
            this.dragEnterTargetIds = [];
            if (this.isDraggingNativeItem()) {
                var ref;
                (ref = this.currentNativeSource) === null || ref === void 0 ? void 0 : ref.loadDataTransfer(e.dataTransfer);
            }
            const isFirstEnter = this.enterLeaveCounter.enter(e.target);
            if (!isFirstEnter || this.monitor.isDragging()) {
                return;
            }
            const { dataTransfer  } = e;
            const nativeType = matchNativeItemType(dataTransfer);
            if (nativeType) {
                // A native item (such as file or URL) dragged from outside the document
                this.beginDragNativeItem(nativeType, dataTransfer);
            }
        };
        this.handleTopDragEnter = (e)=>{
            const { dragEnterTargetIds  } = this;
            this.dragEnterTargetIds = [];
            if (!this.monitor.isDragging()) {
                // This is probably a native item type we don't understand.
                return;
            }
            this.altKeyPressed = e.altKey;
            // If the target changes position as the result of `dragenter`, `dragover` might still
            // get dispatched despite target being no longer there. The easy solution is to check
            // whether there actually is a target before firing `hover`.
            if (dragEnterTargetIds.length > 0) {
                this.actions.hover(dragEnterTargetIds, {
                    clientOffset: getEventClientOffset(e)
                });
            }
            const canDrop = dragEnterTargetIds.some((targetId)=>this.monitor.canDropOnTarget(targetId)
            );
            if (canDrop) {
                // IE requires this to fire dragover events
                e.preventDefault();
                if (e.dataTransfer) {
                    e.dataTransfer.dropEffect = this.getCurrentDropEffect();
                }
            }
        };
        this.handleTopDragOverCapture = (e)=>{
            this.dragOverTargetIds = [];
            if (this.isDraggingNativeItem()) {
                var ref;
                (ref = this.currentNativeSource) === null || ref === void 0 ? void 0 : ref.loadDataTransfer(e.dataTransfer);
            }
        };
        this.handleTopDragOver = (e)=>{
            const { dragOverTargetIds  } = this;
            this.dragOverTargetIds = [];
            if (!this.monitor.isDragging()) {
                // This is probably a native item type we don't understand.
                // Prevent default "drop and blow away the whole document" action.
                e.preventDefault();
                if (e.dataTransfer) {
                    e.dataTransfer.dropEffect = 'none';
                }
                return;
            }
            this.altKeyPressed = e.altKey;
            this.lastClientOffset = getEventClientOffset(e);
            this.scheduleHover(dragOverTargetIds);
            const canDrop = (dragOverTargetIds || []).some((targetId)=>this.monitor.canDropOnTarget(targetId)
            );
            if (canDrop) {
                // Show user-specified drop effect.
                e.preventDefault();
                if (e.dataTransfer) {
                    e.dataTransfer.dropEffect = this.getCurrentDropEffect();
                }
            } else if (this.isDraggingNativeItem()) {
                // Don't show a nice cursor but still prevent default
                // "drop and blow away the whole document" action.
                e.preventDefault();
            } else {
                e.preventDefault();
                if (e.dataTransfer) {
                    e.dataTransfer.dropEffect = 'none';
                }
            }
        };
        this.handleTopDragLeaveCapture = (e)=>{
            if (this.isDraggingNativeItem()) {
                e.preventDefault();
            }
            const isLastLeave = this.enterLeaveCounter.leave(e.target);
            if (!isLastLeave) {
                return;
            }
            if (this.isDraggingNativeItem()) {
                setTimeout(()=>this.endDragNativeItem()
                , 0);
            }
            this.cancelHover();
        };
        this.handleTopDropCapture = (e)=>{
            this.dropTargetIds = [];
            if (this.isDraggingNativeItem()) {
                var ref;
                e.preventDefault();
                (ref = this.currentNativeSource) === null || ref === void 0 ? void 0 : ref.loadDataTransfer(e.dataTransfer);
            } else if (matchNativeItemType(e.dataTransfer)) {
                // Dragging some elements, like <a> and <img> may still behave like a native drag event,
                // even if the current drag event matches a user-defined type.
                // Stop the default behavior when we're not expecting a native item to be dropped.
                e.preventDefault();
            }
            this.enterLeaveCounter.reset();
        };
        this.handleTopDrop = (e)=>{
            const { dropTargetIds  } = this;
            this.dropTargetIds = [];
            this.actions.hover(dropTargetIds, {
                clientOffset: getEventClientOffset(e)
            });
            this.actions.drop({
                dropEffect: this.getCurrentDropEffect()
            });
            if (this.isDraggingNativeItem()) {
                this.endDragNativeItem();
            } else if (this.monitor.isDragging()) {
                this.actions.endDrag();
            }
            this.cancelHover();
        };
        this.handleSelectStart = (e)=>{
            const target = e.target;
            // Only IE requires us to explicitly say
            // we want drag drop operation to start
            if (typeof target.dragDrop !== 'function') {
                return;
            }
            // Inputs and textareas should be selectable
            if (target.tagName === 'INPUT' || target.tagName === 'SELECT' || target.tagName === 'TEXTAREA' || target.isContentEditable) {
                return;
            }
            // For other targets, ask IE
            // to enable drag and drop
            e.preventDefault();
            target.dragDrop();
        };
        this.options = new OptionsReader(globalContext, options);
        this.actions = manager.getActions();
        this.monitor = manager.getMonitor();
        this.registry = manager.getRegistry();
        this.enterLeaveCounter = new EnterLeaveCounter(this.isNodeInDocument);
    }
}

const HTML5Backend = function createBackend(manager, context, options) {
    return new HTML5BackendImpl(manager, context, options);
};

var _excluded = ["tableInstance"];
var MRT_FullScreenToggleButton = function MRT_FullScreenToggleButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FullscreenExitIcon = _tableInstance$option2.FullscreenExitIcon,
      FullscreenIcon = _tableInstance$option2.FullscreenIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleFullScreen = _tableInstance$option.onMrtToggleFullScreen,
      setIsFullScreen = tableInstance.setIsFullScreen;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var handleToggleFullScreen = function handleToggleFullScreen(event) {
    onMrtToggleFullScreen == null ? void 0 : onMrtToggleFullScreen({
      event: event,
      isFullScreen: !isFullScreen,
      tableInstance: tableInstance
    });
    setIsFullScreen(!isFullScreen);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.toggleFullScreen
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleFullScreen
  }, rest), isFullScreen ? React__default.createElement(FullscreenExitIcon, null) : React__default.createElement(FullscreenIcon, null)));
};

var _excluded$1 = ["tableInstance"];
var MRT_ShowHideColumnsButton = function MRT_ShowHideColumnsButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _tableInstance$option = tableInstance.options,
      ViewColumnIcon = _tableInstance$option.icons.ViewColumnIcon,
      localization = _tableInstance$option.localization;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideColumns
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideColumns,
    onClick: handleClick
  }, rest), React__default.createElement(ViewColumnIcon, null))), React__default.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var _excluded$2 = ["tableInstance"];
var MRT_ToggleDensePaddingButton = function MRT_ToggleDensePaddingButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      DensityMediumIcon = _tableInstance$option2.DensityMediumIcon,
      DensitySmallIcon = _tableInstance$option2.DensitySmallIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleDensePadding = _tableInstance$option.onMrtToggleDensePadding,
      setIsDensePadding = tableInstance.setIsDensePadding;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleToggleDensePadding = function handleToggleDensePadding(event) {
    onMrtToggleDensePadding == null ? void 0 : onMrtToggleDensePadding({
      event: event,
      isDensePadding: !isDensePadding,
      tableInstance: tableInstance
    });
    setIsDensePadding(!isDensePadding);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.toggleDensePadding
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.toggleDensePadding,
    onClick: handleToggleDensePadding
  }, rest), isDensePadding ? React__default.createElement(DensitySmallIcon, null) : React__default.createElement(DensityMediumIcon, null)));
};

var _excluded$3 = ["tableInstance"];
var MRT_ToggleFiltersButton = function MRT_ToggleFiltersButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$3);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      localization = _tableInstance$option.localization,
      onMrtToggleShowFilters = _tableInstance$option.onMrtToggleShowFilters,
      setShowFilters = tableInstance.setShowFilters;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var handleToggleShowFilters = function handleToggleShowFilters(event) {
    onMrtToggleShowFilters == null ? void 0 : onMrtToggleShowFilters({
      event: event,
      showFilters: !showFilters,
      tableInstance: tableInstance
    });
    setShowFilters(!showFilters);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideFilters
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleShowFilters
  }, rest), showFilters ? React__default.createElement(FilterListOffIcon, null) : React__default.createElement(FilterListIcon, null)));
};

var _excluded$4 = ["tableInstance"];
var MRT_ToggleGlobalFilterButton = function MRT_ToggleGlobalFilterButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$4);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      SearchOffIcon = _tableInstance$option2.SearchOffIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      onMrtToggleShowGlobalFilter = _tableInstance$option.onMrtToggleShowGlobalFilter,
      setShowGlobalFilter = tableInstance.setShowGlobalFilter;

  var _getState = getState(),
      showGlobalFilter = _getState.showGlobalFilter;

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;

  var handleToggleSearch = function handleToggleSearch(event) {
    onMrtToggleShowGlobalFilter == null ? void 0 : onMrtToggleShowGlobalFilter({
      event: event,
      showGlobalFilter: !showGlobalFilter,
      tableInstance: tableInstance
    });
    setShowGlobalFilter(!showGlobalFilter);
    setTimeout(function () {
      var _document$getElementB, _textFieldProps$id;

      return (_document$getElementB = document.getElementById((_textFieldProps$id = textFieldProps == null ? void 0 : textFieldProps.id) != null ? _textFieldProps$id : "mrt-" + tableId + "-search-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideSearch
  }, React__default.createElement(material.IconButton, Object.assign({
    onClick: handleToggleSearch
  }, rest), showGlobalFilter ? React__default.createElement(SearchOffIcon, null) : React__default.createElement(SearchIcon, null)));
};

var MRT_SearchTextField = function MRT_SearchTextField(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      setGlobalFilter = tableInstance.setGlobalFilter,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      onMrtGlobalFilterValueChange = _tableInstance$option.onMrtGlobalFilterValueChange;

  var _getState = getState(),
      globalFilter = _getState.globalFilter,
      showGlobalFilter = _getState.showGlobalFilter;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var _useState2 = React.useState(globalFilter != null ? globalFilter : ''),
      searchValue = _useState2[0],
      setSearchValue = _useState2[1];

  var handleChange = React.useCallback(material.debounce(function (event) {
    var _event$target$value;

    setGlobalFilter((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
    onMrtGlobalFilterValueChange == null ? void 0 : onMrtGlobalFilterValueChange({
      event: event,
      tableInstance: tableInstance
    });
  }, 200), []);

  var handleGlobalFilterMenuOpen = function handleGlobalFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setSearchValue('');
    setGlobalFilter(undefined);
  };

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;
  return React__default.createElement(material.Collapse, {
    "in": showGlobalFilter,
    orientation: "horizontal"
  }, React__default.createElement(material.TextField, Object.assign({
    id: "mrt-" + tableId + "-search-text-field",
    placeholder: localization.search,
    onChange: function onChange(event) {
      setSearchValue(event.target.value);
      handleChange(event);
    },
    value: searchValue != null ? searchValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: React__default.createElement(material.InputAdornment, {
        position: "start"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        title: localization.changeSearchMode
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.changeSearchMode,
        onClick: handleGlobalFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(SearchIcon, null))))),
      endAdornment: React__default.createElement(material.InputAdornment, {
        position: "end"
      }, React__default.createElement(material.IconButton, {
        "aria-label": localization.clearSearch,
        disabled: (searchValue == null ? void 0 : searchValue.length) === 0,
        onClick: handleClear,
        size: "small",
        title: localization.clearSearch
      }, React__default.createElement(CloseIcon, null)))
    }
  }, textFieldProps, {
    sx: _extends({
      justifySelf: 'end'
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  })), React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_ToolbarInternalButtons = function MRT_ToolbarInternalButtons(_ref) {
  var _renderToolbarInterna;

  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableDensePaddingToggle = _tableInstance$option.enableDensePaddingToggle,
      enableFilters = _tableInstance$option.enableFilters,
      enableFullScreenToggle = _tableInstance$option.enableFullScreenToggle,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enableHiding = _tableInstance$option.enableHiding,
      positionGlobalFilter = _tableInstance$option.positionGlobalFilter,
      renderToolbarInternalActions = _tableInstance$option.renderToolbarInternalActions;
  return React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      alignItems: 'center',
      zIndex: 3
    }
  }, (_renderToolbarInterna = renderToolbarInternalActions == null ? void 0 : renderToolbarInternalActions({
    MRT_FullScreenToggleButton: MRT_FullScreenToggleButton,
    MRT_ShowHideColumnsButton: MRT_ShowHideColumnsButton,
    MRT_ToggleDensePaddingButton: MRT_ToggleDensePaddingButton,
    MRT_ToggleFiltersButton: MRT_ToggleFiltersButton,
    MRT_ToggleGlobalFilterButton: MRT_ToggleGlobalFilterButton,
    tableInstance: tableInstance
  })) != null ? _renderToolbarInterna : React__default.createElement(React__default.Fragment, null, enableGlobalFilter && positionGlobalFilter === 'right' && React__default.createElement(MRT_SearchTextField, {
    tableInstance: tableInstance
  }), enableFilters && enableGlobalFilter && React__default.createElement(MRT_ToggleGlobalFilterButton, {
    tableInstance: tableInstance
  }), enableFilters && enableColumnFilters && React__default.createElement(MRT_ToggleFiltersButton, {
    tableInstance: tableInstance
  }), enableHiding && React__default.createElement(MRT_ShowHideColumnsButton, {
    tableInstance: tableInstance
  }), enableDensePaddingToggle && React__default.createElement(MRT_ToggleDensePaddingButton, {
    tableInstance: tableInstance
  }), enableFullScreenToggle && React__default.createElement(MRT_FullScreenToggleButton, {
    tableInstance: tableInstance
  })));
};

var MRT_TablePagination = function MRT_TablePagination(_ref) {
  var tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getState = tableInstance.getState,
      setPageIndex = tableInstance.setPageIndex,
      setPageSize = tableInstance.setPageSize,
      muiTablePaginationProps = tableInstance.options.muiTablePaginationProps;

  var _getState = getState(),
      _getState$pagination = _getState.pagination,
      _getState$pagination$ = _getState$pagination.pageSize,
      pageSize = _getState$pagination$ === void 0 ? 10 : _getState$pagination$,
      _getState$pagination$2 = _getState$pagination.pageIndex,
      pageIndex = _getState$pagination$2 === void 0 ? 0 : _getState$pagination$2;

  var tablePaginationProps = muiTablePaginationProps instanceof Function ? muiTablePaginationProps({
    tableInstance: tableInstance
  }) : muiTablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    setPageSize(+event.target.value);
  };

  var showFirstLastPageButtons = getPrePaginationRowModel().rows.length / pageSize > 2;
  return React__default.createElement(material.TablePagination, Object.assign({
    SelectProps: {
      sx: {
        m: '0 1rem 0 1ch'
      },
      MenuProps: {
        MenuListProps: {
          disablePadding: true
        }
      }
    },
    component: "div",
    count: getPrePaginationRowModel().rows.length,
    onPageChange: function onPageChange(_, newPage) {
      return setPageIndex(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: pageIndex,
    rowsPerPage: pageSize,
    rowsPerPageOptions: [5, 10, 15, 20, 25, 30, 50, 100],
    showFirstButton: showFirstLastPageButtons,
    showLastButton: showFirstLastPageButtons
  }, tablePaginationProps, {
    sx: _extends({
      m: '0 0.5rem',
      position: 'relative',
      zIndex: 2
    }, tablePaginationProps == null ? void 0 : tablePaginationProps.sx)
  }));
};

var MRT_ToolbarAlertBanner = function MRT_ToolbarAlertBanner(_ref) {
  var _localization$selecte, _localization$selecte2;

  var stackAlertBanner = _ref.stackAlertBanner,
      tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableToolbarAlertBannerProps = _tableInstance$option.muiTableToolbarAlertBannerProps;

  var _getState = getState(),
      grouping = _getState.grouping;

  var alertProps = muiTableToolbarAlertBannerProps instanceof Function ? muiTableToolbarAlertBannerProps({
    tableInstance: tableInstance
  }) : muiTableToolbarAlertBannerProps;
  var selectMessage = getSelectedRowModel().rows.length > 0 ? (_localization$selecte = localization.selectedCountOfRowCountRowsSelected) == null ? void 0 : (_localization$selecte2 = _localization$selecte.replace('{selectedCount}', getSelectedRowModel().rows.length.toString())) == null ? void 0 : _localization$selecte2.replace('{rowCount}', getPrePaginationRowModel().rows.length.toString()) : null;
  var groupedByMessage = grouping.length > 0 ? React__default.createElement("span", null, localization.groupedBy, ' ', grouping.map(function (columnId, index) {
    return React__default.createElement(React.Fragment, {
      key: index + "-" + columnId
    }, index > 0 ? localization.thenBy : '', React__default.createElement(material.Chip, {
      color: "secondary",
      label: tableInstance.getColumn(columnId).columnDef.header,
      onDelete: function onDelete() {
        return tableInstance.getColumn(columnId).toggleGrouping();
      }
    }));
  })) : null;
  return React__default.createElement(material.Collapse, {
    "in": !!selectMessage || !!groupedByMessage,
    timeout: stackAlertBanner ? 200 : 0
  }, React__default.createElement(material.Alert, Object.assign({
    color: "info",
    icon: false,
    sx: _extends({
      borderRadius: 0,
      fontSize: '1rem',
      left: 0,
      p: 0,
      position: 'relative',
      right: 0,
      top: 0,
      width: '100%',
      zIndex: 2
    }, alertProps == null ? void 0 : alertProps.sx)
  }, alertProps), React__default.createElement(material.Box, {
    sx: {
      p: '0.5rem 1rem'
    }
  }, selectMessage, selectMessage && groupedByMessage && React__default.createElement("br", null), groupedByMessage)));
};

var MRT_LinearProgressBar = function MRT_LinearProgressBar(_ref) {
  var alignTo = _ref.alignTo,
      tableInstance = _ref.tableInstance;
  var muiLinearProgressProps = tableInstance.options.muiLinearProgressProps,
      getState = tableInstance.getState;

  var _getState = getState(),
      isLoading = _getState.isLoading,
      showProgressBars = _getState.showProgressBars;

  var linearProgressProps = muiLinearProgressProps instanceof Function ? muiLinearProgressProps({
    tableInstance: tableInstance
  }) : muiLinearProgressProps;
  return React__default.createElement(material.Collapse, {
    "in": isLoading || showProgressBars,
    mountOnEnter: true,
    unmountOnExit: true,
    sx: {
      bottom: alignTo === 'bottom' ? 0 : undefined,
      position: 'absolute',
      top: alignTo === 'top' ? 0 : undefined,
      width: '100%'
    }
  }, React__default.createElement(material.LinearProgress, Object.assign({
    "aria-label": "Loading",
    "aria-busy": "true",
    sx: {
      position: 'relative'
    }
  }, linearProgressProps)));
};

var commonToolbarStyles = function commonToolbarStyles(_ref) {
  var theme = _ref.theme;
  return {
    backgroundColor: material.lighten(theme.palette.background["default"], 0.04),
    backgroundImage: 'none',
    display: 'grid',
    minHeight: '3.5rem',
    overflow: 'hidden',
    p: '0 !important',
    transition: 'all 0.2s ease-in-out',
    width: '100%',
    zIndex: 1
  };
};
var MRT_ToolbarTop = function MRT_ToolbarTop(_ref2) {
  var _renderToolbarCustomA;

  var tableInstance = _ref2.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enablePagination = _tableInstance$option.enablePagination,
      enableToolbarInternalActions = _tableInstance$option.enableToolbarInternalActions,
      tableId = _tableInstance$option.tableId,
      muiTableToolbarTopProps = _tableInstance$option.muiTableToolbarTopProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionGlobalFilter = _tableInstance$option.positionGlobalFilter,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen,
      showGlobalFilter = _getState.showGlobalFilter;

  var isMobile = material.useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarTopProps instanceof Function ? muiTableToolbarTopProps({
    tableInstance: tableInstance
  }) : muiTableToolbarTopProps;
  var stackAlertBanner = isMobile || positionToolbarAlertBanner === 'top' && (!!renderToolbarCustomActions || showGlobalFilter);
  return React__default.createElement(material.Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-top",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        position: isFullScreen ? 'sticky' : undefined,
        top: isFullScreen ? '0' : undefined
      }, commonToolbarStyles({
        theme: theme
      }), toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), positionToolbarAlertBanner === 'top' && React__default.createElement(MRT_ToolbarAlertBanner, {
    stackAlertBanner: stackAlertBanner,
    tableInstance: tableInstance
  }), React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      p: '0.5rem',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0,
      width: renderToolbarCustomActions ? '100%' : undefined
    }
  }, enableGlobalFilter && positionGlobalFilter === 'left' && React__default.createElement(MRT_SearchTextField, {
    tableInstance: tableInstance
  }), (_renderToolbarCustomA = renderToolbarCustomActions == null ? void 0 : renderToolbarCustomActions({
    tableInstance: tableInstance
  })) != null ? _renderToolbarCustomA : React__default.createElement("span", null), enableToolbarInternalActions && positionToolbarActions === 'top' && React__default.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  })), React__default.createElement("div", null, enablePagination && ['top', 'both'].includes(positionPagination != null ? positionPagination : '') && React__default.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })), React__default.createElement(MRT_LinearProgressBar, {
    alignTo: "bottom",
    tableInstance: tableInstance
  }));
};

var MRT_ToolbarBottom = function MRT_ToolbarBottom(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableToolbarInternalActions = _tableInstance$option.enableToolbarInternalActions,
      tableId = _tableInstance$option.tableId,
      enablePagination = _tableInstance$option.enablePagination,
      muiTableToolbarBottomProps = _tableInstance$option.muiTableToolbarBottomProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var isMobile = material.useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarBottomProps instanceof Function ? muiTableToolbarBottomProps({
    tableInstance: tableInstance
  }) : muiTableToolbarBottomProps;
  var stackAlertBanner = isMobile || positionToolbarAlertBanner === 'bottom' && positionToolbarActions === 'bottom' || positionToolbarAlertBanner === 'bottom' && !!renderToolbarCustomActions && positionToolbarActions === 'bottom';
  return React__default.createElement(material.Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-bottom",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({}, commonToolbarStyles({
        theme: theme
      }), {
        bottom: isFullScreen ? '0' : undefined,
        boxShadow: "-3px 0 6px " + material.alpha(theme.palette.common.black, 0.1),
        position: isFullScreen ? 'fixed' : 'relative'
      }, toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), React__default.createElement(MRT_LinearProgressBar, {
    alignTo: "top",
    tableInstance: tableInstance
  }), positionToolbarAlertBanner === 'bottom' && React__default.createElement(MRT_ToolbarAlertBanner, {
    tableInstance: tableInstance
  }), React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      width: '100%',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0
    }
  }, enableToolbarInternalActions && positionToolbarActions === 'bottom' ? React__default.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  }) : React__default.createElement("span", null), enablePagination && ['bottom', 'both'].includes(positionPagination != null ? positionPagination : '') && React__default.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })));
};

var MRT_FilterTextField = function MRT_FilterTextField(_ref) {
  var _localization$filterB, _localization$filterM, _localization$, _localization$clearFi, _columnDef$filterSele;

  var header = _ref.header,
      inputIndex = _ref.inputIndex,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      tableId = _tableInstance$option.tableId,
      localization = _tableInstance$option.localization,
      muiTableHeadCellFilterTextFieldProps = _tableInstance$option.muiTableHeadCellFilterTextFieldProps,
      setCurrentFilterFns = tableInstance.setCurrentFilterFns;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var mTableHeadCellFilterTextFieldProps = muiTableHeadCellFilterTextFieldProps instanceof Function ? muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellFilterTextFieldProps;
  var mcTableHeadCellFilterTextFieldProps = columnDef.muiTableHeadCellFilterTextFieldProps instanceof Function ? columnDef.muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellFilterTextFieldProps;

  var textFieldProps = _extends({}, mTableHeadCellFilterTextFieldProps, mcTableHeadCellFilterTextFieldProps);

  var _useState2 = React.useState(function () {
    var _column$getFilterValu, _column$getFilterValu2, _column$getFilterValu3;

    return inputIndex !== undefined ? (_column$getFilterValu = (_column$getFilterValu2 = column.getFilterValue()) == null ? void 0 : _column$getFilterValu2[inputIndex]) != null ? _column$getFilterValu : '' : (_column$getFilterValu3 = column.getFilterValue()) != null ? _column$getFilterValu3 : '';
  }),
      filterValue = _useState2[0],
      setFilterValue = _useState2[1];

  var handleChangeDebounced = React.useCallback(material.debounce(function (event) {
    var _event$target$value;

    return inputIndex !== undefined ? column.setFilterValue(function (old) {
      var newFilterValues = old != null ? old : ['', ''];
      newFilterValues[inputIndex] = event.target.value;
      return newFilterValues;
    }) : column.setFilterValue((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
  }, 150), []);

  var handleFilterMenuOpen = function handleFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setFilterValue('');

    if (inputIndex !== undefined) {
      column.setFilterValue(function (old) {
        var newFilterValues = old != null ? old : ['', ''];
        newFilterValues[inputIndex] = undefined;
        return newFilterValues;
      });
    } else {
      column.setFilterValue(undefined);
    }
  };

  var handleClearFilterChip = function handleClearFilterChip() {
    setFilterValue('');
    column.setFilterValue(undefined);
    setCurrentFilterFns(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = MRT_FILTER_OPTION.FUZZY, _extends2));
    });
  };

  if (columnDef.Filter) {
    return React__default.createElement(React__default.Fragment, null, columnDef.Filter == null ? void 0 : columnDef.Filter({
      header: header,
      tableInstance: tableInstance
    }));
  }

  var filterId = "mrt-" + tableId + "-" + header.id + "-filter-text-field" + (inputIndex != null ? inputIndex : '');
  var filterFn = currentFilterFns == null ? void 0 : currentFilterFns[header.id];
  var isSelectFilter = !!columnDef.filterSelectOptions;
  var filterChipLabel = !(filterFn instanceof Function) && [MRT_FILTER_OPTION.EMPTY, MRT_FILTER_OPTION.NOT_EMPTY].includes(filterFn) ? //@ts-ignore
  localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))] : '';
  var filterPlaceholder = inputIndex === undefined ? (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header)) : inputIndex === 0 ? localization.min : inputIndex === 1 ? localization.max : '';
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.TextField, Object.assign({
    fullWidth: true,
    id: filterId,
    inputProps: {
      disabled: !!filterChipLabel,
      sx: {
        textOverflow: 'ellipsis',
        width: filterChipLabel ? 0 : undefined
      },
      title: filterPlaceholder
    },
    helperText: !inputIndex ? React__default.createElement("label", {
      htmlFor: filterId
    }, filterFn instanceof Function ? (_localization$filterM = localization.filterMode.replace('{filterType}', // @ts-ignore
    (_localization$ = localization["filter" + (filterFn.name.charAt(0).toUpperCase() + filterFn.name.slice(1))]) != null ? _localization$ : '')) != null ? _localization$filterM : '' : localization.filterMode.replace('{filterType}', // @ts-ignore
    localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))])) : null,
    FormHelperTextProps: {
      sx: {
        fontSize: '0.6rem',
        lineHeight: '0.8rem',
        whiteSpace: 'nowrap'
      }
    },
    label: isSelectFilter && !filterValue ? filterPlaceholder : undefined,
    margin: "none",
    placeholder: filterChipLabel || isSelectFilter ? undefined : filterPlaceholder,
    onChange: function onChange(event) {
      setFilterValue(event.target.value);
      handleChangeDebounced(event);
    },
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    select: isSelectFilter,
    value: filterValue != null ? filterValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: !isSelectFilter && !inputIndex && React__default.createElement(material.InputAdornment, {
        position: "start"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        title: localization.changeFilterMode
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.changeFilterMode,
        onClick: handleFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(FilterListIcon, null)))), filterChipLabel && React__default.createElement(material.Chip, {
        onDelete: handleClearFilterChip,
        label: filterChipLabel
      })),
      endAdornment: !filterChipLabel && React__default.createElement(material.InputAdornment, {
        position: "end"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        disableHoverListener: isSelectFilter,
        placement: "right",
        title: (_localization$clearFi = localization.clearFilter) != null ? _localization$clearFi : ''
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.clearFilter,
        disabled: !(filterValue != null && filterValue.length),
        onClick: handleClear,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(CloseIcon, null)))))
    }
  }, textFieldProps, {
    sx: _extends({
      m: '-0.25rem',
      p: 0,
      minWidth: !filterChipLabel ? '8rem' : 'auto',
      width: 'calc(100% + 0.5rem)',
      mt: isSelectFilter && !filterValue ? '-1rem' : undefined,
      '&	.MuiSelect-icon': {
        mr: '1.5rem'
      }
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  }), isSelectFilter && React__default.createElement(material.MenuItem, {
    divider: true,
    disabled: !filterValue,
    value: ""
  }, localization.clearFilter), columnDef == null ? void 0 : (_columnDef$filterSele = columnDef.filterSelectOptions) == null ? void 0 : _columnDef$filterSele.map(function (option) {
    var value;
    var text;

    if (typeof option === 'string') {
      value = option;
      text = option;
    } else if (typeof option === 'object') {
      value = option.value;
      text = option.text;
    }

    return React__default.createElement(material.MenuItem, {
      key: value,
      value: value
    }, text);
  })), React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_FilterRangeFields = function MRT_FilterRangeFields(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var localization = tableInstance.options.localization;
  return React__default.createElement(material.Box, {
    sx: {
      display: 'grid',
      gridTemplateColumns: '6fr auto 5fr'
    }
  }, React__default.createElement(MRT_FilterTextField, {
    header: header,
    inputIndex: 0,
    tableInstance: tableInstance
  }), React__default.createElement(material.Box, {
    sx: {
      width: '100%',
      minWidth: '5ch',
      textAlign: 'center'
    }
  }, localization.to), React__default.createElement(MRT_FilterTextField, {
    header: header,
    inputIndex: 1,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCellFilterContainer = function MRT_TableHeadCellFilterContainer(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns,
      showFilters = _getState.showFilters;

  var column = header.column;
  return React__default.createElement(material.Collapse, {
    "in": showFilters,
    mountOnEnter: true,
    unmountOnExit: true
  }, currentFilterFns[column.id] === MRT_FILTER_OPTION.BETWEEN ? React__default.createElement(MRT_FilterRangeFields, {
    header: header,
    tableInstance: tableInstance
  }) : React__default.createElement(MRT_FilterTextField, {
    header: header,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCellFilterLabel = function MRT_TableHeadCellFilterLabel(_ref) {
  var _getState2, _getState2$currentFil;

  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterAltIcon = _tableInstance$option2.FilterAltIcon,
      FilterAltOffIcon = _tableInstance$option2.FilterAltOffIcon,
      localization = _tableInstance$option.localization,
      setShowFilters = tableInstance.setShowFilters;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var column = header.column;
  var columnDef = column.columnDef;
  var filterFn = (_getState2 = getState()) == null ? void 0 : (_getState2$currentFil = _getState2.currentFilterFns) == null ? void 0 : _getState2$currentFil[header.id];
  var filterTooltip = !!column.getFilterValue() ? localization.filteringByColumn.replace('{column}', String(columnDef.header)).replace('{filterType}', filterFn instanceof Function ? '' : // @ts-ignore
  localization["filter" + (filterFn.charAt(0).toUpperCase() + filterFn.slice(1))]).replace('{filterValue}', "\"" + (Array.isArray(column.getFilterValue()) ? column.getFilterValue().join("\" " + localization.and + " \"") : column.getFilterValue()) + "\"").replace('" "', '') : localization.showHideFilters;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    placement: "top",
    title: filterTooltip
  }, React__default.createElement(material.IconButton, {
    disableRipple: true,
    onClick: function onClick(event) {
      event.stopPropagation();
      setShowFilters(!showFilters);
    },
    size: "small",
    sx: {
      m: 0,
      opacity: !!column.getFilterValue() || showFilters ? 0.8 : 0,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      transform: 'scale(0.66)',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 0.8
      }
    }
  }, showFilters && !column.getFilterValue() ? React__default.createElement(FilterAltOffIcon, null) : React__default.createElement(FilterAltIcon, null)));
};

var MRT_TableHeadCellResizeHandle = function MRT_TableHeadCellResizeHandle(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  var column = header.column;
  var columnDefType = column.columnDefType;
  return React__default.createElement(material.Divider, {
    flexItem: true,
    orientation: "vertical",
    onDoubleClick: function onDoubleClick() {
      return column.resetSize();
    },
    sx: function sx(theme) {
      return {
        borderRadius: '2px',
        borderRightWidth: '2px',
        cursor: 'col-resize',
        height: showFilters && columnDefType === 'data' ? '4rem' : '2rem',
        opacity: 0.8,
        position: 'absolute',
        right: '1px',
        touchAction: 'none',
        transition: column.getIsResizing() ? undefined : 'all 0.2s ease-in-out',
        userSelect: 'none',
        zIndex: 2000,
        '&:active': {
          backgroundColor: theme.palette.info.main,
          opacity: 1
        }
      };
    },
    onMouseDown: header.getResizeHandler(),
    onTouchStart: header.getResizeHandler(),
    style: {
      transform: column.getIsResizing() ? "translateX(" + getState().columnSizingInfo.deltaOffset + "px)" : 'none'
    }
  });
};

var MRT_TableHeadCellSortLabel = function MRT_TableHeadCellSortLabel(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var localization = tableInstance.options.localization;
  var column = header.column;
  var columnDef = column.columnDef;
  var sortTooltip = !!column.getIsSorted() ? column.getIsSorted() === 'desc' ? localization.sortedByColumnDesc.replace('{column}', columnDef.header) : localization.sortedByColumnAsc.replace('{column}', columnDef.header) : localization.unsorted;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    placement: "top",
    title: sortTooltip
  }, React__default.createElement(material.TableSortLabel, {
    "aria-label": sortTooltip,
    active: !!column.getIsSorted(),
    direction: column.getIsSorted() ? column.getIsSorted() : undefined
  }));
};

var MRT_ToggleColumnActionMenuButton = function MRT_ToggleColumnActionMenuButton(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      MoreVertIcon = _tableInstance$option.icons.MoreVertIcon,
      localization = _tableInstance$option.localization,
      muiTableHeadCellColumnActionsButtonProps = _tableInstance$option.muiTableHeadCellColumnActionsButtonProps;
  var column = header.column;
  var columnDef = column.columnDef;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var mTableHeadCellColumnActionsButtonProps = muiTableHeadCellColumnActionsButtonProps instanceof Function ? muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellColumnActionsButtonProps;
  var mcTableHeadCellColumnActionsButtonProps = columnDef.muiTableHeadCellColumnActionsButtonProps instanceof Function ? columnDef.muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellColumnActionsButtonProps;

  var iconButtonProps = _extends({}, mTableHeadCellColumnActionsButtonProps, mcTableHeadCellColumnActionsButtonProps);

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.columnActions
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.columnActions,
    onClick: handleClick,
    size: "small"
  }, iconButtonProps, {
    sx: _extends({
      height: '2rem',
      mr: '2px',
      mt: '-0.2rem',
      opacity: 0.5,
      transition: 'opacity 0.2s',
      width: '2rem',
      '&:hover': {
        opacity: 1
      }
    }, iconButtonProps.sx)
  }), React__default.createElement(MoreVertIcon, null))), React__default.createElement(MRT_ColumnActionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _ref2, _ref3, _columnDef$header$len, _columnDef$header;

  var dragRef = _ref.dragRef,
      dropRef = _ref.dropRef,
      header = _ref.header,
      isDragging = _ref.isDragging,
      previewRef = _ref.previewRef,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnActions = _tableInstance$option.enableColumnActions,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableGrouping = _tableInstance$option.enableGrouping,
      muiTableHeadCellProps = _tableInstance$option.muiTableHeadCellProps;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var column = header.column;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;
  var mTableHeadCellProps = muiTableHeadCellProps instanceof Function ? muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellProps;
  var mcTableHeadCellProps = columnDef.muiTableHeadCellProps instanceof Function ? columnDef.muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableHeadCellProps;

  var tableCellProps = _extends({}, mTableHeadCellProps, mcTableHeadCellProps);

  var headerElement = (_ref2 = (_ref3 = (columnDef == null ? void 0 : columnDef.Header) instanceof Function ? columnDef == null ? void 0 : columnDef.Header == null ? void 0 : columnDef.Header({
    header: header,
    tableInstance: tableInstance
  }) : columnDef == null ? void 0 : columnDef.Header) != null ? _ref3 : header.renderHeader()) != null ? _ref2 : columnDef.header;

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && tableInstance.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (tableInstance.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  return React__default.createElement(material.TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: header.colSpan
  }, tableCellProps, {
    ref: columnDefType === 'data' && enableColumnOrdering ? dropRef : undefined,
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() && columnDefType !== 'group' ? material.alpha(material.lighten(theme.palette.background["default"], 0.04), 0.95) : 'inherit',
        backgroundImage: 'inherit',
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : undefined,
        fontWeight: 'bold',
        height: '100%',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        overflow: 'visible',
        p: isDensePadding ? columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
        pb: columnDefType === 'display' ? 0 : undefined,
        position: column.getIsPinned() && columnDefType !== 'group' ? 'sticky' : undefined,
        pt: columnDefType !== 'data' ? 0 : isDensePadding ? '0.25' : '.75rem',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        transition: "all " + (enableColumnResizing ? 0 : '0.2s') + " ease-in-out",
        verticalAlign: 'text-top',
        zIndex: column.getIsResizing() ? 3 : column.getIsPinned() && columnDefType !== 'group' ? 2 : 1
      }, tableCellProps == null ? void 0 : tableCellProps.sx, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: header.getSize()
      });
    }
  }), header.isPlaceholder ? null : columnDefType === 'display' ? headerElement : React__default.createElement(material.Box, {
    ref: previewRef,
    sx: {
      alignItems: 'flex-start',
      display: 'flex',
      justifyContent: columnDefType === 'group' ? 'center' : 'space-between',
      opacity: isDragging ? 0.5 : 1,
      width: '100%'
    }
  }, React__default.createElement(material.Box, {
    onClick: function onClick() {
      return column.toggleSorting();
    },
    sx: {
      alignItems: 'center',
      cursor: column.getCanSort() && columnDefType !== 'group' ? 'pointer' : undefined,
      display: 'flex',
      flexWrap: 'nowrap',
      whiteSpace: ((_columnDef$header$len = (_columnDef$header = columnDef.header) == null ? void 0 : _columnDef$header.length) != null ? _columnDef$header$len : 0) < 24 ? 'nowrap' : 'normal'
    }
  }, headerElement, columnDefType === 'data' && column.getCanSort() && React__default.createElement(MRT_TableHeadCellSortLabel, {
    header: header,
    tableInstance: tableInstance
  }), columnDefType === 'data' && enableColumnFilters && column.getCanFilter() && React__default.createElement(MRT_TableHeadCellFilterLabel, {
    header: header,
    tableInstance: tableInstance
  })), React__default.createElement(material.Box, {
    sx: {
      whiteSpace: 'nowrap'
    }
  }, columnDefType === 'data' && (enableColumnOrdering && columnDef.enableColumnOrdering !== false || enableGrouping && columnDef.enableGrouping !== false) && React__default.createElement(MRT_GrabHandleButton, {
    ref: dragRef,
    tableInstance: tableInstance
  }), (enableColumnActions || columnDef.enableColumnActions) && columnDef.enableColumnActions !== false && columnDefType !== 'group' && React__default.createElement(MRT_ToggleColumnActionMenuButton, {
    header: header,
    tableInstance: tableInstance
  })), column.getCanResize() && React__default.createElement(MRT_TableHeadCellResizeHandle, {
    header: header,
    tableInstance: tableInstance
  })), columnDefType === 'data' && column.getCanFilter() && React__default.createElement(MRT_TableHeadCellFilterContainer, {
    header: header,
    tableInstance: tableInstance
  }));
};

var MRT_DraggableTableHeadCell = function MRT_DraggableTableHeadCell(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState;

  _objectDestructuringEmpty(tableInstance.options);

  var setColumnOrder = tableInstance.setColumnOrder;

  var _getState = getState(),
      columnOrder = _getState.columnOrder;

  var column = header.column;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var _useDrag = useDrag({
    collect: function collect(monitor) {
      return {
        isDragging: monitor.isDragging()
      };
    },
    item: function item() {
      return column;
    },
    type: 'column'
  }),
      isDragging = _useDrag[0].isDragging,
      dragRef = _useDrag[1],
      previewRef = _useDrag[2];

  return React__default.createElement(MRT_TableHeadCell, {
    dragRef: dragRef,
    dropRef: dropRef,
    header: header,
    isDragging: isDragging,
    previewRef: previewRef,
    tableInstance: tableInstance
  });
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableGrouping = _tableInstance$option.enableGrouping,
      muiTableHeadRowProps = _tableInstance$option.muiTableHeadRowProps;
  var tableRowProps = muiTableHeadRowProps instanceof Function ? muiTableHeadRowProps({
    headerGroup: headerGroup,
    tableInstance: tableInstance
  }) : muiTableHeadRowProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        boxShadow: "4px 0 8px " + material.alpha(theme.palette.common.black, 0.1),
        backgroundColor: material.lighten(theme.palette.background["default"], 0.04)
      }, tableRowProps == null ? void 0 : tableRowProps.sx);
    }
  }), headerGroup.headers.map(function (header, index) {
    return enableColumnOrdering || enableGrouping ? React__default.createElement(MRT_DraggableTableHeadCell, {
      header: header,
      key: header.id || index,
      tableInstance: tableInstance
    }) : React__default.createElement(MRT_TableHeadCell, {
      header: header,
      key: header.id || index,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableHead = function MRT_TableHead(_ref) {
  var tableInstance = _ref.tableInstance;
  var getHeaderGroups = tableInstance.getHeaderGroups,
      muiTableHeadProps = tableInstance.options.muiTableHeadProps;
  var tableHeadProps = muiTableHeadProps instanceof Function ? muiTableHeadProps({
    tableInstance: tableInstance
  }) : muiTableHeadProps;
  return React__default.createElement(material.TableHead, Object.assign({}, tableHeadProps), getHeaderGroups().map(function (headerGroup) {
    return React__default.createElement(MRT_TableHeadRow, {
      headerGroup: headerGroup,
      key: headerGroup.id,
      tableInstance: tableInstance
    });
  }));
};

function _extends$1() {
  _extends$1 = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends$1.apply(this, arguments);
}

function _objectWithoutPropertiesLoose$2(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var props = ['bottom', 'height', 'left', 'right', 'top', 'width'];

var rectChanged = function rectChanged(a, b) {
  if (a === void 0) {
    a = {};
  }

  if (b === void 0) {
    b = {};
  }

  return props.some(function (prop) {
    return a[prop] !== b[prop];
  });
};

var observedNodes = /*#__PURE__*/new Map();
var rafId;

var run = function run() {
  var changedStates = [];
  observedNodes.forEach(function (state, node) {
    var newRect = node.getBoundingClientRect();

    if (rectChanged(newRect, state.rect)) {
      state.rect = newRect;
      changedStates.push(state);
    }
  });
  changedStates.forEach(function (state) {
    state.callbacks.forEach(function (cb) {
      return cb(state.rect);
    });
  });
  rafId = window.requestAnimationFrame(run);
};

function observeRect(node, cb) {
  return {
    observe: function observe() {
      var wasEmpty = observedNodes.size === 0;

      if (observedNodes.has(node)) {
        observedNodes.get(node).callbacks.push(cb);
      } else {
        observedNodes.set(node, {
          rect: undefined,
          hasRectChanged: false,
          callbacks: [cb]
        });
      }

      if (wasEmpty) run();
    },
    unobserve: function unobserve() {
      var state = observedNodes.get(node);

      if (state) {
        // Remove the callback
        var index = state.callbacks.indexOf(cb);
        if (index >= 0) state.callbacks.splice(index, 1); // Remove the node reference

        if (!state.callbacks.length) observedNodes["delete"](node); // Stop the loop

        if (!observedNodes.size) cancelAnimationFrame(rafId);
      }
    }
  };
}

var useIsomorphicLayoutEffect$1 = typeof window !== 'undefined' ? React__default.useLayoutEffect : React__default.useEffect;

function useRect(nodeRef, initialRect) {
  if (initialRect === void 0) {
    initialRect = {
      width: 0,
      height: 0
    };
  }

  var _React$useState = React__default.useState(nodeRef.current),
      element = _React$useState[0],
      setElement = _React$useState[1];

  var _React$useReducer = React__default.useReducer(rectReducer, initialRect),
      rect = _React$useReducer[0],
      dispatch = _React$useReducer[1];

  var initialRectSet = React__default.useRef(false);
  useIsomorphicLayoutEffect$1(function () {
    if (nodeRef.current !== element) {
      setElement(nodeRef.current);
    }
  });
  useIsomorphicLayoutEffect$1(function () {
    if (element && !initialRectSet.current) {
      initialRectSet.current = true;

      var _rect = element.getBoundingClientRect();

      dispatch({
        rect: _rect
      });
    }
  }, [element]);
  React__default.useEffect(function () {
    if (!element) {
      return;
    }

    var observer = observeRect(element, function (rect) {
      dispatch({
        rect: rect
      });
    });
    observer.observe();
    return function () {
      observer.unobserve();
    };
  }, [element]);
  return rect;
}

function rectReducer(state, action) {
  var rect = action.rect;

  if (state.height !== rect.height || state.width !== rect.width) {
    return rect;
  }

  return state;
}

var defaultEstimateSize = function defaultEstimateSize() {
  return 50;
};

var defaultKeyExtractor = function defaultKeyExtractor(index) {
  return index;
};

var defaultMeasureSize = function defaultMeasureSize(el, horizontal) {
  var key = horizontal ? 'offsetWidth' : 'offsetHeight';
  return el[key];
};

var defaultRangeExtractor = function defaultRangeExtractor(range) {
  var start = Math.max(range.start - range.overscan, 0);
  var end = Math.min(range.end + range.overscan, range.size - 1);
  var arr = [];

  for (var i = start; i <= end; i++) {
    arr.push(i);
  }

  return arr;
};
function useVirtual(_ref) {
  var _measurements;

  var _ref$size = _ref.size,
      size = _ref$size === void 0 ? 0 : _ref$size,
      _ref$estimateSize = _ref.estimateSize,
      estimateSize = _ref$estimateSize === void 0 ? defaultEstimateSize : _ref$estimateSize,
      _ref$overscan = _ref.overscan,
      overscan = _ref$overscan === void 0 ? 1 : _ref$overscan,
      _ref$paddingStart = _ref.paddingStart,
      paddingStart = _ref$paddingStart === void 0 ? 0 : _ref$paddingStart,
      _ref$paddingEnd = _ref.paddingEnd,
      paddingEnd = _ref$paddingEnd === void 0 ? 0 : _ref$paddingEnd,
      parentRef = _ref.parentRef,
      horizontal = _ref.horizontal,
      scrollToFn = _ref.scrollToFn,
      useObserver = _ref.useObserver,
      initialRect = _ref.initialRect,
      onScrollElement = _ref.onScrollElement,
      scrollOffsetFn = _ref.scrollOffsetFn,
      _ref$keyExtractor = _ref.keyExtractor,
      keyExtractor = _ref$keyExtractor === void 0 ? defaultKeyExtractor : _ref$keyExtractor,
      _ref$measureSize = _ref.measureSize,
      measureSize = _ref$measureSize === void 0 ? defaultMeasureSize : _ref$measureSize,
      _ref$rangeExtractor = _ref.rangeExtractor,
      rangeExtractor = _ref$rangeExtractor === void 0 ? defaultRangeExtractor : _ref$rangeExtractor;
  var sizeKey = horizontal ? 'width' : 'height';
  var scrollKey = horizontal ? 'scrollLeft' : 'scrollTop';
  var latestRef = React__default.useRef({
    scrollOffset: 0,
    measurements: []
  });

  var _React$useState = React__default.useState(0),
      scrollOffset = _React$useState[0],
      setScrollOffset = _React$useState[1];

  latestRef.current.scrollOffset = scrollOffset;
  var useMeasureParent = useObserver || useRect;

  var _useMeasureParent = useMeasureParent(parentRef, initialRect),
      outerSize = _useMeasureParent[sizeKey];

  latestRef.current.outerSize = outerSize;
  var defaultScrollToFn = React__default.useCallback(function (offset) {
    if (parentRef.current) {
      parentRef.current[scrollKey] = offset;
    }
  }, [parentRef, scrollKey]);
  var resolvedScrollToFn = scrollToFn || defaultScrollToFn;
  scrollToFn = React__default.useCallback(function (offset) {
    resolvedScrollToFn(offset, defaultScrollToFn);
  }, [defaultScrollToFn, resolvedScrollToFn]);

  var _React$useState2 = React__default.useState({}),
      measuredCache = _React$useState2[0],
      setMeasuredCache = _React$useState2[1];

  var measure = React__default.useCallback(function () {
    return setMeasuredCache({});
  }, []);
  var pendingMeasuredCacheIndexesRef = React__default.useRef([]);
  var measurements = React__default.useMemo(function () {
    var min = pendingMeasuredCacheIndexesRef.current.length > 0 ? Math.min.apply(Math, pendingMeasuredCacheIndexesRef.current) : 0;
    pendingMeasuredCacheIndexesRef.current = [];
    var measurements = latestRef.current.measurements.slice(0, min);

    for (var i = min; i < size; i++) {
      var key = keyExtractor(i);
      var measuredSize = measuredCache[key];

      var _start = measurements[i - 1] ? measurements[i - 1].end : paddingStart;

      var _size = typeof measuredSize === 'number' ? measuredSize : estimateSize(i);

      var _end = _start + _size;

      measurements[i] = {
        index: i,
        start: _start,
        size: _size,
        end: _end,
        key: key
      };
    }

    return measurements;
  }, [estimateSize, measuredCache, paddingStart, size, keyExtractor]);
  var totalSize = (((_measurements = measurements[size - 1]) == null ? void 0 : _measurements.end) || paddingStart) + paddingEnd;
  latestRef.current.measurements = measurements;
  latestRef.current.totalSize = totalSize;
  var element = onScrollElement ? onScrollElement.current : parentRef.current;
  var scrollOffsetFnRef = React__default.useRef(scrollOffsetFn);
  scrollOffsetFnRef.current = scrollOffsetFn;
  useIsomorphicLayoutEffect$1(function () {
    if (!element) {
      setScrollOffset(0);
      return;
    }

    var onScroll = function onScroll(event) {
      var offset = scrollOffsetFnRef.current ? scrollOffsetFnRef.current(event) : element[scrollKey];
      setScrollOffset(offset);
    };

    onScroll();
    element.addEventListener('scroll', onScroll, {
      capture: false,
      passive: true
    });
    return function () {
      element.removeEventListener('scroll', onScroll);
    };
  }, [element, scrollKey]);

  var _calculateRange = calculateRange(latestRef.current),
      start = _calculateRange.start,
      end = _calculateRange.end;

  var indexes = React__default.useMemo(function () {
    return rangeExtractor({
      start: start,
      end: end,
      overscan: overscan,
      size: measurements.length
    });
  }, [start, end, overscan, measurements.length, rangeExtractor]);
  var measureSizeRef = React__default.useRef(measureSize);
  measureSizeRef.current = measureSize;
  var virtualItems = React__default.useMemo(function () {
    var virtualItems = [];

    var _loop = function _loop(k, len) {
      var i = indexes[k];
      var measurement = measurements[i];

      var item = _extends$1(_extends$1({}, measurement), {}, {
        measureRef: function measureRef(el) {
          if (el) {
            var measuredSize = measureSizeRef.current(el, horizontal);

            if (measuredSize !== item.size) {
              var _scrollOffset = latestRef.current.scrollOffset;

              if (item.start < _scrollOffset) {
                defaultScrollToFn(_scrollOffset + (measuredSize - item.size));
              }

              pendingMeasuredCacheIndexesRef.current.push(i);
              setMeasuredCache(function (old) {
                var _extends2;

                return _extends$1(_extends$1({}, old), {}, (_extends2 = {}, _extends2[item.key] = measuredSize, _extends2));
              });
            }
          }
        }
      });

      virtualItems.push(item);
    };

    for (var k = 0, len = indexes.length; k < len; k++) {
      _loop(k);
    }

    return virtualItems;
  }, [indexes, defaultScrollToFn, horizontal, measurements]);
  var mountedRef = React__default.useRef(false);
  useIsomorphicLayoutEffect$1(function () {
    if (mountedRef.current) {
      setMeasuredCache({});
    }

    mountedRef.current = true;
  }, [estimateSize]);
  var scrollToOffset = React__default.useCallback(function (toOffset, _temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        _ref2$align = _ref2.align,
        align = _ref2$align === void 0 ? 'start' : _ref2$align;

    var _latestRef$current = latestRef.current,
        scrollOffset = _latestRef$current.scrollOffset,
        outerSize = _latestRef$current.outerSize;

    if (align === 'auto') {
      if (toOffset <= scrollOffset) {
        align = 'start';
      } else if (toOffset >= scrollOffset + outerSize) {
        align = 'end';
      } else {
        align = 'start';
      }
    }

    if (align === 'start') {
      scrollToFn(toOffset);
    } else if (align === 'end') {
      scrollToFn(toOffset - outerSize);
    } else if (align === 'center') {
      scrollToFn(toOffset - outerSize / 2);
    }
  }, [scrollToFn]);
  var tryScrollToIndex = React__default.useCallback(function (index, _temp2) {
    var _ref3 = _temp2 === void 0 ? {} : _temp2,
        _ref3$align = _ref3.align,
        align = _ref3$align === void 0 ? 'auto' : _ref3$align,
        rest = _objectWithoutPropertiesLoose$2(_ref3, ["align"]);

    var _latestRef$current2 = latestRef.current,
        measurements = _latestRef$current2.measurements,
        scrollOffset = _latestRef$current2.scrollOffset,
        outerSize = _latestRef$current2.outerSize;
    var measurement = measurements[Math.max(0, Math.min(index, size - 1))];

    if (!measurement) {
      return;
    }

    if (align === 'auto') {
      if (measurement.end >= scrollOffset + outerSize) {
        align = 'end';
      } else if (measurement.start <= scrollOffset) {
        align = 'start';
      } else {
        return;
      }
    }

    var toOffset = align === 'center' ? measurement.start + measurement.size / 2 : align === 'end' ? measurement.end : measurement.start;
    scrollToOffset(toOffset, _extends$1({
      align: align
    }, rest));
  }, [scrollToOffset, size]);
  var scrollToIndex = React__default.useCallback(function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    // We do a double request here because of
    // dynamic sizes which can cause offset shift
    // and end up in the wrong spot. Unfortunately,
    // we can't know about those dynamic sizes until
    // we try and render them. So double down!
    tryScrollToIndex.apply(void 0, args);
    requestAnimationFrame(function () {
      tryScrollToIndex.apply(void 0, args);
    });
  }, [tryScrollToIndex]);
  return {
    virtualItems: virtualItems,
    totalSize: totalSize,
    scrollToOffset: scrollToOffset,
    scrollToIndex: scrollToIndex,
    measure: measure
  };
}

var findNearestBinarySearch = function findNearestBinarySearch(low, high, getCurrentValue, value) {
  while (low <= high) {
    var middle = (low + high) / 2 | 0;
    var currentValue = getCurrentValue(middle);

    if (currentValue < value) {
      low = middle + 1;
    } else if (currentValue > value) {
      high = middle - 1;
    } else {
      return middle;
    }
  }

  if (low > 0) {
    return low - 1;
  } else {
    return 0;
  }
};

function calculateRange(_ref4) {
  var measurements = _ref4.measurements,
      outerSize = _ref4.outerSize,
      scrollOffset = _ref4.scrollOffset;
  var size = measurements.length - 1;

  var getOffset = function getOffset(index) {
    return measurements[index].start;
  };

  var start = findNearestBinarySearch(0, size, getOffset, scrollOffset);
  var end = start;

  while (end < size && measurements[end].end < scrollOffset + outerSize) {
    end++;
  }

  return {
    start: start,
    end: end
  };
}

var MRT_EditCellTextField = function MRT_EditCellTextField(_ref) {
  var cell = _ref.cell,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      tableId = _tableInstance$option.tableId,
      enableEditing = _tableInstance$option.enableEditing,
      muiTableBodyCellEditTextFieldProps = _tableInstance$option.muiTableBodyCellEditTextFieldProps,
      onMrtCellEditBlur = _tableInstance$option.onMrtCellEditBlur,
      onMrtCellEditChange = _tableInstance$option.onMrtCellEditChange,
      setCurrentEditingCell = tableInstance.setCurrentEditingCell,
      setCurrentEditingRow = tableInstance.setCurrentEditingRow;

  var _useState = React.useState(cell.getValue()),
      value = _useState[0],
      setValue = _useState[1];

  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef;

  var handleChange = function handleChange(event) {
    setValue(event.target.value);
    columnDef.onMrtCellEditChange == null ? void 0 : columnDef.onMrtCellEditChange({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
    onMrtCellEditChange == null ? void 0 : onMrtCellEditChange({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
  };

  var handleBlur = function handleBlur(event) {
    if (getState().currentEditingRow) {
      if (!row._valuesCache) row._valuesCache = {};
      row._valuesCache[column.id] = value;
      setCurrentEditingRow(_extends({}, getState().currentEditingRow));
    }

    setCurrentEditingCell(null);
    columnDef.onMrtCellEditBlur == null ? void 0 : columnDef.onMrtCellEditBlur({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
    onMrtCellEditBlur == null ? void 0 : onMrtCellEditBlur({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
  };

  var mTableBodyCellEditTextFieldProps = muiTableBodyCellEditTextFieldProps instanceof Function ? muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellEditTextFieldProps;
  var mcTableBodyCellEditTextFieldProps = columnDef.muiTableBodyCellEditTextFieldProps instanceof Function ? columnDef.muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellEditTextFieldProps;

  var textFieldProps = _extends({}, mTableBodyCellEditTextFieldProps, mcTableBodyCellEditTextFieldProps);

  if (enableEditing && columnDef.enableEditing !== false && columnDef.Edit) {
    return React__default.createElement(React__default.Fragment, null, columnDef.Edit == null ? void 0 : columnDef.Edit({
      cell: cell,
      tableInstance: tableInstance
    }));
  }

  return React__default.createElement(material.TextField, Object.assign({
    id: "mrt-" + tableId + "-edit-cell-text-field-" + cell.id,
    margin: "dense",
    onBlur: handleBlur,
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    placeholder: columnDef.header,
    value: value,
    variant: "standard"
  }, textFieldProps));
};

var MRT_CopyButton = function MRT_CopyButton(_ref) {
  var cell = _ref.cell,
      children = _ref.children,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableBodyCellCopyButtonProps = _tableInstance$option.muiTableBodyCellCopyButtonProps;
  var column = cell.column;
  var columnDef = column.columnDef;

  var _useState = React.useState(false),
      copied = _useState[0],
      setCopied = _useState[1];

  var handleCopy = function handleCopy(text) {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(function () {
      return setCopied(false);
    }, 4000);
  };

  var mTableBodyCellCopyButtonProps = muiTableBodyCellCopyButtonProps instanceof Function ? muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellCopyButtonProps;
  var mcTableBodyCellCopyButtonProps = columnDef.muiTableBodyCellCopyButtonProps instanceof Function ? columnDef.muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellCopyButtonProps;

  var buttonProps = _extends({}, mTableBodyCellCopyButtonProps, mcTableBodyCellCopyButtonProps);

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: copied ? localization.copiedToClipboard : localization.clickToCopy
  }, React__default.createElement(material.Button, Object.assign({
    "aria-label": localization.clickToCopy,
    onClick: function onClick() {
      return handleCopy(cell.getValue());
    },
    size: "small",
    type: "button",
    variant: "text"
  }, buttonProps, {
    sx: _extends({
      backgroundColor: 'transparent',
      border: 'none',
      color: 'inherit',
      cursor: 'copy',
      fontFamily: 'inherit',
      fontSize: 'inherit',
      letterSpacing: 'inherit',
      m: '-0.25rem',
      minWidth: 'unset',
      textAlign: 'inherit',
      textTransform: 'inherit'
    }, buttonProps == null ? void 0 : buttonProps.sx)
  }), children));
};

var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var _columnDef$Cell, _row$subRows, _columnDef$Cell2, _row$subRows$length, _row$subRows2;

  var cell = _ref.cell,
      enableHover = _ref.enableHover,
      rowIndex = _ref.rowIndex,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      editingMode = _tableInstance$option.editingMode,
      enableClickToCopy = _tableInstance$option.enableClickToCopy,
      enableColumnOrdering = _tableInstance$option.enableColumnOrdering,
      enableEditing = _tableInstance$option.enableEditing,
      enableRowNumbers = _tableInstance$option.enableRowNumbers,
      muiTableBodyCellProps = _tableInstance$option.muiTableBodyCellProps,
      muiTableBodyCellSkeletonProps = _tableInstance$option.muiTableBodyCellSkeletonProps,
      onMrtCellClick = _tableInstance$option.onMrtCellClick,
      rowNumberMode = _tableInstance$option.rowNumberMode,
      tableId = _tableInstance$option.tableId,
      setColumnOrder = tableInstance.setColumnOrder,
      setCurrentEditingCell = tableInstance.setCurrentEditingCell;

  var _getState = getState(),
      columnOrder = _getState.columnOrder,
      currentEditingCell = _getState.currentEditingCell,
      currentEditingRow = _getState.currentEditingRow,
      isDensePadding = _getState.isDensePadding,
      isLoading = _getState.isLoading,
      showSkeletons = _getState.showSkeletons;

  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;

  var _useDrop = useDrop({
    accept: 'column',
    drop: function drop(movingColumn) {
      return reorderColumn(movingColumn, column, columnOrder, setColumnOrder);
    }
  }),
      dropRef = _useDrop[1];

  var mTableCellBodyProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellProps;
  var mcTableCellBodyProps = columnDef.muiTableBodyCellProps instanceof Function ? columnDef.muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : columnDef.muiTableBodyCellProps;

  var tableCellProps = _extends({}, mTableCellBodyProps, mcTableCellBodyProps);

  var skeletonWidth = React.useMemo(function () {
    return columnDefType === 'display' ? column.getSize() / 2 : Math.random() * (column.getSize() - column.getSize() / 3) + column.getSize() / 3;
  }, [columnDefType, column.getSize()]);
  var isEditable = (enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false;
  var isEditing = isEditable && (editingMode === 'table' || (currentEditingRow == null ? void 0 : currentEditingRow.id) === row.id || (currentEditingCell == null ? void 0 : currentEditingCell.id) === cell.id);

  var handleDoubleClick = function handleDoubleClick(_event) {
    if ((enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false && editingMode === 'cell') {
      setCurrentEditingCell(cell);
      setTimeout(function () {
        var textField = document.getElementById("mrt-" + tableId + "-edit-cell-text-field-" + cell.id);

        if (textField) {
          textField.focus();
          textField.select();
        }
      }, 200);
    }
  };

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && tableInstance.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (tableInstance.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  return React__default.createElement(material.TableCell, Object.assign({
    onClick: function onClick(event) {
      return onMrtCellClick == null ? void 0 : onMrtCellClick({
        event: event,
        cell: cell,
        tableInstance: tableInstance
      });
    },
    onDoubleClick: handleDoubleClick
  }, tableCellProps, {
    ref: columnDefType === 'data' && enableColumnOrdering ? dropRef : undefined,
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() ? material.alpha(material.lighten(theme.palette.background["default"], 0.04), 0.95) : undefined,
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : undefined,
        cursor: isEditable && editingMode === 'cell' ? 'pointer' : 'text',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        overflow: 'hidden',
        p: isDensePadding ? columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
        pl: column.id === 'mrt-expand' ? row.depth + (isDensePadding ? 0.5 : 0.75) + "rem" : undefined,
        position: column.getIsPinned() ? 'sticky' : 'relative',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        textOverflow: columnDefType !== 'display' ? 'ellipsis' : undefined,
        transition: 'all 0.2s ease-in-out',
        whiteSpace: isDensePadding ? 'nowrap' : 'normal',
        zIndex: column.getIsPinned() ? 1 : undefined,
        '&:hover': {
          backgroundColor: enableHover && enableEditing && editingMode !== 'row' ? theme.palette.mode === 'dark' ? material.lighten(theme.palette.background["default"], 0.13) + " !important" : material.darken(theme.palette.background["default"], 0.07) + " !important" : undefined
        }
      }, tableCellProps == null ? void 0 : tableCellProps.sx, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: column.getSize()
      });
    }
  }), React__default.createElement(React__default.Fragment, null, isLoading || showSkeletons ? React__default.createElement(material.Skeleton, Object.assign({
    animation: "wave",
    height: 20,
    width: skeletonWidth
  }, muiTableBodyCellSkeletonProps)) : enableRowNumbers && rowNumberMode === 'static' && column.id === 'mrt-row-numbers' ? rowIndex + 1 : columnDefType === 'display' ? columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  }) : cell.getIsPlaceholder() || row.getIsGrouped() && column.id !== row.groupingColumnId ? null : cell.getIsAggregated() ? cell.renderAggregatedCell() : isEditing ? React__default.createElement(MRT_EditCellTextField, {
    cell: cell,
    tableInstance: tableInstance
  }) : (enableClickToCopy || columnDef.enableClickToCopy) && columnDef.enableClickToCopy !== false ? React__default.createElement(React__default.Fragment, null, React__default.createElement(MRT_CopyButton, {
    cell: cell,
    tableInstance: tableInstance
  }, React__default.createElement(React__default.Fragment, null, (_columnDef$Cell = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  })) != null ? _columnDef$Cell : cell.renderCell())), row.getIsGrouped() && React__default.createElement(React__default.Fragment, null, " (", (_row$subRows = row.subRows) == null ? void 0 : _row$subRows.length, ")")) : React__default.createElement(React__default.Fragment, null, (_columnDef$Cell2 = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    tableInstance: tableInstance
  })) != null ? _columnDef$Cell2 : cell.renderCell(), row.getIsGrouped() && React__default.createElement(React__default.Fragment, null, " (", (_row$subRows$length = (_row$subRows2 = row.subRows) == null ? void 0 : _row$subRows2.length) != null ? _row$subRows$length : '', ")"))));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getVisibleLeafColumns = tableInstance.getVisibleLeafColumns,
      _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      muiTableDetailPanelProps = _tableInstance$option.muiTableDetailPanelProps,
      onMrtDetailPanelClick = _tableInstance$option.onMrtDetailPanelClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;
  var tableCellProps = muiTableDetailPanelProps instanceof Function ? muiTableDetailPanelProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableDetailPanelProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps), React__default.createElement(material.TableCell, Object.assign({
    colSpan: getVisibleLeafColumns().length,
    onClick: function onClick(event) {
      return onMrtDetailPanelClick == null ? void 0 : onMrtDetailPanelClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    }
  }, tableCellProps, {
    sx: _extends({
      borderBottom: !row.getIsExpanded() ? 'none' : undefined,
      pb: row.getIsExpanded() ? '1rem' : 0,
      pt: row.getIsExpanded() ? '1rem' : 0,
      transition: 'all 0.2s ease-in-out',
      width: tableInstance.getTotalSize() + "px"
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), React__default.createElement(material.Collapse, {
    "in": row.getIsExpanded()
  }, renderDetailPanel == null ? void 0 : renderDetailPanel({
    row: row,
    tableInstance: tableInstance
  }))));
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var row = _ref.row,
      rowIndex = _ref.rowIndex,
      tableInstance = _ref.tableInstance;
  var getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      onMrtRowClick = _tableInstance$option.onMrtRowClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.TableRow, Object.assign({
    hover: true,
    onClick: function onClick(event) {
      return onMrtRowClick == null ? void 0 : onMrtRowClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    },
    selected: row.getIsSelected()
  }, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: material.lighten(theme.palette.background["default"], 0.06),
        transition: 'all 0.2s ease-in-out',
        '&:hover td': {
          backgroundColor: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false && getIsSomeColumnsPinned() ? theme.palette.mode === 'dark' ? "" + material.lighten(theme.palette.background["default"], 0.12) : "" + material.darken(theme.palette.background["default"], 0.05) : undefined
        }
      }, tableRowProps == null ? void 0 : tableRowProps.sx);
    }
  }), row.getVisibleCells().map(function (cell) {
    return React__default.createElement(MRT_TableBodyCell, {
      cell: cell,
      key: cell.id,
      enableHover: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false,
      rowIndex: rowIndex,
      tableInstance: tableInstance
    });
  })), renderDetailPanel && !row.getIsGrouped() && React__default.createElement(MRT_TableDetailPanel, {
    row: row,
    tableInstance: tableInstance
  }));
};

var MRT_TableBody = function MRT_TableBody(_ref) {
  var tableInstance = _ref.tableInstance,
      tableContainerRef = _ref.tableContainerRef;
  var getPaginationRowModel = tableInstance.getPaginationRowModel,
      getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enablePagination = _tableInstance$option.enablePagination,
      enableRowVirtualization = _tableInstance$option.enableRowVirtualization,
      muiTableBodyProps = _tableInstance$option.muiTableBodyProps,
      virtualizerProps = _tableInstance$option.virtualizerProps;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var tableBodyProps = muiTableBodyProps instanceof Function ? muiTableBodyProps({
    tableInstance: tableInstance
  }) : muiTableBodyProps;
  var rows = enablePagination ? getPaginationRowModel().rows : getPrePaginationRowModel().rows;
  var rowVirtualizer = enableRowVirtualization ? useVirtual(_extends({
    overscan: isDensePadding ? 15 : 5,
    size: rows.length,
    parentRef: tableContainerRef
  }, virtualizerProps)) : {};
  var virtualRows = rowVirtualizer.virtualItems;
  var paddingTop = (virtualRows == null ? void 0 : virtualRows.length) > 0 ? virtualRows[0].start : 0;
  var paddingBottom = (virtualRows == null ? void 0 : virtualRows.length) > 0 ? rowVirtualizer.totalSize - virtualRows[virtualRows.length - 1].end : 0;
  return React__default.createElement(material.TableBody, Object.assign({}, tableBodyProps), enableRowVirtualization && paddingTop > 0 && React__default.createElement("tr", null, React__default.createElement("td", {
    style: {
      height: paddingTop + "px"
    }
  })), (enableRowVirtualization ? virtualRows : rows).map(function (rowOrVirtualRow, rowIndex) {
    var row = enableRowVirtualization ? rows[rowOrVirtualRow.index] : rowOrVirtualRow;
    return React__default.createElement(MRT_TableBodyRow, {
      key: row.id,
      row: row,
      rowIndex: enableRowVirtualization ? rowOrVirtualRow.index : rowIndex,
      tableInstance: tableInstance
    });
  }), enableRowVirtualization && paddingBottom > 0 && React__default.createElement("tr", null, React__default.createElement("td", {
    style: {
      height: paddingBottom + "px"
    }
  })));
};

var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _ref2, _ref3, _ref4;

  var footer = _ref.footer,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      muiTableFooterCellProps = _tableInstance$option.muiTableFooterCellProps,
      enableColumnResizing = _tableInstance$option.enableColumnResizing;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var column = footer.column;
  var columnDef = column.columnDef,
      columnDefType = column.columnDefType;
  var mTableFooterCellProps = muiTableFooterCellProps instanceof Function ? muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableFooterCellProps;
  var mcTableFooterCellProps = columnDef.muiTableFooterCellProps instanceof Function ? columnDef.muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : columnDef.muiTableFooterCellProps;

  var tableCellProps = _extends({}, mTableFooterCellProps, mcTableFooterCellProps);

  return React__default.createElement(material.TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: footer.colSpan,
    variant: "head"
  }, tableCellProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: theme.palette.background["default"],
        backgroundImage: "linear-gradient(" + material.alpha(theme.palette.common.white, 0.05) + "," + material.alpha(theme.palette.common.white, 0.05) + ")",
        fontWeight: 'bold',
        maxWidth: column.getSize() + "px",
        minWidth: column.getSize() + "px",
        p: isDensePadding ? '0.5rem' : '1rem',
        transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out",
        width: column.getSize(),
        verticalAlign: 'text-top'
      }, tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), React__default.createElement(React__default.Fragment, null, footer.isPlaceholder ? null : (_ref2 = (_ref3 = (_ref4 = columnDef.Footer instanceof Function ? columnDef.Footer == null ? void 0 : columnDef.Footer({
    footer: footer,
    tableInstance: tableInstance
  }) : columnDef.Footer) != null ? _ref4 : columnDef.footer) != null ? _ref3 : footer.renderFooter()) != null ? _ref2 : null));
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var _footerGroup$headers;

  var footerGroup = _ref.footerGroup,
      tableInstance = _ref.tableInstance;
  var muiTableFooterRowProps = tableInstance.options.muiTableFooterRowProps; // if no content in row, skip row

  if (!((_footerGroup$headers = footerGroup.headers) != null && _footerGroup$headers.some(function (header) {
    return typeof header.column.columnDef.footer === 'string' && !!header.column.columnDef.footer || header.column.columnDef.Footer;
  }))) return null;
  var tableRowProps = muiTableFooterRowProps instanceof Function ? muiTableFooterRowProps({
    footerGroup: footerGroup,
    tableInstance: tableInstance
  }) : muiTableFooterRowProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps), footerGroup.headers.map(function (footer) {
    return React__default.createElement(MRT_TableFooterCell, {
      footer: footer,
      key: footer.id,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableFooter = function MRT_TableFooter(_ref) {
  var tableInstance = _ref.tableInstance;
  var getFooterGroups = tableInstance.getFooterGroups,
      muiTableFooterProps = tableInstance.options.muiTableFooterProps;
  var tableFooterProps = muiTableFooterProps instanceof Function ? muiTableFooterProps({
    tableInstance: tableInstance
  }) : muiTableFooterProps;
  return React__default.createElement(material.TableFooter, Object.assign({}, tableFooterProps), getFooterGroups().map(function (footerGroup) {
    return React__default.createElement(MRT_TableFooterRow, {
      footerGroup: footerGroup,
      key: footerGroup.id,
      tableInstance: tableInstance
    });
  }));
};

var MRT_Table = function MRT_Table(_ref) {
  var tableContainerRef = _ref.tableContainerRef,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      enableRowVirtualization = _tableInstance$option.enableRowVirtualization,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      enableTableFooter = _tableInstance$option.enableTableFooter,
      enableTableHead = _tableInstance$option.enableTableHead,
      muiTableProps = _tableInstance$option.muiTableProps;
  var tableProps = muiTableProps instanceof Function ? muiTableProps({
    tableInstance: tableInstance
  }) : muiTableProps;
  return React__default.createElement(material.Table, Object.assign({
    stickyHeader: enableStickyHeader
  }, tableProps, {
    sx: _extends({
      tableLayout: enableColumnResizing || enableRowVirtualization ? 'fixed' : 'auto'
    }, tableProps == null ? void 0 : tableProps.sx)
  }), enableTableHead && React__default.createElement(MRT_TableHead, {
    tableInstance: tableInstance
  }), React__default.createElement(MRT_TableBody, {
    tableContainerRef: tableContainerRef,
    tableInstance: tableInstance
  }), enableTableFooter && React__default.createElement(MRT_TableFooter, {
    tableInstance: tableInstance
  }));
};

var useIsomorphicLayoutEffect$2 = typeof window !== 'undefined' ? React.useLayoutEffect : React.useEffect;
var MRT_TableContainer = function MRT_TableContainer(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      muiTableContainerProps = _tableInstance$option.muiTableContainerProps,
      tableId = _tableInstance$option.tableId;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var _useState = React.useState(0),
      totalToolbarHeight = _useState[0],
      setTotalToolbarHeight = _useState[1];

  var tableContainerProps = muiTableContainerProps instanceof Function ? muiTableContainerProps({
    tableInstance: tableInstance
  }) : muiTableContainerProps;
  useIsomorphicLayoutEffect$2(function () {
    var _document$getElementB, _document, _document$getElementB2, _document$getElementB3, _document2, _document2$getElement;

    var topToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB = (_document = document) == null ? void 0 : (_document$getElementB2 = _document.getElementById("mrt-" + tableId + "-toolbar-top")) == null ? void 0 : _document$getElementB2.offsetHeight) != null ? _document$getElementB : 0 : 0;
    var bottomToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB3 = (_document2 = document) == null ? void 0 : (_document2$getElement = _document2.getElementById("mrt-" + tableId + "-toolbar-bottom")) == null ? void 0 : _document2$getElement.offsetHeight) != null ? _document$getElementB3 : 0 : 0;
    setTotalToolbarHeight(topToolbarHeight + bottomToolbarHeight);
  });
  var tableContainerRef = React__default.useRef(null);
  return React__default.createElement(material.TableContainer, Object.assign({}, tableContainerProps, {
    ref: tableContainerRef,
    sx: _extends({
      maxWidth: '100%',
      maxHeight: enableStickyHeader ? "clamp(350px, calc(100vh - " + totalToolbarHeight + "px), 2000px)" : undefined,
      overflow: 'auto'
    }, tableContainerProps == null ? void 0 : tableContainerProps.sx),
    style: {
      maxHeight: isFullScreen ? "calc(100vh - " + totalToolbarHeight + "px)" : undefined
    }
  }), React__default.createElement(MRT_Table, {
    tableContainerRef: tableContainerRef,
    tableInstance: tableInstance
  }));
};

var MRT_TablePaper = function MRT_TablePaper(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableToolbarBottom = _tableInstance$option.enableToolbarBottom,
      enableToolbarTop = _tableInstance$option.enableToolbarTop,
      muiTablePaperProps = _tableInstance$option.muiTablePaperProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  React.useEffect(function () {
    if (typeof window !== 'undefined') {
      if (isFullScreen) {
        document.body.style.overflow = 'hidden';
        document.body.style.height = '100vh';
      } else {
        document.body.style.overflow = 'auto';
        document.body.style.height = 'auto';
      }
    }
  }, [isFullScreen]);
  var tablePaperProps = muiTablePaperProps instanceof Function ? muiTablePaperProps({
    tableInstance: tableInstance
  }) : muiTablePaperProps;
  return React__default.createElement(DndProvider, {
    backend: HTML5Backend
  }, React__default.createElement(material.Paper, Object.assign({
    elevation: 2
  }, tablePaperProps, {
    sx: _extends({
      transition: 'all 0.2s ease-in-out'
    }, tablePaperProps == null ? void 0 : tablePaperProps.sx),
    style: {
      height: isFullScreen ? '100vh' : undefined,
      margin: isFullScreen ? '0' : undefined,
      maxHeight: isFullScreen ? '100vh' : undefined,
      maxWidth: isFullScreen ? '100vw' : undefined,
      padding: isFullScreen ? '0' : undefined,
      width: isFullScreen ? '100vw' : undefined
    }
  }), enableToolbarTop && React__default.createElement(MRT_ToolbarTop, {
    tableInstance: tableInstance
  }), React__default.createElement(MRT_TableContainer, {
    tableInstance: tableInstance
  }), enableToolbarBottom && React__default.createElement(MRT_ToolbarBottom, {
    tableInstance: tableInstance
  })));
};

var MRT_TableRoot = function MRT_TableRoot(props) {
  var _initialState$current, _initialState$current2, _initialState$isDense, _initialState$isFullS, _initialState$showFil, _initialState$showGlo, _props$globalFilterFn, _props$state3, _props$state4;

  var _useState = React.useState(props.tableId),
      tableId = _useState[0],
      setIdPrefix = _useState[1];

  React.useEffect(function () {
    var _props$tableId;

    return setIdPrefix((_props$tableId = props.tableId) != null ? _props$tableId : Math.random().toString(36).substring(2, 9));
  }, [props.tableId]);
  var showActionColumn = props.enableRowActions || props.enableEditing && props.editingMode === 'row';
  var showExpandColumn = props.enableExpanding || props.enableGrouping;
  var initialState = React.useMemo(function () {
    var _props$initialState, _initState$columnOrde;

    var initState = (_props$initialState = props.initialState) != null ? _props$initialState : {};
    initState.columnOrder = ((_initState$columnOrde = initState == null ? void 0 : initState.columnOrder) != null ? _initState$columnOrde : props.enableColumnOrdering || props.enableGrouping) ? [showActionColumn && 'mrt-row-actions', showExpandColumn && 'mrt-expand', props.enableRowSelection && 'mrt-select', props.enableRowNumbers && 'mrt-row-numbers'].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
      return c.id;
    })).filter(Boolean) : [];

    if (!props.enablePersistentState || !props.tableId) {
      return initState;
    }

    if (typeof window === 'undefined') {
      {
        console.error('The MRT Persistent Table State feature is not supported if using SSR, but you can wrap your <MaterialReactTable /> in a MUI <NoSsr> tags to let it work');
      }

      return initState;
    }

    var storedState = props.persistentStateMode === 'localStorage' ? localStorage.getItem("mrt-" + tableId + "-table-state") : props.persistentStateMode === 'sessionStorage' ? sessionStorage.getItem("mrt-" + tableId + "-table-state") : '{}';

    if (storedState) {
      var parsedState = JSON.parse(storedState);

      if (parsedState) {
        return _extends({}, initState, parsedState);
      }
    }

    return initState;
  }, []);

  var _useState2 = React.useState((_initialState$current = initialState == null ? void 0 : initialState.currentEditingCell) != null ? _initialState$current : null),
      currentEditingCell = _useState2[0],
      setCurrentEditingCell = _useState2[1];

  var _useState3 = React.useState((_initialState$current2 = initialState == null ? void 0 : initialState.currentEditingRow) != null ? _initialState$current2 : null),
      currentEditingRow = _useState3[0],
      setCurrentEditingRow = _useState3[1];

  var _useState4 = React.useState((_initialState$isDense = initialState == null ? void 0 : initialState.isDensePadding) != null ? _initialState$isDense : false),
      isDensePadding = _useState4[0],
      setIsDensePadding = _useState4[1];

  var _useState5 = React.useState((_initialState$isFullS = initialState == null ? void 0 : initialState.isFullScreen) != null ? _initialState$isFullS : false),
      isFullScreen = _useState5[0],
      setIsFullScreen = _useState5[1];

  var _useState6 = React.useState((_initialState$showFil = initialState == null ? void 0 : initialState.showFilters) != null ? _initialState$showFil : false),
      showFilters = _useState6[0],
      setShowFilters = _useState6[1];

  var _useState7 = React.useState((_initialState$showGlo = initialState == null ? void 0 : initialState.showGlobalFilter) != null ? _initialState$showGlo : false),
      showGlobalFilter = _useState7[0],
      setShowGlobalFilter = _useState7[1];

  var _useState8 = React.useState(function () {
    return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
      var _ref, _c$filterFn, _initialState$current3, _c$filterSelectOption, _ref2;

      return _ref2 = {}, _ref2[c.id] = (_ref = (_c$filterFn = c.filterFn) != null ? _c$filterFn : initialState == null ? void 0 : (_initialState$current3 = initialState.currentFilterFns) == null ? void 0 : _initialState$current3[c.id]) != null ? _ref : !!((_c$filterSelectOption = c.filterSelectOptions) != null && _c$filterSelectOption.length) ? MRT_FILTER_OPTION.EQUALS : MRT_FILTER_OPTION.FUZZY, _ref2;
    })));
  }),
      currentFilterFns = _useState8[0],
      setCurrentFilterFns = _useState8[1];

  var _useState9 = React.useState((_props$globalFilterFn = props.globalFilterFn) != null ? _props$globalFilterFn : MRT_FILTER_OPTION.FUZZY),
      currentGlobalFilterFn = _useState9[0],
      setCurrentGlobalFilterFn = _useState9[1];

  var table = React.useMemo(function () {
    return (// @ts-ignore
      reactTable.createTable().setOptions({
        //@ts-ignore
        filterFns: defaultFilterFNs,
        getCoreRowModel: reactTable.getCoreRowModel(),
        getExpandedRowModel: reactTable.getExpandedRowModel(),
        getFacetedRowModel: reactTable.getFacetedRowModel(),
        getFilteredRowModel: reactTable.getFilteredRowModel(),
        getGroupedRowModel: reactTable.getGroupedRowModel(),
        getPaginationRowModel: reactTable.getPaginationRowModel(),
        getSortedRowModel: reactTable.getSortedRowModel(),
        getSubRows: function getSubRows(row) {
          return row == null ? void 0 : row.subRows;
        },
        tableId: tableId,
        initialState: initialState
      })
    );
  }, []);
  var displayColumns = React.useMemo(function () {
    var _props$localization, _props$localization2, _props$localization3, _props$localization5;

    return [showActionColumn && createDisplayColumn(table, {
      Cell: function Cell(_ref3) {
        var cell = _ref3.cell;
        return React__default.createElement(MRT_ToggleRowActionMenuButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      header: (_props$localization = props.localization) == null ? void 0 : _props$localization.actions,
      id: 'mrt-row-actions',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 60
    }), showExpandColumn && createDisplayColumn(table, {
      Cell: function Cell(_ref4) {
        var cell = _ref4.cell;
        return React__default.createElement(MRT_ExpandButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableExpandAll ? React__default.createElement(MRT_ExpandAllButton, {
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization2 = props.localization) == null ? void 0 : _props$localization2.expand,
      id: 'mrt-expand',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    }), props.enableRowSelection && createDisplayColumn(table, {
      Cell: function Cell(_ref5) {
        var cell = _ref5.cell;
        return React__default.createElement(MRT_SelectCheckbox, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableSelectAll ? React__default.createElement(MRT_SelectCheckbox, {
          selectAll: true,
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization3 = props.localization) == null ? void 0 : _props$localization3.select,
      id: 'mrt-select',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    }), props.enableRowNumbers && createDisplayColumn(table, {
      Cell: function Cell(_ref6) {
        var cell = _ref6.cell;
        return cell.row.index + 1;
      },
      Header: function Header() {
        var _props$localization4;

        return (_props$localization4 = props.localization) == null ? void 0 : _props$localization4.rowNumber;
      },
      header: (_props$localization5 = props.localization) == null ? void 0 : _props$localization5.rowNumbers,
      id: 'mrt-row-numbers',
      muiTableBodyCellProps: props.muiTableBodyCellProps,
      muiTableHeadCellProps: props.muiTableHeadCellProps,
      size: 50
    })].filter(Boolean);
  }, [props.editingMode, props.enableEditing, props.enableExpandAll, props.enableExpanding, props.enableGrouping, props.enableRowActions, props.enableRowNumbers, props.enableRowSelection, props.enableSelectAll, props.localization, table]);
  var columns = React.useMemo(function () {
    return [].concat(displayColumns, props.columns.map(function (column) {
      return column.columns ? createGroup(table, column, currentFilterFns) : createDataColumn(table, column, currentFilterFns);
    }));
  }, [table, props.columns, currentFilterFns]);
  var data = React.useMemo(function () {
    var _props$state, _props$state2;

    return ((_props$state = props.state) != null && _props$state.isLoading || (_props$state2 = props.state) != null && _props$state2.showSkeletons) && !props.data.length ? [].concat(Array(10).fill(null)).map(function () {
      return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
        var _ref7;

        return _ref7 = {}, _ref7[c.id] = null, _ref7;
      })));
    }) : props.data;
  }, [props.data, (_props$state3 = props.state) == null ? void 0 : _props$state3.isLoading, (_props$state4 = props.state) == null ? void 0 : _props$state4.showSkeletons]); //@ts-ignore

  var tableInstance = _extends({}, reactTable.useTableInstance(table, _extends({}, props, {
    //@ts-ignore
    columns: columns,
    data: data,
    //@ts-ignore
    globalFilterFn: currentGlobalFilterFn,
    state: _extends({
      currentEditingCell: currentEditingCell,
      currentEditingRow: currentEditingRow,
      currentFilterFns: currentFilterFns,
      currentGlobalFilterFn: currentGlobalFilterFn,
      isDensePadding: isDensePadding,
      isFullScreen: isFullScreen,
      showFilters: showFilters,
      showGlobalFilter: showGlobalFilter
    }, props.state)
  })), {
    setCurrentEditingCell: setCurrentEditingCell,
    setCurrentEditingRow: setCurrentEditingRow,
    setCurrentFilterFns: setCurrentFilterFns,
    setCurrentGlobalFilterFn: setCurrentGlobalFilterFn,
    setIsDensePadding: setIsDensePadding,
    setIsFullScreen: setIsFullScreen,
    setShowFilters: setShowFilters,
    setShowGlobalFilter: setShowGlobalFilter
  });

  React.useEffect(function () {
    if (typeof window === 'undefined' || !props.enablePersistentState) {
      return;
    }

    if (!props.tableId && "development" !== 'production') {
      console.warn('a unique tableId prop is required for persistent table state to work');
      return;
    }

    var itemArgs = ["mrt-" + tableId + "-table-state", JSON.stringify(tableInstance.getState())];

    if (props.persistentStateMode === 'localStorage') {
      var _localStorage;

      (_localStorage = localStorage).setItem.apply(_localStorage, itemArgs);
    } else if (props.persistentStateMode === 'sessionStorage') {
      var _sessionStorage;

      (_sessionStorage = sessionStorage).setItem.apply(_sessionStorage, itemArgs);
    }
  }, [props.enablePersistentState, props.tableId, props.persistentStateMode, tableInstance]);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Dialog, {
    PaperComponent: material.Box,
    TransitionComponent: material.Grow,
    disablePortal: true,
    fullScreen: true,
    keepMounted: false,
    onClose: function onClose() {
      return setIsFullScreen(false);
    },
    open: isFullScreen,
    transitionDuration: 400
  }, React__default.createElement(MRT_TablePaper, {
    tableInstance: tableInstance
  })), !isFullScreen && React__default.createElement(MRT_TablePaper, {
    tableInstance: tableInstance
  }));
};

var _excluded$5 = ["autoResetExpanded", "columnResizeMode", "defaultColumn", "editingMode", "enableColumnActions", "enableColumnFilters", "enableColumnOrdering", "enableColumnResizing", "enableDensePaddingToggle", "enableExpandAll", "enableFilters", "enableFullScreenToggle", "enableGlobalFilter", "enableGrouping", "enableHiding", "enableMultiRowSelection", "enablePagination", "enablePinning", "enableSelectAll", "enableSorting", "enableStickyHeader", "enableTableFooter", "enableTableHead", "enableToolbarBottom", "enableToolbarInternalActions", "enableToolbarTop", "icons", "localization", "persistentStateMode", "positionActionsColumn", "positionPagination", "positionGlobalFilter", "positionToolbarActions", "positionToolbarAlertBanner", "rowNumberMode", "selectAllMode"];
var MaterialReactTable = (function (_ref) {
  var _ref$autoResetExpande = _ref.autoResetExpanded,
      autoResetExpanded = _ref$autoResetExpande === void 0 ? false : _ref$autoResetExpande,
      _ref$columnResizeMode = _ref.columnResizeMode,
      columnResizeMode = _ref$columnResizeMode === void 0 ? 'onEnd' : _ref$columnResizeMode,
      _ref$defaultColumn = _ref.defaultColumn,
      defaultColumn = _ref$defaultColumn === void 0 ? {
    minSize: 40,
    maxSize: 1000,
    size: 180
  } : _ref$defaultColumn,
      _ref$editingMode = _ref.editingMode,
      editingMode = _ref$editingMode === void 0 ? 'row' : _ref$editingMode,
      _ref$enableColumnActi = _ref.enableColumnActions,
      enableColumnActions = _ref$enableColumnActi === void 0 ? true : _ref$enableColumnActi,
      _ref$enableColumnFilt = _ref.enableColumnFilters,
      enableColumnFilters = _ref$enableColumnFilt === void 0 ? true : _ref$enableColumnFilt,
      _ref$enableColumnOrde = _ref.enableColumnOrdering,
      enableColumnOrdering = _ref$enableColumnOrde === void 0 ? false : _ref$enableColumnOrde,
      _ref$enableColumnResi = _ref.enableColumnResizing,
      enableColumnResizing = _ref$enableColumnResi === void 0 ? false : _ref$enableColumnResi,
      _ref$enableDensePaddi = _ref.enableDensePaddingToggle,
      enableDensePaddingToggle = _ref$enableDensePaddi === void 0 ? true : _ref$enableDensePaddi,
      _ref$enableExpandAll = _ref.enableExpandAll,
      enableExpandAll = _ref$enableExpandAll === void 0 ? true : _ref$enableExpandAll,
      _ref$enableFilters = _ref.enableFilters,
      enableFilters = _ref$enableFilters === void 0 ? true : _ref$enableFilters,
      _ref$enableFullScreen = _ref.enableFullScreenToggle,
      enableFullScreenToggle = _ref$enableFullScreen === void 0 ? true : _ref$enableFullScreen,
      _ref$enableGlobalFilt = _ref.enableGlobalFilter,
      enableGlobalFilter = _ref$enableGlobalFilt === void 0 ? true : _ref$enableGlobalFilt,
      _ref$enableGrouping = _ref.enableGrouping,
      enableGrouping = _ref$enableGrouping === void 0 ? false : _ref$enableGrouping,
      _ref$enableHiding = _ref.enableHiding,
      enableHiding = _ref$enableHiding === void 0 ? true : _ref$enableHiding,
      _ref$enableMultiRowSe = _ref.enableMultiRowSelection,
      enableMultiRowSelection = _ref$enableMultiRowSe === void 0 ? true : _ref$enableMultiRowSe,
      _ref$enablePagination = _ref.enablePagination,
      enablePagination = _ref$enablePagination === void 0 ? true : _ref$enablePagination,
      _ref$enablePinning = _ref.enablePinning,
      enablePinning = _ref$enablePinning === void 0 ? false : _ref$enablePinning,
      _ref$enableSelectAll = _ref.enableSelectAll,
      enableSelectAll = _ref$enableSelectAll === void 0 ? true : _ref$enableSelectAll,
      _ref$enableSorting = _ref.enableSorting,
      enableSorting = _ref$enableSorting === void 0 ? true : _ref$enableSorting,
      _ref$enableStickyHead = _ref.enableStickyHeader,
      enableStickyHeader = _ref$enableStickyHead === void 0 ? true : _ref$enableStickyHead,
      _ref$enableTableFoote = _ref.enableTableFooter,
      enableTableFooter = _ref$enableTableFoote === void 0 ? true : _ref$enableTableFoote,
      _ref$enableTableHead = _ref.enableTableHead,
      enableTableHead = _ref$enableTableHead === void 0 ? true : _ref$enableTableHead,
      _ref$enableToolbarBot = _ref.enableToolbarBottom,
      enableToolbarBottom = _ref$enableToolbarBot === void 0 ? true : _ref$enableToolbarBot,
      _ref$enableToolbarInt = _ref.enableToolbarInternalActions,
      enableToolbarInternalActions = _ref$enableToolbarInt === void 0 ? true : _ref$enableToolbarInt,
      _ref$enableToolbarTop = _ref.enableToolbarTop,
      enableToolbarTop = _ref$enableToolbarTop === void 0 ? true : _ref$enableToolbarTop,
      icons = _ref.icons,
      localization = _ref.localization,
      _ref$persistentStateM = _ref.persistentStateMode,
      persistentStateMode = _ref$persistentStateM === void 0 ? 'sessionStorage' : _ref$persistentStateM,
      _ref$positionActionsC = _ref.positionActionsColumn,
      positionActionsColumn = _ref$positionActionsC === void 0 ? 'first' : _ref$positionActionsC,
      _ref$positionPaginati = _ref.positionPagination,
      positionPagination = _ref$positionPaginati === void 0 ? 'bottom' : _ref$positionPaginati,
      _ref$positionGlobalFi = _ref.positionGlobalFilter,
      positionGlobalFilter = _ref$positionGlobalFi === void 0 ? 'right' : _ref$positionGlobalFi,
      _ref$positionToolbarA = _ref.positionToolbarActions,
      positionToolbarActions = _ref$positionToolbarA === void 0 ? 'top' : _ref$positionToolbarA,
      _ref$positionToolbarA2 = _ref.positionToolbarAlertBanner,
      positionToolbarAlertBanner = _ref$positionToolbarA2 === void 0 ? 'top' : _ref$positionToolbarA2,
      _ref$rowNumberMode = _ref.rowNumberMode,
      rowNumberMode = _ref$rowNumberMode === void 0 ? 'original' : _ref$rowNumberMode,
      _ref$selectAllMode = _ref.selectAllMode,
      selectAllMode = _ref$selectAllMode === void 0 ? 'all' : _ref$selectAllMode,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$5);

  return React__default.createElement(MRT_TableRoot, Object.assign({
    autoResetExpanded: autoResetExpanded,
    columnResizeMode: columnResizeMode,
    defaultColumn: defaultColumn,
    editingMode: editingMode,
    enableColumnActions: enableColumnActions,
    enableColumnFilters: enableColumnFilters,
    enableColumnOrdering: enableColumnOrdering,
    enableColumnResizing: enableColumnResizing,
    enableDensePaddingToggle: enableDensePaddingToggle,
    enableExpandAll: enableExpandAll,
    enableFilters: enableFilters,
    enableFullScreenToggle: enableFullScreenToggle,
    enableGlobalFilter: enableGlobalFilter,
    enableGrouping: enableGrouping,
    enableHiding: enableHiding,
    enableMultiRowSelection: enableMultiRowSelection,
    enablePagination: enablePagination,
    enablePinning: enablePinning,
    enableSelectAll: enableSelectAll,
    enableSorting: enableSorting,
    enableStickyHeader: enableStickyHeader,
    enableTableFooter: enableTableFooter,
    enableTableHead: enableTableHead,
    enableToolbarBottom: enableToolbarBottom,
    enableToolbarInternalActions: enableToolbarInternalActions,
    enableToolbarTop: enableToolbarTop,
    icons: _extends({}, MRT_Default_Icons, icons),
    localization: _extends({}, MRT_DefaultLocalization_EN, localization),
    persistentStateMode: persistentStateMode,
    positionActionsColumn: positionActionsColumn,
    positionGlobalFilter: positionGlobalFilter,
    positionPagination: positionPagination,
    positionToolbarActions: positionToolbarActions,
    positionToolbarAlertBanner: positionToolbarAlertBanner,
    rowNumberMode: rowNumberMode,
    selectAllMode: selectAllMode
  }, rest));
});

exports.default = MaterialReactTable;
//# sourceMappingURL=material-react-table.cjs.development.js.map
